@@ -250,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "%sに完了",
     "Due on %s by %s" : "期限日%s が%sにより設定",
     "Due on %s" : "期限日：%s",
+    "System Address Book" : "システム連絡先リスト",
+    "The system address book contains contact information for all users in your instance." : "システムのアドレス帳には、インスタンスのすべてのユーザーの連絡先情報が含まれています。",
+    "Enable System Address Book" : "システム連絡先リストを有効にする",
     "DAV system address book" : "DAVシステムアドレス帳",
     "No outstanding DAV system address book sync." : "DAVシステムアドレス帳の同期が完了していません。",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAVシステムのアドレス帳同期は、インスタンスに1000人以上のユーザーがいるか、エラーが発生したためまだ実行されていません。手動で実行するには、\"occ dav:sync-system-addressbook\"を呼び出してください。",
