@@ -250,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "Slutförd %s",
     "Due on %s by %s" : "Slutar den %s vid %s",
     "Due on %s" : "Slutar den %s",
+    "System Address Book" : "Systemadressbok",
+    "The system address book contains contact information for all users in your instance." : "Systemadressboken innehåller kontaktinformation för alla användare i din instans.",
+    "Enable System Address Book" : "Aktivera systemadressboken",
     "DAV system address book" : "DAV-systemets adressbok",
     "No outstanding DAV system address book sync." : "Ingen utestående synkronisering för DAV-systemets adressbok.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV-systemets adressbokssynkronisering har inte körts ännu eftersom din instans har fler än 1000 användare eller för att ett fel uppstod. Kör det manuellt genom att anropa \"occ dav:sync-system-addressbook\".",
