@@ -235,6 +235,8 @@ OC.L10N.register(
     "Failed to convert files: {message}" : "Kunne ikke konvertere filer: {message}",
     "All files failed to be converted" : "Alle filer kunne ikke konverteres",
     "One file could not be converted: {message}" : "En fil kunne ikke konverteres: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["En fil kunne ikke konverteres","%n filer kunne ikke konverteres"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["En fil konverteret","%n filer konverteret"],
     "Files successfully converted" : "Filer konverteret",
     "Failed to convert files" : "Kunne ikke konvertere filer",
     "Converting file …" : "Konverterer fil ...",
