@@ -235,6 +235,8 @@ OC.L10N.register(
     "Failed to convert files: {message}" : "ファイルの変換に失敗しました: {message}",
     "All files failed to be converted" : "すべてのファイルの変換に失敗しました",
     "One file could not be converted: {message}" : "1つのファイルが変換できませんでした: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["%n個のファイルが変換できませんでした"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["%n個のファイルの変換に成功しました"],
     "Files successfully converted" : "ファイルは正常に変換されました",
     "Failed to convert files" : "ファイルの変換に失敗しました",
     "Converting file …" : "ファイルの変換…",
