@@ -80,6 +80,7 @@ OC.L10N.register(
     "Go to the \"{dir}\" directory" : "Перейти в каталог \"{dir}\"",
     "Current directory path" : "Текущий путь к каталогу",
     "Your have used your space quota and cannot upload files anymore" : "Вы использовали всё доступное вам место и не можете больше загружать файлы",
+    "You do not have permission to upload or create files here." : "У вас нет прав загружать или создавать здесь файлы.",
     "Drag and drop files here to upload" : "Перетаскивайте файлы сюда для загрузки",
     "Favorite" : "Добавить в избранное",
     "Back" : "Назад",
@@ -105,6 +106,7 @@ OC.L10N.register(
     "Toggle selection for all files and folders" : "Установить или снять выделение всех файлов и папок",
     "Name" : "Имя",
     "Size" : "Размер",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" не удалось выполнить некоторые элементы",
     "\"{displayName}\" batch action executed successfully" : "Пакетное действие \"{displayName}\" выполнено успешно",
     "\"{displayName}\" action failed" : "Действие «{displayName}» завершилось неудачно",
     "Actions" : "Действия",
@@ -127,6 +129,7 @@ OC.L10N.register(
     "This name is already in use." : "Это название уже используется.",
     "Create" : "Создать",
     "Fill template fields" : "Заполните поля шаблона",
+    "Submitting fields …" : "Отправка полей…",
     "Submit" : "Отправить ответ",
     "Choose a file or folder to transfer" : "Выберите файл или папку для передачи",
     "Transfer" : "Передать",
@@ -139,11 +142,15 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Выберите файл или папку для передачи владения",
     "Change" : "Изменить",
     "New owner" : "Новый владелец",
+    "Keep {old}" : "Сохранить {old}",
+    "Keep without extension" : "Сохранить без расширения",
+    "Use {new}" : "Использовать{new}",
     "Remove extension" : "Удалить расширение",
     "Change file extension" : "Изменить расширение файла",
     "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Изменение расширения файла с \"{old}\" на \"{new}\" может сделать файл нечитаемым.",
     "Removing the file extension \"{old}\" may render the file unreadable." : "Удаление расширения файла \"{old}\" может сделать файл нечитаемым.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Добавление расширения файла \"{new}\" может сделать его нечитаемым.",
+    "Do not show this dialog again." : "Больше не показывать это диалоговое окно.",
     "Select file or folder to link to" : "Выберите файл или папку для создания ссылки",
     "Choose {file}" : "Выберан {file}",
     "Share" : "Поделиться",
@@ -151,6 +158,7 @@ OC.L10N.register(
     "Shared" : "Опубликованное",
     "Switch to list view" : "Переключение в режим просмотра списка",
     "Switch to grid view" : "Переключиться на режим просмотра сеткой",
+    "The file could not be found" : "Файл не найден.",
     "Upload was cancelled by user" : "Загрузка была отменена пользователем",
     "Not enough free space" : "Недостаточно свободного места",
     "Operation is blocked by access control" : "Операция не разрешена модулем контроля доступа",
@@ -163,6 +171,7 @@ OC.L10N.register(
     "No files in here" : "Здесь нет файлов",
     "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
     "Go back" : "Назад",
+    "Filter file names …" : "Фильтровать имена файлов…",
     "Views" : "Представления",
     "Files settings" : "Настройки файлов",
     "Your files" : "Ваши файлы",
@@ -183,6 +192,7 @@ OC.L10N.register(
     "Copy to clipboard" : "Копировать в буфер",
     "Use this address to access your Files via WebDAV" : "Используйте этот адрес для подключения WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Если вы включили двухфакторную аутентификацию, то нажмите здесь, чтобы создать пароль приложения.",
+    "Warnings" : "Предупреждения",
     "Keyboard shortcuts" : "Сочетания клавиш",
     "Speed up your Files experience with these quick shortcuts." : "Ускорьте работу с файлами с помощью сочетаний клавиш.",
     "Open the actions menu for a file" : "Открыть меню действий для файла",
