@@ -10,12 +10,12 @@ OC.L10N.register(
     "Removed share for group {group}" : "到群组 {group} 的共享已被移除 ",
     "{actor} shared with group {group}" : "{actor}  被共享到群组 {group}",
     "{actor} removed share for group {group}" : "{actor} 删除了群组 {group} 的共享",
-    "Share for group {group} expired" : "给分组 {group} 的共享已过期",
+    "Share for group {group} expired" : "给群组 {group} 的共享已过期",
     "You shared {file} with group {group}" : "您与群组 {group} 共享了 {file} ",
     "You removed group {group} from {file}" : "已从 {file} 移除组 {group}",
     "{actor} shared {file} with group {group}" : "{actor} 与群组 {group} 共享了 {file} ",
     "{actor} removed group {group} from {file}" : "{actor} 从 {file} 删除群组 {group} ",
-    "Share for file {file} with group {group} expired" : "与分组 {group} 的文件共享 {file} 已过期",
+    "Share for file {file} with group {group} expired" : "与群组 {group} 的文件共享 {file} 已过期",
     "Shared as public link" : "共享为公开链接",
     "Removed public link" : "移除公开链接",
     "Public link expired" : "公开链接已过期",
