@@ -32,7 +32,6 @@ OC.L10N.register(
     "{actor} changed your email address" : "{actor} ŝanĝis vian retpoŝtadreson",
     "You changed your email address" : "Vi ŝanĝis vian retpoŝtadreson",
     "Your email address was changed by an administrator" : "Administranto ŝanĝis vian retpoŝtadreson",
-    "You created app password \"{token}\"" : "Vi kreis aplikaĵan pasvorton „{token}“",
     "You deleted app password \"{token}\"" : "Vi forigis aplikaĵan pasvorton „{token}“",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Vi alinomis aplikaĵan pasvorton „{token}“ al „{newToken}“",
     "You granted filesystem access to app password \"{token}\"" : "Vi permesis aliron al dosiersistemo al aplikaĵa pasvorton „{token}“",
@@ -43,21 +42,19 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Defora forviŝado komenciĝis ĉe %1$s",
     "Remote wipe has finished on %1$s" : "Defora forviŝado finis ĉe %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Via <strong>pasvorto</strong> aŭ <strong>retpoŝtadreso</strong> estis modifita",
+    "Settings" : "Agordoj",
     "Wrong password" : "Neĝusta pasvorto",
     "Saved" : "Konservita",
-    "No user supplied" : "Neniu uzanto provizita",
     "Authentication error" : "Aŭtentiga eraro",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Bonvolu doni reekhava pasvorton de administranto; aliokaze, ĉiuj uzanto-datumoj perdiĝos.",
     "Wrong admin recovery password. Please check the password and try again." : "Neĝusta reekhava pasvorto de administranto. Bv. kontroli la pasvorton kaj reprovi.",
-    "Federated Cloud Sharing" : "Federnuba kunhavado",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL uzas neĝisdatan version %1$s (%2$s). Bv. ĝisdatigi vian operaciumon aŭ programon, aŭ trajtoj kiel %3$s ne plu funkcios fidinde.",
+    "Administrator documentation" : "Dokumentaro por administranto",
+    "User documentation" : "Dokumentaro por uzanto",
     "Invalid SMTP password." : "Nevalida SMTP-pasvorto.",
     "Email setting test" : "Provo de retpoŝtagordo",
     "Well done, %s!" : "Bonege, %s!",
     "If you received this email, the email configuration seems to be correct." : "Se vi ricevis tiun ĉi retmesaĝon, retpoŝta agordo estas ĝusta, espereble.",
     "Email could not be sent. Check your mail server log" : "Retmesaĝo ne eblis esti sendita. Kontrolu vian servil-protokolon.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Problem dum sendado de la retmesaĝo. Bv. ekzameni viajn agordojn. (Eraro: %s)",
-    "Invalid user" : "Nevalida uzanto",
     "Invalid mail address" : "Nevalida retpoŝtadreso",
     "Settings saved" : "Agordoj konservitaj",
     "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
@@ -79,140 +76,153 @@ OC.L10N.register(
     "Welcome aboard" : "Bonvenon",
     "Welcome aboard %s" : "Bonvenon %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Bonvenon ĉe via konto %s; vi povas aldoni, protekti kaj kunhavigi viajn datumojn.",
-    "Your username is: %s" : "Via uzantnomo estas: %s",
     "Set your password" : "Agordi vian pasvorton",
     "Go to %s" : "Iri al %s",
     "Install Client" : "Instali kienton",
-    "Logged in user must be a subadmin" : "La konektita uzanto estu subadministranto.",
     "Apps" : "Aplikaĵoj",
-    "Settings" : "Agordoj",
     "Personal" : "Persona",
     "Administration" : "Administrado",
+    "Users" : "Uzantoj",
     "Additional settings" : "Plia agordo",
     "Groupware" : "Grupa kunlaborado",
     "Overview" : "Superrigardo",
     "Basic settings" : "Bazaj agordoj",
     "Sharing" : "Kunhavigo",
+    "Calendar" : "Kalendaro",
     "Personal info" : "Persona informo",
     "Mobile & desktop" : "Porteblaj kaj labortablaj aplikaĵoj",
     "Email server" : "Retpoŝtoservilo",
-    "Security & setup warnings" : "Avertoj pri sekureco kaj agordoj",
     "Background jobs" : "Fonaj taskoj",
-    "Create" : "Krei",
-    "Change" : "Ŝanĝi",
-    "Delete" : "Forigi",
     "Unlimited" : "Senlima",
     "Verifying" : "Kontrolado",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankas kelkaj malnepraj kolumnoj en la datumbazo. Pro la ebla malrapideco aldoni kolumnojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-columns“, dum la servilo estas funkcianta. Kiam la kolumnoj aldoniĝos, la uzo de tiuj tabelojn estos kutime pli rapida.",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Mankas kelkaj ĉefŝlosiloj en la datumbazo. Pro la ebla malrapideco aldoni ĉefŝlosilojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-primary-keys“, dum la servilo estas funkcianta.",
+    "Disabled" : "Malkapabligita",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La PHP-funkcio „set_time_limit“ (angle „difini tempolimo“) ne disponeblas. Pro tio, skriptoj povus halti mezvoje, eble difektante vian instalaĵon. Ebligi tiun funkcion estas tre rekomendita.",
+    "Supported" : "Subtenite",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Via PHP ne subtenas la bibliotekon FreeType, kio provokos misfunkcion de profilbildo kaj de la agorda fasado.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ŝajnas ne esti taŭge agordita por informpeti sistemajn medivariablojn. La testado kun getenv(\"PATH\") revenigas nur malplenan respondon.",
+    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La nurlega agordodosiero estis ebligita. Tio baras modifon de kelkaj agordoj per la reta fasado. Plie, la dosiero bezonos esti markita mane kiel legebla dum ĉiu ĝisdatigo.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Via datumbazo ne uzas la nivelon de izoltransakcio „READ COMMITTED“ (angle por „asertita datumlegado“). Tio povas estigi problemojn, kiam pluraj agoj ruliĝas paralele.",
     "Nextcloud settings" : "Nextcloud-agordoj",
+    "Enable" : "Ŝalti",
     "None" : "Nenio",
+    "Allow apps to use the Share API" : "Ebligi aplikaĵojn uzi la API-on pri kunhavigo",
+    "Allow resharing" : "Permesi rekunhavigon",
+    "Allow sharing with groups" : "Permesi kunhavigon kun grupoj",
+    "Restrict users to only share with users in their groups" : "Limigi uzantojn al kunhavigado kun uzantoj en iiajn grupojn",
+    "Allow public uploads" : "Permesi publikajn alŝutojn",
+    "Always ask for a password" : "Ĉiam peti pasvorton",
+    "Enforce password protection" : "Devigi pasvortan protekton ",
+    "Enforce expiration date" : "Devigi limdaton",
+    "This text will be shown on the public link upload page when the file list is hidden." : "Tiu ĉi teksto montriĝos en la publika paĝo de alŝutado, kiam la dosierlisto estas kaŝita.",
+    "Default share permissions" : "Defaŭltaj kunhavigaj permesoj",
     "Two-Factor Authentication" : "Dufaza aŭtentigo",
     "Enforce two-factor authentication" : "Devigi dufazan aŭtentigon",
     "Limit to groups" : "Limigi al grupoj",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Devigo de dufaza aŭtentigo povas ekzisti nur por certaj grupoj.",
     "Enforced groups" : "Devigataj grupoj",
     "Excluded groups" : "Nedevigataj grupoj",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Kiam grupoj estas aŭ elektitaj aŭ nedevigataj, ili sekvas la jenan logikon por decidi, ĉu uzanto estas devigata uzi dufazan aŭtentigon (2FA). Se neniu grupo estas elektita, 2FA estas devigata por ĉiuj escepte membrojn de la nedevigataj grupoj. Se uzanto estas samtempe en elektita kaj nedevigata grupo, la elektita ekprioritatas kaj 2FA estas devigata.",
     "Save changes" : "Konservi modifojn",
+    "Update to {update}" : "Ĝisdatigi al {update}",
+    "Remove" : "Forigi",
+    "Featured" : "Elstaraj",
+    "This app is supported via your current Nextcloud subscription." : "Tiu aplikaĵo estas subtenita per via nuna Nextcloud-abono.",
+    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Elstaraj aplikaĵoj estas programataj de kaj ene de la komunumo. Ili alportas kernajn trajtojn kaj ili povas tuj uziĝi.",
+    "Disable all" : "Malŝalti ĉiujn",
+    "Icon" : "Piktogramo",
+    "Name" : "Nomo",
+    "Version" : "Versio",
+    "Level" : "Nivelo",
+    "Actions" : "Agoj",
+    "Results from other categories" : "Rezultoj el aliaj kategorioj",
+    "No apps found for your version" : "Neniu aplikaĵo trovita por via versio",
+    "Loading" : "Ŝargado",
+    "Type" : "Tipo",
+    "Learn more" : "Scii pli",
+    "Confirm" : "Konfirmi",
+    "Cancel" : "Nuligi",
+    "Description" : "Priskribo",
+    "View in store" : "Vidi en butiko",
+    "Visit website" : "Viziti retejon",
+    "Admin documentation" : "Dokumentaro por administranto",
+    "Developer documentation" : "Dokumentaro por programisto",
+    "Details" : "Detaloj",
     "All" : "Ĉio",
     "Limit app usage to groups" : "Limigi aplikaĵan uzon al grupoj",
     "No results" : "Neniu rezulto",
     "Update to {version}" : "Ĝisdatigi al {version}",
-    "Remove" : "Forigi",
-    "Disable" : "Malŝalti",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas minimuman Nextcloud-version. Tio estos eraro en la estonteco.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tiu aplikaĵo ne postulas maksimuman Nextcloud-version. Tio estos eraro en la estonteco.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Tiu aplikaĵo ne instaliĝas, ĉar la jenaj dependecoj ne plenumiĝas:",
-    "View in store" : "Vidi en butiko",
-    "Visit website" : "Viziti retejon",
+    "Categories" : "Kategorioj",
+    "Resources" : "Rimedoj",
+    "Documentation" : "Dokumentaro",
     "Report a bug" : "Raporti problemon",
-    "User documentation" : "Dokumentaro por uzanto",
-    "Admin documentation" : "Dokumentaro por administranto",
-    "Developer documentation" : "Dokumentaro por programisto",
-    "This app is supported via your current Nextcloud subscription." : "Tiu aplikaĵo estas subtenita per via nuna Nextcloud-abono.",
-    "Supported" : "Subtenite",
-    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Elstaraj aplikaĵoj estas programataj de kaj ene de la komunumo. Ili alportas kernajn trajtojn kaj ili povas tuj uziĝi.",
-    "Featured" : "Elstaraj",
-    "Update to {update}" : "Ĝisdatigi al {update}",
-    "Results from other categories" : "Rezultoj el aliaj kategorioj",
-    "No apps found for your version" : "Neniu aplikaĵo trovita por via versio",
-    "Disable all" : "Malŝalti ĉiujn",
-    "Enable all" : "Ŝalti ĉiujn",
+    "Request feature" : "Peti novan funkcion",
+    "Ask questions or discuss" : "Demandi aŭ priparoli",
+    "Rate" : "Pritakso",
+    "Changelog" : "Ŝanĝoprotokolo",
+    "Google Chrome for Android" : "Google Chrome por Android",
+    "This session" : "Tiu ĉi seanco",
     "Marked for remote wipe" : "Elektita por fora forviŝado",
     "Device settings" : "Aparataj agordoj",
     "Allow filesystem access" : "Permesi aliron al dosiersistemo",
     "Rename" : "Alinomi",
     "Revoke" : "Senvalidigi",
     "Wipe device" : "Forviŝi aparaton",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Google Chrome for Android" : "Google Chrome por Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "Sinkroniga kliento — {os}",
-    "This session" : "Tiu ĉi seanco",
     "Device" : "Aparato",
     "Last activity" : "Lasta aktivaĵo",
     "Devices & sessions" : "Aparatoj kaj seancoj",
     "Web, desktop and mobile clients currently logged in to your account." : "Reta, surtabla kaj portebla klientoj nun konektitaj al via konto.",
-    "Do you really want to wipe your data from this device?" : "Ĉu vi vere volas forviŝi viajn datumojn el tiu ĉi aparato?",
-    "Confirm wipe" : "Konfirmi forviŝadon",
     "Error while creating device token" : "Eraro dum kreo de aparata ĵetono",
-    "Error while updating device token scope" : "Eraro dum ĝisdatigo de la amplekso de la aparataj ĵetonoj",
-    "Error while updating device token name" : "Eraro dum ĝisdatigo de la nomo de la aparataj ĵetonoj",
-    "Error while deleting the token" : "Eraro dum forigado de la ĵetono",
-    "Error while wiping the device with the token" : "Eraro dum forviŝado de la aparato kun la ĵetono",
     "App name" : "Aplikaĵa nomo",
     "Create new app password" : "Krei novan aplikaĵan pasvorton",
-    "Use the credentials below to configure your app or device." : "Uzu la ĉi-subajn akreditilojn por agordi vian aplikaĵon aŭ aparaton.",
-    "For security reasons this password will only be shown once." : "Pro sekurigaj kialoj, tiu ĉi pasvorto montriĝos nur unufoje.",
-    "Username" : "Uzantonomo",
-    "Password" : "Pasvorto",
-    "Done" : "Farita",
-    "Show QR code for mobile apps" : "Montri rapidrespondan (QR) kodon por porteblaj aplikaĵoj",
-    "Copied!" : "Kopiita!",
-    "Copy" : "Kopii",
     "Could not copy app password. Please copy it manually." : "Ne eblis kopii la aplikaĵan pasvorton. Bv. kopii ĝin permane.",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Por ruli iton, vi bezonas la PHP-modulon pri POSIX. Vidu la {linkstart}PHP-dokumentaron{linkend} pro pli da detaloj.",
-    "Enable" : "Ŝalti",
+    "Login" : "Ensaluti",
+    "Password" : "Pasvorto",
+    "Show QR code for mobile apps" : "Montri rapidrespondan (QR) kodon por porteblaj aplikaĵoj",
+    "Use system cron service to call the cron.php file every 5 minutes." : "Uzu la sisteman „cron“-servon por voki cron.php ĉiujn 5 minutojn.",
     "Server-side encryption" : "Ĉeservila ĉifrado",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Ĉeservila ĉifrado elbigas ĉifri ĉiujn alŝutitajn dosierojn al la servilo. Tio havas kelkajn limigojn kiel pli malbonan rendimenton, do ŝaltu tion nur se necese.",
     "Enable server-side encryption" : "Ŝalti ĉeservilan ĉifradon",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "Neniu ĉifrado-modulo ŝargita. Bv. ebligi iun ĉifrado-modulon en la aplikaĵa menuo.",
+    "Select default encryption module:" : "Elekti defaŭltan ĉifrado-modulon:",
+    "Enable encryption" : "Ŝalti ĉifradon",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Kiam ĉeservila ĉifrado estas ŝaltita, ĉiuj dosieroj alŝutitaj al la servilo ekde nun estos ĉifritaj ĉe la servilo. Malebligi ĉifradon povos esti farite poste nur se la uzata ĉifrado-modulo subtenas tion kaj ĉiuj kondiĉoj (ekz. difini restaŭran ŝlisilon) estos kunigitaj.",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Ĉifrado sola ne garantias sekurigon de la sistemo. Bv. vidi la dokumentaron por pli da informoj pri kiel funkcias la ĉifrado kaj pri subtenata scenaro.",
     "Be aware that encryption always increases the file size." : "Atentu, ke ĉifrado ĉiam pligrandigas dosierojn.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Ĉiam estas bone krei savkopiojn de viaj datumoj. Se tiuj ĉi lastaj estas ĉifritaj, certigu, ke vi savkopias ankaŭ la ĉifroŝlosilon kune kun la datumoj.",
     "This is the final warning: Do you really want to enable encryption?" : "Jen la fina averto: ĉu vi certe volas ŝalti ĉifradon?",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "Neniu ĉifrado-modulo ŝargita. Bv. ebligi iun ĉifrado-modulon en la aplikaĵa menuo.",
-    "Select default encryption module:" : "Elekti defaŭltan ĉifrado-modulon:",
+    "Submit" : "Sendi",
     "Remove group" : "Forigi grupon",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Vi tuj forigos grupon {group}. La uzantoj NE estos forigitaj.",
-    "Please confirm the group removal " : "Bv. konfirmi forigadon de la grupo",
     "Current password" : "Nuna pasvorto",
     "New password" : "Nova pasvorto",
     "Change password" : "Ŝanĝi la pasvorton",
-    "png or jpg, max. 20 MB" : "png aŭ jpg, maksimume 20 MB",
     "Picture provided by original account" : "Bildo el la origina konto",
-    "Cancel" : "Nuligi",
-    "Details" : "Detaloj",
     "You are a member of the following groups:" : "Vi estas membro el la jenaj grupoj:",
-    "Your email address" : "Via retpoŝta adreso",
     "No email address set" : "Neniu retpoŝta adreso agordita",
-    "Language" : "Lingvo",
+    "Languages" : "Lingvoj",
     "Help translate" : "Helpu traduki",
     "No language set" : "Neniu lingvo agordita",
-    "Locale" : "Lokaĵaro",
     "Your phone number" : "Via telefonnumero",
     "Add" : "Aldoni",
-    "You do not have permissions to see the details of this user" : "Vi ne rajtas vidi detalojn pri tiu ĉu uzanto",
-    "Set user as admin for" : "Agordi uzanton kiel administranto por",
-    "Select user quota" : "Elekti uzant-kvoton",
-    "Delete user" : "Forigi uzanton",
-    "Wipe all devices" : "Forviŝi ĉiujn aparaton",
-    "Disable user" : "Malebligi uzanton",
-    "Enable user" : "Ebligi uzanton",
+    "Create" : "Krei",
+    "Change" : "Ŝanĝi",
+    "Delete" : "Forigi",
+    "Default language" : "Defaŭlta lingvo",
+    "Common languages" : "Ordinaraj lingvoj",
+    "Password change is disabled because the master key is disabled" : "Pasvorta ŝanĝo ne eblas, ĉar la ĉefa ŝlosilo estas neebligita",
+    "Display name" : "Vidiga nomo",
+    "Email" : "Retpoŝtadreso",
+    "Quota" : "Kvoto",
+    "Language" : "Lingvo",
+    "Avatar" : "Avataro",
+    "Group admin for" : "Grupadministranto por",
+    "Storage location" : "Konserveja loko",
+    "Last login" : "Lasta ensaluto",
+    "{size} used" : "{size} uzataj",
+    "Delete account" : "Forigi konton",
     "Resend welcome email" : "Resendi bonvenan retpoŝtmesaĝon",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Okaze de perdo de aparato aŭ eliro de la organizaĵo, tio povas defore forviŝi la datumojn de Nextcloud el ĉiuj aparatoj ligitaj per {userid}. Nur funkcias, se la aparatoj estas konektitaj  al interreto.",
     "Remote wipe of devices" : "Defora forviŝado de aparatoj",
@@ -221,41 +231,16 @@ OC.L10N.register(
     "Account deletion" : "Forigo de konto",
     "Delete {userid}'s account" : "Forigi konton de {userid}",
     "Welcome mail sent!" : "Bonvena retpoŝtmesaĝo sendita!",
-    "{size} used" : "{size} uzataj",
-    "New user" : "Nova uzanto",
-    "Will be autogenerated" : "Estos memgenerita",
-    "Display name" : "Vidiga nomo",
-    "Email" : "Retpoŝtadreso",
-    "Default language" : "Defaŭlta lingvo",
-    "Add a new user" : "Aldoni novan uzanton",
-    "Group admin for" : "Grupadministranto por",
-    "Quota" : "Kvoto",
-    "User backend" : "Uzanto-loko",
-    "Storage location" : "Konserveja loko",
-    "Last login" : "Lasta ensaluto",
-    "No users in here" : "Neniu uzanto ĉi tie",
-    "Default quota" : "Defaŭlta kvoto",
-    "Common languages" : "Ordinaraj lingvoj",
-    "Password change is disabled because the master key is disabled" : "Pasvorta ŝanĝo ne eblas, ĉar la ĉefa ŝlosilo estas neebligita",
-    "Your apps" : "Viaj aplikaĵoj",
-    "Active apps" : "Aktivaj aplikaĵoj",
-    "Disabled apps" : "Malŝaltitaj aplikaĵoj",
-    "Updates" : "Ĝisdatigoj",
-    "App bundles" : "Aplikaĵaj kuniĝoj",
-    "{license}-licensed" : "Permesilo: {license}",
-    "Changelog" : "Ŝanĝoprotokolo",
-    "Add group" : "Aldoni grupon",
-    "Active users" : "Aktivaj uzantoj",
-    "Admins" : "Administrantoj",
-    "Disabled users" : "Malebligitaj uzantoj",
-    "Default quota:" : "Defaŭlta kvoto:",
-    "Select default quota" : "Elekti defaŭltan kvoton",
-    "Show Languages" : "Montri lingvojn",
-    "Show last login" : "Montri lastan ensaluton",
-    "Show user backend" : "Montri uzantolokon",
+    "Done" : "Farita",
+    "Edit" : "Modifi",
     "Show storage path" : "Montri vojon al konservejo",
-    "Send email to new user" : "Sendi retmesaĝon al nova uzanto",
-    "Not saved" : "Ne konservita",
+    "Show last login" : "Montri lastan ensaluton",
+    "Send email" : "Sendi retpoŝtmesaĝon",
+    "Default quota" : "Defaŭlta kvoto",
+    "Select default quota" : "Elekti defaŭltan kvoton",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Kiel administranto, vi povas agordi plidetale la kunhavigon. Bv. vidi la dokumentaron pri tio.",
+    "Admins" : "Administrantoj",
+    "Group name" : "Gruponomo",
     "Sending…" : "Sendado...",
     "Email sent" : "La retpoŝtaĵo sendiĝis",
     "Location" : "Loko",
@@ -263,37 +248,45 @@ OC.L10N.register(
     "About" : "Pri",
     "Full name" : "Plena nomo",
     "Phone number" : "Telefonnumero",
-    "Twitter" : "Twitter",
     "Website" : "Retejo",
+    "Locale" : "Lokaĵaro",
+    "Your apps" : "Viaj aplikaĵoj",
+    "Active apps" : "Aktivaj aplikaĵoj",
+    "Disabled apps" : "Malŝaltitaj aplikaĵoj",
+    "Updates" : "Ĝisdatigoj",
+    "App bundles" : "Aplikaĵaj kuniĝoj",
     "Hide" : "Malmontri",
     "Download and enable" : "Elŝuti kaj ŝalti",
-    "Enable untested app" : "Ŝalti netestitan aplikaĵon",
+    "Disable" : "Malŝalti",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tiu aplikaĵo ne kongruas kun via Nextcloud-versio. Se vi daŭrigas, vi tamen povos instali ĝin, sed eble tiu aplikaĵo ne funkcios bone.",
+    "Unknown" : "Nekonata",
     "Never" : "Neniam",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplikaĵo estis ŝaltita, sed ĝi bezonas ĝisdatiĝi. Vi estos direktita al ĝisdatiga paĝon post 5 sekundoj.",
-    "Administrator documentation" : "Dokumentaro por administranto",
-    "Documentation" : "Dokumentaro",
+    "Do you really want to wipe your data from this device?" : "Ĉu vi vere volas forviŝi viajn datumojn el tiu ĉi aparato?",
+    "Confirm wipe" : "Konfirmi forviŝadon",
+    "Error while wiping the device with the token" : "Eraro dum forviŝado de la aparato kun la ĵetono",
+    "Error while updating device token name" : "Eraro dum ĝisdatigo de la nomo de la aparataj ĵetonoj",
+    "Error while updating device token scope" : "Eraro dum ĝisdatigo de la amplekso de la aparataj ĵetonoj",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Estis tro multaj petoj de via reto. Reprovu poste aŭ kontaktu vian administranton se tio estas eraro.",
+    "Error" : "Eraro",
     "Forum" : "Forumo",
-    "Login" : "Ensaluti",
-    "Plain" : "Plena",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
+    "Legal notice" : "Leĝa regularo",
+    "Privacy policy" : "Privateca regularo",
+    "SSL" : "SSL",
     "Open documentation" : "Malfermi la dokumentaron",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Gravas agordi tiun ĉi servilon por povi sendi retpoŝtmesaĝojn, ekz. por restarigo de pasvorto aŭ sciigoj.",
     "Send mode" : "Kiel sendi",
     "Encryption" : "Ĉifrado",
     "Sendmail mode" : "Sendmail-reĝimo",
     "From address" : "El adreso",
-    "Authentication method" : "Aŭtentiga metodo",
-    "Authentication required" : "Aŭtentiĝo nepras",
     "Server address" : "Servila adreso",
     "Port" : "Pordo",
+    "Authentication" : "Aŭtentigo",
+    "Authentication required" : "Aŭtentiĝo nepras",
     "Credentials" : "Aŭtentigiloj",
-    "SMTP Username" : "SMTP-uzantonomo",
     "SMTP Password" : "SMTP-pasvorto",
     "Save" : "Konservi",
-    "Send email" : "Sendi retpoŝtmesaĝon",
+    "Security & setup warnings" : "Avertoj pri sekureco kaj agordoj",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Gravas por sekureco kaj rapideco de via servilo, ke ĉio estu agordita bone. Por helpi vin pri tio, ni faras kelkajn aŭtomatajn testojn. Bv. vidi la dokumentaron por pli da informoj.",
     "All checks passed." : "Ĉiuj testoj sukcese trapasitaj.",
     "There are some errors regarding your setup." : "Estas kelkaj eraroj pri via instalaĵo.",
@@ -301,68 +294,17 @@ OC.L10N.register(
     "Checking for system and security issues." : "Kontrolado de problemoj pri sistemo kaj sekurigo.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Bv. zorgeme kontroli la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">manlibroj pri instalaĵo ↗</a>, kaj kontroli avertojn kaj erarojn en la <a href=\"%2$s\">protokolo</a>.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Kontrolu sekurecon de via servilo Nextcloud pere de <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nia sekureca ekzameno ↗</a>.",
-    "Version" : "Versio",
-    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Kiel administranto, vi povas agordi plidetale la kunhavigon. Bv. vidi la dokumentaron pri tio.",
-    "Allow apps to use the Share API" : "Ebligi aplikaĵojn uzi la API-on pri kunhavigo",
-    "Enforce expiration date" : "Devigi limdaton",
-    "Allow public uploads" : "Permesi publikajn alŝutojn",
-    "Always ask for a password" : "Ĉiam peti pasvorton",
-    "Enforce password protection" : "Devigi pasvortan protekton ",
-    "Set default expiration date" : "Agordi defaŭltan limdaton",
-    "Allow resharing" : "Permesi rekunhavigon",
-    "Allow sharing with groups" : "Permesi kunhavigon kun grupoj",
-    "Restrict users to only share with users in their groups" : "Limigi uzantojn al kunhavigado kun uzantoj en iiajn grupojn",
-    "Exclude groups from sharing" : "Malhelpi, ke grupoj kunhavigas",
-    "These groups will still be able to receive shares, but not to initiate them." : "Tiu ĉi grupoj povos ricevi kunhavojn, sed ne ekigi ilin.",
-    "This text will be shown on the public link upload page when the file list is hidden." : "Tiu ĉi teksto montriĝos en la publika paĝo de alŝutado, kiam la dosierlisto estas kaŝita.",
-    "Default share permissions" : "Defaŭltaj kunhavigaj permesoj",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Programita de la {communityopen}Nextcloud-komunumo{linkclose}, la {githubopen}fontkodo{linkclose} havas {licenseopen}AGPL{linkclose}-permesilon.",
     "Like our Facebook page" : "Ŝatu nian Facebook-paĝon",
-    "Follow us on Twitter" : "Sekvu nin per Twitter",
     "Follow us on Mastodon" : "Sekvu nin per Mastodon",
     "Check out our blog" : "Vizitu nian blogon",
     "Subscribe to our newsletter" : "Aboni nian retan bultenon",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tiu elkomunuma eldono de Nextcloud ne estas subtenata, kaj tuj-sciigoj ne disponeblas.",
     "Use a second factor besides your password to increase security for your account." : "Uzu duan fazon krom via pasvorto por plisekurigi vian konton.",
-    "Migration in progress. Please wait until the migration is finished" : "Transmeto faranta. Bv. atendi ĝis la fino de la transmeto.",
-    "Migration started …" : "Ektransmetado...",
-    "An error occurred while changing your language. Please reload the page and try again." : "Eraro okazis dum ŝanĝo de lingvo. Bv. reŝargi la paĝon kaj provi ree.",
-    "An error occurred while changing your locale. Please reload the page and try again." : "Eraro okazis dum ŝanĝo de lokaĵaro. Bv. reŝargi la paĝon kaj provi ree.",
-    "Select a profile picture" : "Elekti profilan bildon",
-    "Week starts on {fdow}" : "Semajno komencas je {fdow}",
-    "Couldn't remove app." : "Ne eblis forigi la aplikaĵon.",
-    "Couldn't update app." : "Ne eblis ĝisdatigi la aplikaĵon.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "Servilo ne subtenas pasvorto-ŝanĝon, tamen ĉifroŝlosilo de la uzanto estis ĝisdatigita.",
-    "You need to set your user email before being able to send test emails." : "Vi bezonas agordi vian retpoŝtadreso, antaŭ ol povi sendi provan retmesaĝon.",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Senvalido de tiu ĉi ĵetono eble malhelpos forviŝadon de via aparato, se ĝi ankoraŭ ne komencis forviŝadon.",
-    "All languages" : "Ĉiuj lingvoj",
-    "Everyone" : "Ĉiuj",
-    "An error occured during the request. Unable to proceed." : "Eraro okazis dum peto. Ne eblas plui.",
-    "Test email settings" : "Provi retpoŝtagordon",
-    "Please read carefully before activating server-side encryption: " : "Atente legu antaŭ ol ŝalti ĉeservilan ĉifradon:",
-    "Enable encryption" : "Ŝalti ĉifradon",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Vi bezonas transigi vian ĉifroŝlosilon el malnova instalaĵo (ownCloud ⩽ 8.0) al la nova. Bv. ebligi la „defaŭltan ĉifrado-modulon“ kaj ruli komandlinie „occ encryption:migrate“",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Vi bezonas transigi vian ĉifroŝlosilon el malnova instalaĵo (ownCloud ⩽ 8.0) al la nova.",
-    "Start migration" : "Komenci transigon",
-    "Last job execution ran %s. Something seems wrong." : "Lastataska plenumo ruliĝis %s. Io ŝajne misfunkciis.",
-    "Last job ran %s." : "Lasta tasko okazis %s.",
-    "Background job didn’t run yet!" : "Fona tasko ankoraŭ ne ruliĝis!",
-    "Pick background job setting" : "Elekti agordon pri fona tasko",
-    "Recommended" : "Rekomendata",
-    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php bezonas esti rulita de la sistema uzanto „%s“.",
-    "days" : "tagoj",
-    "Upload new" : "Alŝuti novan",
-    "Select from Files" : "Elekti el dosieroj",
-    "Remove image" : "Forigi bildon",
-    "Choose as profile picture" : "Elekti kiel profilan bildon",
-    "You are using <strong>%s</strong>" : "Vi uzas <strong>%s</strong>",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Vi uzas <strong>%1$s</strong> el <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "No display name set" : "Neniui vidiga nomo agordita",
-    "Address" : "Adreso",
-    "Your postal address" : "Via poŝta adreso",
-    "It can take up to 24 hours before the account is displayed as verified." : "Ĝis 24 horoj estas kelkfoje bezonataj, antaŭ ol la konto estas markita kiel kontrolita.",
-    "Link https://…" : "Ligilo https://…",
-    "Twitter handle @…" : "Twitter-kontonomo @…",
-    "Avatar" : "Avataro"
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankas kelkaj indeksoj en la datumbazo. Pro la ebla malrapideco aldoni indeksojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-indices“, dum la servilo estas funkcianta. Kiam la indeksoj ekzistos, la uzo de tiuj tabelojn estos kutime pli rapida.",
+    "New user" : "Nova uzanto",
+    "Username" : "Uzantonomo",
+    "User backend" : "Uzanto-loko",
+    "Follow us on Twitter" : "Sekvu nin per Twitter"
 },
 "nplurals=2; plural=(n != 1);");
