@@ -5,7 +5,7 @@ OC.L10N.register(
     "Only visible to people matched via phone number integration through Talk on mobile" : "เห็นได้เฉพาะคนที่จับคู่ผ่านหมายเลขโทรศัพท์มือถือผ่าน Talk บนมือถือ",
     "Local" : "ต้นทาง",
     "Only visible to people on this instance and guests" : "เห็นได้เฉพาะคนบนเซิร์ฟเวอร์นี้และผู้เยี่ยมชม",
-    "Federated" : "Federated",
+    "Federated" : "ที่ติดต่อกับภายนอก",
     "Only synchronize to trusted servers" : "ซิงโครไนซ์ไปยังเซิร์ฟเวอร์ที่เชื่อถือเท่านั้น",
     "Published" : "เผยแพร่แล้ว",
     "Verify" : "ยืนยัน",
@@ -37,152 +37,158 @@ OC.L10N.register(
     "{actor} changed your email address" : "{actor} ได้เปลี่ยนที่อยู่อีเมลของคุณ",
     "You changed your email address" : "คุณได้เปลี่ยนที่อยู่อีเมลของคุณ",
     "Your email address was changed by an administrator" : "ที่อยู่อีเมลของคุณถูกเปลี่ยนโดยผู้ดูแลระบบ",
-    "You created app password \"{token}\"" : "คุณสร้างรหัสผ่านแอป \"{token}\" แล้ว",
     "You deleted app password \"{token}\"" : "คุณลบรหัสผ่านแอป \"{token}\" แล้ว",
     "Security" : "ความปลอดภัย",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "มีการเปลี่ยนแปลง<strong>รหัสผ่าน</strong>หรือ<strong>อีเมล</strong>ของคุณ",
+    "Settings" : "การตั้งค่า",
     "Wrong password" : "รหัสผ่านไม่ถูกต้อง",
     "Saved" : "บันทึกแล้ว",
-    "No user supplied" : "ไม่ได้ระบุผู้ใช้",
     "Authentication error" : "เกิดข้อผิดพลาดในการตรวจสอบสิทธิ์",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "โปรดใส่รหัสผ่านกู้คืนของผู้ดูแลระบบ มิฉะนั้น ข้อมูลของผู้ใช้ทั้งหมดจะหายไป",
     "Wrong admin recovery password. Please check the password and try again." : "รหัสผ่านกู้คืนของผู้ดูแลระบบไม่ถูกต้อง กรุณาตรวจสอบรหัสผ่านและลองอีกครั้ง",
-    "Federated Cloud Sharing" : "แชร์กับสหพันธ์คลาวด์",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL กำลังใช้ %1$s รุ่นเก่า (%2$s) โปรดอัปเดตระบบปฏิบัติการ ไม่เช่นนั้นคุณสมบัติเช่น %3$s จะไม่สามารถทำงานอย่างมีประสิทธิภาพ",
+    "Administrator documentation" : "เอกสารประกอบสำหรับผู้ดูแลระบบ",
+    "User documentation" : "เอกสารประกอบสำหรับผู้ใช้",
     "Email setting test" : "ทดสอบการตั้งค่าอีเมล",
     "Well done, %s!" : "เยี่ยมยอด คุณ %s!",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "เกิดปัญหาขณะส่งอีเมล กรุณาแก้ไขการตั้งค่าของคุณ (ข้อผิดพลาด: %s)",
-    "Invalid user" : "ผู้ใช้ไม่ถูกต้อง",
+    "Invalid account" : "บัญชีไม่ถูกต้อง",
     "Invalid mail address" : "ที่อยู่อีเมลไม่ถูกต้อง",
     "Settings saved" : "บันทึกการตั้งค่าแล้ว",
     "Unable to change full name" : "ไม่สามารถเปลี่ยนชื่อเต็ม",
     "Your %s account was created" : "สร้างบัญชี %s ของคุณแล้ว",
     "Welcome to your %s account, you can add, protect, and share your data." : "ยินดีต้อนรับสู่บัญชี %s ของคุณ คุณสามารถเพิ่ม ป้องกัน และแชร์ข้อมูลของคุณ",
-    "Your username is: %s" : "ชื่อผู้ใช้ของคุณคือ: %s",
     "Set your password" : "ตั้งรหัสผ่านของคุณ",
     "Go to %s" : "ไปที่ %s",
     "Install Client" : "ติดตั้งไคลเอ็นต์",
     "Apps" : "แอป",
-    "Settings" : "การตั้งค่า",
     "Personal" : "ส่วนตัว",
+    "Users" : "ผู้ใช้",
+    "Additional settings" : "การตั้งค่าเพิ่มเติม",
     "Sharing" : "การแชร์",
+    "Calendar" : "ปฏิทิน",
     "Personal info" : "ข้อมูลส่วนบุคคล",
     "Email server" : "เซิร์ฟเวอร์อีเมล",
-    "Security & setup warnings" : "คำเตือนความปลอดภัยและการติดตั้ง",
-    "Create" : "สร้าง",
-    "Change" : "เปลี่ยนแปลง",
-    "Delete" : "ลบ",
     "Unlimited" : "ไม่จำกัด",
+    "Cron errors" : "การทำงานของ Cron ผิดพลาด",
+    "Cron last run" : "การทำงานของ Cron ครั้งล่าสุด",
+    "Disabled" : "ปิดใช้งาน",
+    "MySQL Unicode support" : "การซัพพอร์ต Unicode ของ MySQL",
+    "Supported" : "รองรับ",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP ของคุณไม่รองรับ FreeType ส่งผลให้รูปภาพโปรไฟล์และส่วนติดต่อการตั้งค่าไม่สมบูรณ์",
     "Nextcloud settings" : "การตั้งค่า Nextcloud",
+    "Enable" : "เปิดใช้งาน",
     "None" : "ไม่มี",
+    "Allow apps to use the Share API" : "อนุญาตให้แอปสามารถใช้ API แชร์",
+    "Allow resharing" : "อนุญาตให้แชร์ซ้ำ",
+    "Allow sharing with groups" : "อนุญาตให้แชร์กับกลุ่ม",
+    "Restrict users to only share with users in their groups" : "จำกัดให้ผู้ใช้สามารถแชร์กับผู้ใช้ในกลุ่มของพวกเขาเท่านั้น",
+    "Allow users to share via link and emails" : "อนุญาตให้ผู้ใช้สามารถแชร์ผ่านลิงก์และอีเมล",
+    "Allow public uploads" : "อนุญาตให้อัปโหลดสาธารณะ",
+    "Always ask for a password" : "ถามรหัสผ่านเสมอ",
+    "Enforce password protection" : "บังคับใช้การป้องกันรหัสผ่าน",
+    "Enforce expiration date" : "บังคับให้มีวันหมดอายุ",
+    "Set default expiration date for shares to other servers" : "ตั้งวันหมดอายุค่าเริ่มต้นสำหรับการแชร์ไปยังเซิร์ฟเวอร์อื่น",
     "Two-Factor Authentication" : "การยืนยันสองปัจจัย",
     "Save changes" : "บันทึกการเปลี่ยนแปลง",
+    "Update to {update}" : "อัปเดตเป็น {update}",
+    "Remove" : "ลบออก",
+    "Featured" : "แนะนำ",
+    "This app is supported via your current Nextcloud subscription." : "แอปนี้รองรับผ่านการเป็นสมาชิก Nextcloud ปัจจุบันของคุณ",
+    "Disable all" : "ปิดใช้งานทั้งหมด",
+    "Icon" : "ไอคอน",
+    "Name" : "ชื่อ",
+    "Version" : "รุ่น",
+    "Actions" : "การกระทำ",
+    "Results from other categories" : "ผลลัพธ์จากหมวดหมู่อื่น ๆ",
+    "No apps found for your version" : "ไม่พบแอปสำหรับรุ่นของคุณ",
+    "_%n app has an update available_::_%n apps have an update available_" : ["%n แอปมีอัปเดตใหม่"],
+    "Loading" : "กำลังโหลด",
+    "Type" : "ประเภท",
+    "Confirm" : "ยืนยัน",
+    "Cancel" : "ยกเลิก",
+    "Description" : "คำอธิบาย",
+    "View in store" : "ดูในร้านค้า",
+    "Visit website" : "เข้าสู่เว็บไซต์",
+    "Admin documentation" : "เอกสารประกอบสำหรับผู้ดูแลระบบ",
+    "Developer documentation" : "เอกสารประกอบสำหรับนักพัฒนา",
+    "Details" : "รายละเอียด",
     "All" : "ทั้งหมด",
     "Limit app usage to groups" : "จำกัดการใช้แอปสำหรับกลุ่ม",
     "No results" : "ไม่มีผลลัพธ์",
     "Update to {version}" : "อัปเดตเป็น {version}",
-    "Remove" : "ลบออก",
-    "Disable" : "ปิดใช้งาน",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นขั้นต่ำของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นสูงสุดของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "ไม่สามารถติดตั้งแอปนี้ เนื่องจากสิ่งที่พึ่งพาต่อไปนี้ยังไม่ครบ:",
-    "View in store" : "ดูในร้านค้า",
-    "Visit website" : "เข้าสู่เว็บไซต์",
+    "Categories" : "หมวดหมู่",
+    "Resources" : "ทรัพยากร",
+    "Documentation" : "เอกสารประกอบ",
     "Report a bug" : "รายงานข้อผิดพลาด",
-    "User documentation" : "เอกสารประกอบสำหรับผู้ใช้",
-    "Admin documentation" : "เอกสารประกอบสำหรับผู้ดูแลระบบ",
-    "Developer documentation" : "เอกสารประกอบสำหรับนักพัฒนา",
-    "This app is supported via your current Nextcloud subscription." : "แอปนี้รองรับผ่านการเป็นสมาชิก Nextcloud ปัจจุบันของคุณ",
-    "Supported" : "รองรับ",
-    "Featured" : "แนะนำ",
-    "Update to {update}" : "อัปเดตเป็น {update}",
-    "Results from other categories" : "ผลลัพธ์จากหมวดหมู่อื่น ๆ",
-    "No apps found for your version" : "ไม่พบแอปสำหรับรุ่นของคุณ",
-    "Disable all" : "ปิดใช้งานทั้งหมด",
-    "Enable all" : "เปิดใช้งานทั้งหมด",
-    "_%n app has an update available_::_%n apps have an update available_" : ["%n แอปมีอัปเดตใหม่"],
+    "Changelog" : "บันทึกการเปลี่ยนแปลง",
+    "Google Chrome for Android" : "Google Chrome สำหรับ Android",
+    "{productName} iOS app" : "แอป {productName} สำหรับ iOS",
+    "{productName} Android app" : "แอป {productName} สำหรับ Android",
+    "{productName} Talk for iOS" : "{productName} Talk สำหรับ iOS",
+    "{productName} Talk for Android" : "{productName} Talk สำหรับ Android",
+    "Sync client" : "ไคลเอ็นต์ซิงค์",
+    "This session" : "เซสชันนี้",
     "Marked for remote wipe" : "ระบุสำหรับการล้างระยะไกลแล้ว",
     "Device settings" : "การตั้งค่าอุปกรณ์",
     "Allow filesystem access" : "อนุญาตให้เข้าถึงระบบไฟล์",
     "Rename" : "เปลี่ยนชื่อ",
     "Revoke" : "เพิกถอน",
     "Wipe device" : "ล้างอุปกรณ์",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "Google Chrome for Android" : "Google Chrome สำหรับ Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "{productName} iOS app" : "แอป {productName} สำหรับ iOS",
-    "{productName} Android app" : "แอป {productName} สำหรับ Android",
-    "{productName} Talk for iOS" : "{productName} Talk สำหรับ iOS",
-    "{productName} Talk for Android" : "{productName} Talk สำหรับ Android",
-    "Sync client - {os}" : "ไคลเอ็นต์ซิงค์ - {os}",
-    "This session" : "เซสชันนี้",
     "Device" : "อุปกรณ์",
     "Last activity" : "กิจกรรมล่าสุด",
     "Devices & sessions" : "อุปกรณ์และเซสซัน",
     "Web, desktop and mobile clients currently logged in to your account." : "ไคลเอ็นต์เว็บ เดสก์ท็อป และมือถือที่เข้าสู่ระบบบัญชีของคุณอยู่",
-    "Do you really want to wipe your data from this device?" : "คุณแน่ใจว่าต้องการล้างข้อมูลจากอุปกรณ์นี้จริง ๆ หรือไม่?",
-    "Confirm wipe" : "ยืนยันการล้าง",
     "Error while creating device token" : "ข้อผิดพลาดขณะสร้างโทเค็นอุปกรณ์",
-    "Error while updating device token scope" : "ข้อผิดพลาดขณะอัปเดตขอบเขตโทเค็นอุปกรณ์",
-    "Error while updating device token name" : "ข้อผิดพลาดขณะอัปเดตชื่อโทเค็นอุปกรณ์",
-    "Error while deleting the token" : "ข้อผิดพลาดขณะลบโทเค็น",
-    "Error while wiping the device with the token" : "ข้อผิดพลาดขณะล้างอุปกรณ์ที่มีโทเค็น",
     "App name" : "ชื่อแอป",
     "Create new app password" : "สร้างรหัสผ่านแอปใหม่",
-    "Use the credentials below to configure your app or device." : "ใช้ข้อมูลประจำตัวด้านล่างเพื่อกำหนดค่าแอปหรืออุปกรณ์ของคุณ",
-    "For security reasons this password will only be shown once." : "เนื่องด้วยเหตุผลด้านความปลอดภัย รหัสผ่านนี้จะแสดงครั้งเดียว",
-    "Username" : "ชื่อผู้ใช้",
-    "Password" : "รหัสผ่าน",
-    "Done" : "เสร็จสิ้น",
-    "Show QR code for mobile apps" : "แสดงคิวอาร์โค้ดสำหรับแอปมือถือ",
-    "Copied!" : "คัดลอกแล้ว!",
-    "Copy" : "คัดลอก",
     "Could not copy app password. Please copy it manually." : "ไม่สามารถคัดลอกรหัสผ่านแอป โปรดคัดลอกด้วยตนเอง",
-    "Enable" : "เปิดใช้งาน",
+    "Login" : "เข้าสู่ระบบ",
+    "Password" : "รหัสผ่าน",
+    "Show QR code for mobile apps" : "แสดงคิวอาร์โค้ดสำหรับแอปมือถือ",
     "Server-side encryption" : "การเข้ารหัสฝั่งเซิร์ฟเวอร์",
     "Enable server-side encryption" : "เปิดใช้การเข้ารหัสฝั่งเซิร์ฟเวอร์",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "ไม่มีโมดูลการเข้ารหัสที่ถูกโหลด โปรดเปิดใช้งานโมดูลการเข้ารหัสในเมนูแอป",
+    "Select default encryption module:" : "เลือกโมดูลการเข้ารหัสค่าเริ่มต้น:",
+    "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "เมื่อเปิดใช้งานการเข้ารหัส ไฟล์ทั้งหมดที่อัปโหลดไปยังเซิร์ฟเวอร์จะถูกเข้ารหัสบนเซิฟเวอร์ สามารถปิดใช้งานการเข้ารหัสในภายหลังหากโมดูลการเข้ารหัสที่ใช้อยู่รองรับฟังก์ชั่นนี้ และเข้าเงื่อนไขก่อนการเปิดใช้งาน (เช่น การตั้งค่าคีย์กู้คืน) ทุกข้อแล้ว",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "การเข้ารหัสเพียงอย่างเดียวไม่สามารถการันตีความปลอดภัยของระบบ โปรดดูเอกสารประกอบสำหรับข้อมูลเพิ่มเติมเกี่ยวกับวิธีการทำงานของแอปการเข้ารหัส และรูปแบบการใช้งานที่รองรับ",
     "Be aware that encryption always increases the file size." : "โปรดทราบว่าการเข้ารหัสไฟล์จะทำให้ขนาดของไฟล์ใหญ่ขึ้นเสมอ",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "การสำรองข้อมูลของคุณเป็นประจำเป็นเรื่องที่ดีเสมอ ในกรณีของการเข้ารหัส อย่าลืมสำรองคีย์เข้ารหัสพร้อมข้อมูลของคุณด้วย",
     "This is the final warning: Do you really want to enable encryption?" : "นี่คือการเตือนครั้งสุดท้าย: คุณต้องการเปิดใช้การเข้ารหัสจริง ๆ หรือไม่?",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "ไม่มีโมดูลการเข้ารหัสที่ถูกโหลด โปรดเปิดใช้งานโมดูลการเข้ารหัสในเมนูแอป",
-    "Select default encryption module:" : "เลือกโมดูลการเข้ารหัสค่าเริ่มต้น:",
+    "Submit" : "ส่ง",
     "Remove group" : "ลบกลุ่ม",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "คุณกำลังจะลบกลุ่ม {group} ผู้ใช้ที่อยู่ในกลุ่มจะไม่ถูกลบไปด้วย",
-    "Please confirm the group removal " : "กรุณายืนยันการลบกลุ่ม",
     "Current password" : "รหัสผ่านปัจจุบัน",
     "New password" : "รหัสผ่านใหม่",
     "Change password" : "เปลี่ยนรหัสผ่าน",
-    "png or jpg, max. 20 MB" : "png หรือ jpg สูงสุดไม่เกิน 20 MB",
     "Picture provided by original account" : "ใช้รูปภาพจากบัญชีเดิม",
-    "Cancel" : "ยกเลิก",
-    "Details" : "รายละเอียด",
     "Email options" : "ตัวเลือกอีเมล",
-    "Primary email for password reset and notifications" : "อีเมลหลักสำหรับการตั้งรหัสผ่านใหม่และการแจ้งเตือน",
     "Remove primary email" : "ลบอีเมลหลักออก",
     "Delete email" : "ลบอีเมล",
-    "Your email address" : "ที่อยู่อีเมลของคุณ",
     "Additional email address {index}" : "ที่อยู่อีเมลเพิ่มเติม {index}",
+    "Primary email for password reset and notifications" : "อีเมลหลักสำหรับการตั้งรหัสผ่านใหม่และการแจ้งเตือน",
     "No email address set" : "ไม่ได้ระบุที่อยู่อีเมล",
-    "Language" : "ภาษา",
     "Help translate" : "ช่วยแปล",
     "No language set" : "ไม่ได้ตั้งภาษา",
-    "Locale" : "ตำแหน่งที่ตั้ง",
     "Add" : "เพิ่ม",
-    "You do not have permissions to see the details of this user" : "คุณไม่มีสิทธิ์ที่จะดูรายละเอียดของผู้ใช้นี้",
-    "Add new password" : "เพิ่มรหัสผ่านใหม่",
-    "Add new email address" : "เพิ่มที่อยู่อีเมลใหม่",
-    "Add user to group" : "เพิ่มผู้ใช้เข้ากลุ่ม",
-    "Set user as admin for" : "ตั้งผู้ใช้เป็นผู้ดูแลระบบสำหรับ",
-    "Select user quota" : "เลือกโควต้าผู้ใช้",
-    "Delete user" : "ลบผู้ใช้",
-    "Wipe all devices" : "ล้างอุปกรณ์ทั้งหมด",
-    "Disable user" : "ปิดใช้งานผู้ใช้",
-    "Enable user" : "เปิดใช้งานผู้ใช้",
+    "Create" : "สร้าง",
+    "Change" : "เปลี่ยนแปลง",
+    "Delete" : "ลบ",
+    "Default language" : "ภาษาค่าเริ่มต้น",
+    "Common languages" : "ภาษาที่นิยม",
+    "Password change is disabled because the master key is disabled" : "การเปลี่ยนรหัสผ่านถูกปิดการใช้งาน เนื่องจากคีย์หลักถูกปิดการใช้งาน",
+    "Display name" : "ชื่อที่แสดง",
+    "Email" : "อีเมล",
+    "Quota" : "โควต้า",
+    "Language" : "ภาษา",
+    "Avatar" : "ภาพแทนตัว",
+    "Account name" : "ชื่อบัญชี",
+    "Group admin for" : "ผู้ดูแลกลุ่มสำหรับ",
+    "Storage location" : "สถานที่จัดเก็บข้อมูล",
+    "Last login" : "เข้าสู่ระบบล่าสุด",
+    "{size} used" : "ใช้ไป {size}",
+    "Delete account" : "ลบบัญชี",
     "Resend welcome email" : "ส่งอีเมลยินดีต้อนรับซ้ำ",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "ในกรณีที่อุปกรณ์สูญหายหรือออกจากองค์กร ตัวเลือกนี้สามารถล้างข้อมูล Nextcloud จากทุกอุปกรณ์ที่เชื่อมโยงกับ {userid} จากระยะไกล การล้างข้อมูลจะทำงานเฉพาะเมื่ออุปกรณ์เชื่อมต่อกับอินเทอร์เน็ตเท่านั้น",
     "Remote wipe of devices" : "ล้างอุปกรณ์จากระยะไกล",
@@ -191,99 +197,73 @@ OC.L10N.register(
     "Account deletion" : "การลบบัญชี",
     "Delete {userid}'s account" : "ลบบัญชีของ {userid}",
     "Welcome mail sent!" : "ส่งอีเมลยินดีต้อนรับแล้ว!",
-    "Edit User" : "แก้ไขผู้ใช้",
-    "Toggle user actions menu" : "เปิด-ปิด เมนูการกระทำผู้ใช้",
-    "{size} used" : "ใช้ไป {size}",
-    "New user" : "ผู้ใช้ใหม่",
-    "Will be autogenerated" : "จะถูกสร้างขึ้นโดยอัตโนมัติ",
-    "Display name" : "ชื่อที่แสดง",
-    "Email" : "อีเมล",
-    "Default language" : "ภาษาค่าเริ่มต้น",
-    "Add a new user" : "เพิ่มผู้ใช้ใหม่",
-    "Group admin for" : "ผู้ดูแลกลุ่มสำหรับ",
-    "Quota" : "โควต้า",
-    "User backend" : "แบ็กเอนด์ของผู้ใช้",
-    "Storage location" : "สถานที่จัดเก็บข้อมูล",
-    "Last login" : "เข้าสู่ระบบล่าสุด",
-    "No users in here" : "ไม่มีผู้ใช้ที่นี่",
+    "Done" : "เสร็จสิ้น",
+    "Edit" : "แก้ไข",
+    "Show storage path" : "แสดงเส้นทางจัดเก็บข้อมูล",
+    "Show last login" : "แสดงการเข้าสู่ระบบล่าสุด",
+    "Send email" : "ส่งอีเมล",
     "Default quota" : "ค่าโควต้าเริ่มต้น",
-    "Common languages" : "ภาษาที่นิยม",
-    "Password change is disabled because the master key is disabled" : "การเปลี่ยนรหัสผ่านถูกปิดการใช้งาน เนื่องจากคีย์หลักถูกปิดการใช้งาน",
+    "Select default quota" : "เลือกค่าโควต้าเริ่มต้น",
+    "Server error while trying to complete WebAuthn device registration" : "เกิดข้อผิดพลาดเซิร์ฟเวอร์ขณะกำลังพยายามลงทะเบียนอุปกรณ์ WebAuthn ให้เสร็จสิ้น",
     "Passwordless authentication requires a secure connection." : "การรับรองความถูกต้องแบบไร้รหัสผ่านต้องใช้การเชื่อมต่อที่ปลอดภัย",
     "Add WebAuthn device" : "เพิ่มอุปกรณ์ WebAuthn",
     "Please authorize your WebAuthn device." : "โปรดอนุมัติอุปกรณ์ WebAuthn ของคุณ",
-    "Name your device" : "ตั้งชื่ออุปกรณ์ของคุณ",
     "Adding your device …" : "กำลังเพิ่มอุปกรณ์ …",
-    "Server error while trying to add WebAuthn device" : "เกิดข้อผิดพลาดเซิร์ฟเวอร์ขณะกำลังพยายามเพิ่มอุปกรณ์ WebAuthn",
-    "Server error while trying to complete WebAuthn device registration" : "เกิดข้อผิดพลาดเซิร์ฟเวอร์ขณะกำลังพยายามลงทะเบียนอุปกรณ์ WebAuthn ให้เสร็จสิ้น",
     "Unnamed device" : "อุปกรณ์ไม่มีชื่อ",
     "Passwordless Authentication" : "การรับรองความถูกต้องแบบไร้รหัสผ่าน",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "ตั้งค่าบัญชีของคุณเพื่อใช้การรับรองความถูกต้องแบบไร้รหัสผ่านตามมาตรฐาน FIDO2",
     "No devices configured." : "ไม่มีอุปกรณ์ที่กำหนดค่า",
     "The following devices are configured for your account:" : "อุปกรณ์เหล่านี้มีการกำหนดค่าสำหรับบัญชีของคุณแล้ว:",
     "Your browser does not support WebAuthn." : "เบราว์เซอร์ของคุณไม่รองรับ WebAuthn",
+    "Admins" : "ผู้ดูแลระบบ",
+    "Group name" : "ชื่อกลุ่ม",
+    "Sending…" : "กำลังส่ง....",
+    "Email sent" : "ส่งอีเมลแล้ว",
+    "Location" : "ตำแหน่ง",
+    "Profile picture" : "รูปภาพโปรไฟล์",
+    "About" : "เกี่ยวกับ",
+    "Full name" : "ชื่อเต็ม",
+    "Phone number" : "หมายเลขโทรศัพท์",
+    "Website" : "เว็บไซต์",
+    "Locale" : "ตำแหน่งที่ตั้ง",
     "Your apps" : "แอปของคุณ",
     "Active apps" : "แอปที่เปิดใช้งานอยู่",
     "Disabled apps" : "แอปที่ปิดใช้งาน",
     "Updates" : "อัปเดต",
     "App bundles" : "ชุดรวมแอป",
     "Featured apps" : "แอปแนะนำ",
-    "{license}-licensed" : "สัญญาอนุญาต {license}",
-    "Changelog" : "บันทึกการเปลี่ยนแปลง",
-    "by {author}\n{license}" : "โดย {author}\n{license}",
-    "Enter group name" : "ใส่ชื่อกลุ่ม",
-    "Add group" : "เพิ่มกลุ่ม",
-    "Active users" : "ผู้ใช้ที่ใช้งานอยู่",
-    "Admins" : "ผู้ดูแลระบบ",
-    "Disabled users" : "ผู้ใช้ที่ปิดใช้งาน",
-    "Default quota:" : "ค่าโควต้าเริ่มต้น:",
-    "Select default quota" : "เลือกค่าโควต้าเริ่มต้น",
-    "Show Languages" : "แสดงภาษา",
-    "Show last login" : "แสดงการเข้าสู่ระบบล่าสุด",
-    "Show user backend" : "แสดงแบ็กเอนด์ของผู้ใช้",
-    "Show storage path" : "แสดงเส้นทางจัดเก็บข้อมูล",
-    "Send email to new user" : "ส่งอีเมลไปยังผู้ใช้ใหม่",
-    "Not saved" : "ไม่ได้บันทึก",
-    "Sending…" : "กำลังส่ง....",
-    "Email sent" : "ส่งอีเมลแล้ว",
-    "Location" : "ตำแหน่งที่อยู่",
-    "Profile picture" : "รูปภาพโปรไฟล์",
-    "About" : "เกี่ยวกับ",
-    "Full name" : "ชื่อเต็ม",
-    "Phone number" : "หมายเลขโทรศัพท์",
-    "Twitter" : "ทวิตเตอร์",
-    "Website" : "เว็บไซต์",
     "Hide" : "ซ๋อน",
     "Download and enable" : "ดาวน์โหลดและเปิดใช้งาน",
-    "Enable untested app" : "เปิดใช้งานแอปที่ไม่ได้ทดสอบ",
+    "Disable" : "ปิดใช้งาน",
     "The app will be downloaded from the App Store" : "แอปจะถูกดาวน์โหลดจากร้านค้าแอป",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "แอปนี้ยังไม่ถูกระบุว่ารองรับกับรุ่น Nextcloud ของคุณ หากคุณดำเนินการต่อ คุณจะสามารถติดตั้งแอปได้ แต่แอปอาจไม่ทำงานอย่างที่คาดหวังไว้",
+    "Unknown" : "ไม่ทราบ",
     "Never" : "ไม่เคย",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "แอปเปิดใช้งานแล้ว แต่ต้องทำการอัปเดต คุณจะถูกนำไปยังหน้าอัปเดตใน 5 วินาที",
     "Error: This app cannot be enabled because it makes the server unstable" : "ข้อผิดพลาด: ไม่สามารถเปิดใช้งานแอปนี้เพราะทำให้เซิร์ฟเวอร์ไม่เสถียร",
-    "Administrator documentation" : "เอกสารประกอบสำหรับผู้ดูแลระบบ",
-    "Documentation" : "เอกสารประกอบ",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "แอปเปิดใช้งานแล้ว แต่ต้องทำการอัปเดต คุณจะถูกนำไปยังหน้าอัปเดตใน 5 วินาที",
+    "Do you really want to wipe your data from this device?" : "คุณแน่ใจว่าต้องการล้างข้อมูลจากอุปกรณ์นี้จริง ๆ หรือไม่?",
+    "Confirm wipe" : "ยืนยันการล้าง",
+    "Error while wiping the device with the token" : "ข้อผิดพลาดขณะล้างอุปกรณ์ที่มีโทเค็น",
+    "Error while updating device token name" : "ข้อผิดพลาดขณะอัปเดตชื่อโทเค็นอุปกรณ์",
+    "Error while updating device token scope" : "ข้อผิดพลาดขณะอัปเดตขอบเขตโทเค็นอุปกรณ์",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "มีการส่งคำขอจากเครือข่ายของคุณมากเกินไป กรุณาลองอีกครั้งในภายหลัง หรือติดต่อผู้ดูแลระบบหากเป็นข้อผิดพลาด",
+    "Error" : "ข้อผิดพลาด",
     "Forum" : "ฟอรัม",
-    "Login" : "เข้าสู่ระบบ",
-    "Plain" : "ธรรมดา",
-    "NT LAN Manager" : "ตัวจัดการ NT LAN",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
+    "SSL" : "SSL",
     "Open documentation" : "เปิดเอกสารประกอบ",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "การตั้งค่าให้เซิร์ฟเวอร์นี้ส่งอีเมลได้ เช่น อีเมลสำหรับการตั้งรหัสผ่านใหม่และการแจ้งเตือน เป็นสิ่งสำคัญ",
     "Send mode" : "โหมดการส่ง",
     "Encryption" : "การเข้ารหัส",
     "Sendmail mode" : "โหมดส่งอีเมล",
     "From address" : "จากที่อยู่",
-    "Authentication method" : "วิธีการตรวจสอบความถูกต้อง",
-    "Authentication required" : "จำเป็นต้องตรวจสอบความถูกต้อง",
     "Server address" : "ที่อยู่เซิร์ฟเวอร์",
     "Port" : "พอร์ต",
+    "Authentication" : "การตรวจสอบสิทธิ์",
+    "Authentication required" : "จำเป็นต้องตรวจสอบความถูกต้อง",
     "Credentials" : "ข้อมูลส่วนตัวสำหรับเข้าระบบ",
-    "SMTP Username" : "ชื่อผู้ใช้ SMTP",
     "SMTP Password" : "รหัสผ่าน SMTP",
     "Save" : "บันทึก",
-    "Send email" : "ส่งอีเมล",
+    "Security & setup warnings" : "คำเตือนความปลอดภัยและการติดตั้ง",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "การกำหนดค่าทุกอย่างให้ถูกต้องเป็นสิ่งสำคัญสำหรับความปลอดภัยและประสิทธิภาพของเซิร์ฟเวอร์ของคุณ เพื่อช่วยคุณในเรื่องนี้ เรากำลังทำการตรวจสอบอัตโนมัติ โปรดดูเอกสารประกอบที่ลิงก์มาสำหรับข้อมูลเพิ่มเติม",
     "All checks passed." : "ผ่านการตรวจสอบทั้งหมด",
     "There are some errors regarding your setup." : "มีข้อผิดพลาดบางอย่างเกี่ยวกับการติดตั้งของคุณ",
@@ -291,53 +271,14 @@ OC.L10N.register(
     "Checking for system and security issues." : "กำลังตรวจสอบปัญหาระบบและความปลอดภัย",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "โปรดตรวจสอบ<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">คู่มือการติดตั้ง ↗</a>ซ้ำ และตรวจสอบข้อผิดพลาดหรือคำเตือนใน<a href=\"%2$s\">บันทึก</a>",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "ตรวจสอบความปลอดภัยของ Nextcloud ของคุณผ่าน<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">การสแกนความปลอดภัยของเรา ↗</a>",
-    "Version" : "รุ่น",
-    "Allow apps to use the Share API" : "อนุญาตให้แอปสามารถใช้ API แชร์",
-    "Set default expiration date for shares" : "ตั้งวันหมดอายุค่าเริ่มต้นสำหรับการแชร์",
-    "Expire after" : "หมดอายุหลังจาก",
-    "day(s)" : "วัน",
-    "Enforce expiration date" : "บังคับให้มีวันหมดอายุ",
-    "Set default expiration date for shares to other servers" : "ตั้งวันหมดอายุค่าเริ่มต้นสำหรับการแชร์ไปยังเซิร์ฟเวอร์อื่น",
-    "Allow users to share via link and emails" : "อนุญาตให้ผู้ใช้สามารถแชร์ผ่านลิงก์และอีเมล",
-    "Allow public uploads" : "อนุญาตให้อัปโหลดสาธารณะ",
-    "Always ask for a password" : "ถามรหัสผ่านเสมอ",
-    "Enforce password protection" : "บังคับใช้การป้องกันรหัสผ่าน",
-    "Set default expiration date" : "ตั้งวันหมดอายุค่าเริ่มต้น",
-    "Exclude groups from creating link shares:" : "ยกเว้นกลุ่มจากการสร้างลิงก์แชร์:",
-    "Allow resharing" : "อนุญาตให้แชร์ซ้ำ",
-    "Allow sharing with groups" : "อนุญาตให้แชร์กับกลุ่ม",
-    "Restrict users to only share with users in their groups" : "จำกัดให้ผู้ใช้สามารถแชร์กับผู้ใช้ในกลุ่มของพวกเขาเท่านั้น",
-    "Exclude groups from sharing" : "ยกเว้นกลุ่มจากการแชร์",
-    "These groups will still be able to receive shares, but not to initiate them." : "กลุ่มนี้จะยังคงสามารถรับการแชร์ แต่ไม่สามารถสร้างแชร์ใหม่",
     "Reasons to use Nextcloud in your organization" : "เหตุผลที่ควรใช้ Nextcloud ในองค์กรของคุณ",
-    "Migration in progress. Please wait until the migration is finished" : "การโยกย้ายกำลังทำงาน กรุณารอสักครู่จนกว่าการโยกย้ายจะเสร็จสิ้น",
-    "Migration started …" : "เริ่มต้นการโยกย้าย …",
-    "An error occurred while changing your language. Please reload the page and try again." : "เกิดข้อผิดพลาดขณะเปลี่ยนภาษา กรุณาโหลดหน้าใหม่และลองอีกครั้ง",
-    "An error occurred while changing your locale. Please reload the page and try again." : "เกิดข้อผิดพลาดขณะเปลี่ยนตำแหน่งที่ตั้ง กรุณาโหลดหน้าใหม่และลองอีกครั้ง",
-    "Select a profile picture" : "เลือกรูปภาพโปรไฟล์",
-    "Week starts on {fdow}" : "เริ่มต้นสัปดาห์วัน{fdow}",
-    "Couldn't remove app." : "ไม่สามารถลบแอป",
-    "Couldn't update app." : "ไม่สามารถอัปเดตแอป",
-    "You need to set your user email before being able to send test emails." : "คุณจำเป็นต้องตั้งค่าอีเมลผู้ใช้ของคุณก่อนที่จะสามารถส่งอีเมลทดสอบ",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "การเพิกถอนโทเค็นนี้อาจทำให้ไม่สามารถล้างอุปกรณ์ของคุณได้หากการล้างยังไม่เริ่ม",
-    "Change privacy level of email" : "เปลี่ยนระดับความเป็นส่วนตัวของอีเมล",
-    "All languages" : "ทุกภาษา",
-    "Everyone" : "ทุกคน",
-    "An error occured during the request. Unable to proceed." : "เกิดข้อผิดพลาดขณะส่งคำขอ ไม่สามารถดำเนินการต่อ",
-    "Test email settings" : "ทดสอบการตั้งค่าอีเมล",
-    "Please read carefully before activating server-side encryption: " : "กรุณาอ่านอย่างละเอียดก่อนเปิดใช้การเข้ารหัสฝั่งเซิร์ฟเวอร์:",
-    "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "คุณจำเป็นต้องโอนย้ายคีย์การเข้ารหัสของคุณจากการเข้ารหัสเก่า (ownCloud <= 8.0) ไปใหม่ กรุณาเปิดใช้งาน \"โมดูลการเข้ารหัสเริ่มต้น\" และเรียกใช้ 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "คุณจำเป็นต้องโอนย้ายคีย์การเข้ารหัสของคุณจากการเข้ารหัสเก่า (ownCloud <= 8.0) ไปใหม่",
-    "Start migration" : "เริ่มการโยกย้าย",
-    "Recommended" : "แนะนำ",
-    "days" : "วัน",
-    "Upload new" : "อัปโหลดใหม่",
-    "Select from Files" : "เลือกจากไฟล์",
-    "Remove image" : "ลบรูปภาพ",
-    "Choose as profile picture" : "เลือกเป็นรูปภาพโปรไฟล์",
-    "No display name set" : "ไม่มีชื่อที่แสดง",
-    "Address" : "ที่อยู่",
-    "Avatar" : "ภาพแทนตัว"
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "รุ่นที่ออกโดยชุมชนของ Nextcloud นี้ไม่ได้รับการสนับสนุน และไม่สามารถใช้งานการแจ้งเตือนทันทีได้",
+    "Set default expiration date for shares" : "ตั้งวันหมดอายุค่าเริ่มต้นสำหรับการแชร์",
+    "New user" : "ผู้ใช้ใหม่",
+    "Username" : "ชื่อผู้ใช้",
+    "User backend" : "แบ็กเอนด์ของผู้ใช้",
+    "Add user to group" : "เพิ่มผู้ใช้เข้ากลุ่ม",
+    "Server error while trying to add WebAuthn device" : "เกิดข้อผิดพลาดเซิร์ฟเวอร์ขณะกำลังพยายามเพิ่มอุปกรณ์ WebAuthn",
+    "Name your device" : "ตั้งชื่ออุปกรณ์ของคุณ"
 },
 "nplurals=1; plural=0;");
