@@ -84,11 +84,11 @@ OC.L10N.register(
     "Password" : "Ger-tremen",
     "Log in with a device" : "Mon-tre gan un ardivink",
     "Your account is not setup for passwordless login." : "N'eo ket arventennet ho kont evit kennaskañ hep ger-tremen.",
-    "Passwordless authentication is not supported in your browser." : "Ne vez ket degemeret gant ho furcher an anaouadur hep ger-tremen.",
     "Passwordless authentication is only available over a secure connection." : "Dilesa hep ger-tremen a vez kinniget fant ur c'henstagadur sur nemetken.",
+    "Passwordless authentication is not supported in your browser." : "Ne vez ket degemeret gant ho furcher an anaouadur hep ger-tremen.",
     "Reset password" : "Cheñch ger-tremen",
-    "Couldn't send reset email. Please contact your administrator." : "N'eo ket posuple kas ar postel adober. Mar-plij, kelaouit o merour.",
     "Back to login" : "Distro d'ar c'hennask",
+    "Couldn't send reset email. Please contact your administrator." : "N'eo ket posuple kas ar postel adober. Mar-plij, kelaouit o merour.",
     "New password" : "Ger-tremen nevez",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Sifret eo ar restr. ne vo ket posupl deoc'h adtapout ho roadenno goude bezhañ cheñchet ho ger-tremenn. Ma n'oc'h ket sur petra ober, goulenit d'ho merour a raok kendec'hel. C'hoant ho peus kendec'hel ?",
     "I know what I'm doing" : "Gouzout a ran petra a ran",
@@ -116,6 +116,23 @@ OC.L10N.register(
     "Loading more results …" : "O kargañ muioc'h a zisoc'hoù ...",
     "Forgot password?" : "Ger-tremen ankouaet?",
     "Back" : "Distro",
+    "Security warning" : "Kemmenadenn surentez",
+    "Storage & database" : "Lec'h renkañ ha roadennoù-diaz",
+    "Data folder" : "Teuliat roadennoù",
+    "Install and activate additional PHP modules to choose other database types." : "Lakaat ha difraeañ molladoù PHP ouzhpenn evit dibab doare roadennoù-diaz all",
+    "For more details check out the documentation." : "Sellit ouz an dielladur evit munudoù ouzhpenn.",
+    "Performance warning" : "Diwallit ouzh mont en dro",
+    "You chose SQLite as database." : "Choazet o peus SQLite evel roadennoù-diaz.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite a zlefe beahñ implijet evit azgoulennoù bihañ ha/pe dioren. Kinniget eo kemer ur backend roadennoù-diaz all evit ar c'hendec'h.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "M'a vez implijet ar c'hliant evit ar c'hemprenañ, kinniget eo implij un dra kreñvoc'h eget SQLite",
+    "Database user" : "Roadennoù-diaz an implijourien",
+    "Database password" : "Roadennoù-diaz ar gerioù-trermen",
+    "Database name" : "Roadennoù-diaz an anvioù",
+    "Database tablespace" : "Lec'h berniañ ar roadennoù-diaz",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lakit an niverenn porzh gant an anv ostiz (skouer, localhost:5432).",
+    "Database host" : "Roadenn-diaz ostiz",
+    "Need help?" : "Sikour o po ?",
+    "See the documentation" : "Sellit ouz an dielladur",
     "Search {types} …" : "Klask {types} ...",
     "Choose" : "Dibab",
     "Copy" : "Eilañ",
@@ -148,11 +165,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Skrivit evit klask ar raktresoù dija krouet",
     "New in" : "Nevez e-bazh",
     "View changelog" : "Sellet ar changelog",
-    "Very weak password" : "Ger-tremen skanv kenan",
-    "Weak password" : "Ger-tremen skanv",
-    "So-so password" : "Ger-tremen skañvig",
-    "Good password" : "Ger-tremen mat",
-    "Strong password" : "Ger-tremen kreñv",
     "No action available" : "Oberen ebet posuple",
     "Error fetching contact actions" : "Ur fazi a zo bet en ur tapout an darempred",
     "Non-existing tag #{tag}" : "N'ez eus ket eus ar c'hlav #{tag}",
@@ -183,27 +195,6 @@ OC.L10N.register(
     "File: %s" : "Restr : %s",
     "Line: %s" : "Linenn :%s",
     "Trace" : "Trace",
-    "Security warning" : "Kemmenadenn surentez",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "O teuliad ha restroù rouadennoù a zo posuple tizhout a dalek ar roaedad, peogwir ne gerzh ket ar restr .htaccess.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Evit kaout titouroù diwar benn penaos stumman mat o servijour, sellit ouz an <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dielvadur</a> mar-plij.",
-    "Show password" : "Diskouez ar ger-tremen",
-    "Storage & database" : "Lec'h renkañ ha roadennoù-diaz",
-    "Data folder" : "Teuliat roadennoù",
-    "Configure the database" : "Stumman ar roadennoù-diaz",
-    "Only %s is available." : "%s digarg nemetken",
-    "Install and activate additional PHP modules to choose other database types." : "Lakaat ha difraeañ molladoù PHP ouzhpenn evit dibab doare roadennoù-diaz all",
-    "For more details check out the documentation." : "Sellit ouz an dielladur evit munudoù ouzhpenn.",
-    "Database password" : "Roadennoù-diaz ar gerioù-trermen",
-    "Database name" : "Roadennoù-diaz an anvioù",
-    "Database tablespace" : "Lec'h berniañ ar roadennoù-diaz",
-    "Database host" : "Roadenn-diaz ostiz",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lakit an niverenn porzh gant an anv ostiz (skouer, localhost:5432).",
-    "Performance warning" : "Diwallit ouzh mont en dro",
-    "You chose SQLite as database." : "Choazet o peus SQLite evel roadennoù-diaz.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite a zlefe beahñ implijet evit azgoulennoù bihañ ha/pe dioren. Kinniget eo kemer ur backend roadennoù-diaz all evit ar c'hendec'h.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "M'a vez implijet ar c'hliant evit ar c'hemprenañ, kinniget eo implij un dra kreñvoc'h eget SQLite",
-    "Need help?" : "Sikour o po ?",
-    "See the documentation" : "Sellit ouz an dielladur",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Seblant a ra bezhañ emaoc'h o adstaliañ Nexcloud. N'ez eus ket eus arrestr CAN_INSTALL en o teuliad config. Crouit ar restr CAN_INSTALL en teuliad config evit kendec'hel.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "N'eo ket posupl lemel CAN_INSTALL eus an teuliad config. Lamit anezhañ gan an dorn mar-plij.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ezhomp en deus ar meziant eus JavaScript evit kerzhout mat. Mar-plij, {linkstart}aotreit JavaScript{linkend} hag adkargit ar bajenn.",
@@ -253,6 +244,16 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Ar bajenn a azgreeno e unan pa vo vak an azgoulenn en dro.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kit e darempred gant anr merour reizhad ma chomm ar c'hemenadenn-mañ, pe ma ze war well dic'hortozet ",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chattañ, pellgomzadennoù video, rannañ skramm, emvodoù dre linnen, ha web brezegennoù - gant o furcherha gant o meziantoù pellgomzerioù-hezoug.",
-    "Error loading message template: {error}" : "Ur fazi zo bet pa voe karget stumm skouer ar gemenadenn : [error]"
+    "Error loading message template: {error}" : "Ur fazi zo bet pa voe karget stumm skouer ar gemenadenn : [error]",
+    "Very weak password" : "Ger-tremen skanv kenan",
+    "Weak password" : "Ger-tremen skanv",
+    "So-so password" : "Ger-tremen skañvig",
+    "Good password" : "Ger-tremen mat",
+    "Strong password" : "Ger-tremen kreñv",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "O teuliad ha restroù rouadennoù a zo posuple tizhout a dalek ar roaedad, peogwir ne gerzh ket ar restr .htaccess.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Evit kaout titouroù diwar benn penaos stumman mat o servijour, sellit ouz an <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dielvadur</a> mar-plij.",
+    "Show password" : "Diskouez ar ger-tremen",
+    "Configure the database" : "Stumman ar roadennoù-diaz",
+    "Only %s is available." : "%s digarg nemetken"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
