@@ -140,7 +140,7 @@ OC.L10N.register(
     "Logging in …" : "S'està iniciant la sessió…",
     "Log in to {productName}" : "Inici de sessió del {productName}",
     "Wrong login or password." : "Inici de sessió o contrasenya incorrectes.",
-    "This account is disabled" : "Aquest compte està desactivat",
+    "This account is disabled" : "Aquest compte està inhabilitat",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hem detectat diversos intents d'inici de sessió no vàlids des de la vostra IP. Per tant, el següent inici de sessió s'ha endarrerit fins a 30 segons.",
     "Account name or email" : "Nom del compte o adreça electrònica",
     "Account name" : "Nom de compte",
@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Inicia la sessió amb un dispositiu",
     "Login or email" : "Inicieu sessió o correu electrònic",
     "Your account is not setup for passwordless login." : "El vostre compte no està configurat per a l'inici de sessió sense contrasenya.",
-    "Browser not supported" : "El navegador no és compatible",
-    "Passwordless authentication is not supported in your browser." : "L'autenticació sense contrasenya no és compatible amb el vostre navegador.",
     "Your connection is not secure" : "La vostra connexió no és segura",
     "Passwordless authentication is only available over a secure connection." : "L'autenticació sense contrasenya només està disponible amb una connexió segura.",
+    "Browser not supported" : "El navegador no és compatible",
+    "Passwordless authentication is not supported in your browser." : "L'autenticació sense contrasenya no és compatible amb el vostre navegador.",
     "Reset password" : "Reinicialitza la contrasenya",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si aquest compte existeix, s'ha enviat un missatge de restabliment de la contrasenya a la seva adreça electrònica. Si no el rebeu, verifiqueu la vostra adreça de correu electrònic i/o inici de sessió, comproveu les vostres carpetes de correu brossa o demaneu ajuda a l'administració local.",
+    "Back to login" : "Torna a l'inici de sessió",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si aquest compte existeix, s'ha enviat un missatge de restabliment de la contrasenya a la seva adreça de correu electrònic. Si no el rebeu, verifiqueu la vostra adreça de correu electrònic i/o inici de sessió, comproveu les vostres carpetes de correu brossa o demaneu ajuda a l'administració local.",
     "Couldn't send reset email. Please contact your administrator." : "No s'ha pogut reinicialitzar l'adreça electrònica. Contacteu amb l'administrador.",
     "Password cannot be changed. Please contact your administrator." : "No es pot canviar la contrasenya. Contacteu amb l'administrador.",
-    "Back to login" : "Torna a l'inici de sessió",
     "New password" : "Contrasenya nova",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Els vostres fitxers estan xifrats. No hi haurà manera de recuperar les dades quan reinicialitzeu la contrasenya. Si no sabeu el que feu, contacteu amb l'administrador abans de continuar. Segur que voleu continuar ara?",
     "I know what I'm doing" : "Sé el que faig",
@@ -170,6 +170,7 @@ OC.L10N.register(
     "Schedule work & meetings, synced with all your devices." : "Planifiqueu feina i reunions, amb sincronització entre tots els vostres dispositius.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Deseu la informació de companys i amistats en un sol lloc sense revelar-ne la informació privada.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Aplicació senzilla de correu electrònic ben integrada amb les aplicacions Fitxers, Contactes i Calendari.",
+    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Xat, videotrucades, ús compartit de pantalla, reunions en línia i conferències web – fal navegador i amb aplicacions mòbils.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documents, fulls de càlcul i presentacions col·laboratius, basats en Collabora Online.",
     "Distraction free note taking app." : "Aplicació per a prendre notes sense distraccions.",
     "Recommended apps" : "Aplicacions recomanades",
@@ -206,6 +207,42 @@ OC.L10N.register(
     "Login form is disabled." : "El formulari d'inici de sessió està inhabilitat.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulari d'inici de sessió de Nextcloud està desactivat. Utilitzeu una altra opció d'inici de sessió si està disponible o poseu-vos en contacte amb la vostra administració.",
     "More actions" : "Més accions",
+    "Password is too weak" : "La contrasenya és massa feble",
+    "Password is weak" : "La contrasenya és feble",
+    "Password is average" : "La contrasenya és mitjana",
+    "Password is strong" : "La contrasenya és segura",
+    "Password is very strong" : "La contrasenya és molt forta",
+    "Password is extremely strong" : "La contrasenya és extremadament segura",
+    "Unknown password strength" : "Força de contrasenya desconeguda",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Probablement es pugui accedir al vostre directori de dades i fitxers des d'Internet perquè el fitxer <code>.htaccess</code> no funciona.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Per obtenir informació sobre com configurar correctament el vostre servidor, {linkStart}consulteu la documentació{linkEnd}",
+    "Autoconfig file detected" : "S'ha detectat un fitxer de configuració automàtica",
+    "The setup form below is pre-filled with the values from the config file." : "El formulari de configuració següent està emplenat prèviament amb els valors del fitxer de configuració.",
+    "Security warning" : "Avís de seguretat",
+    "Create administration account" : "Crear un compte d'administració",
+    "Administration account name" : "Nom del compte d'administració",
+    "Administration account password" : "Contrasenya del compte d'administració",
+    "Storage & database" : "Emmagatzematge i base de dades",
+    "Data folder" : "Carpeta de dades",
+    "Database configuration" : "Configuració de la base de dades",
+    "Only {firstAndOnlyDatabase} is available." : "Només {firstAndOnlyDatabase} està disponible.",
+    "Install and activate additional PHP modules to choose other database types." : "Instal·leu i activeu mòduls del PHP addicionals per a seleccionar altres tipus de bases de dades.",
+    "For more details check out the documentation." : "Per a conèixer més detalls, consulteu la documentació.",
+    "Performance warning" : "Avís de rendiment",
+    "You chose SQLite as database." : "Heu triat l'SQLite com a base de dades.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "L'SQLite només s'hauria d'utilitzar per a instàncies mínimes i de desenvolupament. Per a sistemes en producció, us recomanem un rerefons de base de dades diferent.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si utilitzeu clients per a la sincronització de fitxers, no es recomana en absolut l'ús de l'SQLite.",
+    "Database user" : "Usuari de la base de dades",
+    "Database password" : "Contrasenya de la base de dades",
+    "Database name" : "Nom de la base de dades",
+    "Database tablespace" : "Espai de taula de la base de dades",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifiqueu el número de port, juntament amb el nom del servidor (per exemple, localhost:5432).",
+    "Database host" : "Servidor de la base de dades",
+    "localhost" : "localhost",
+    "Installing …" : "S'està instal·lant…",
+    "Install" : "Instal·la",
+    "Need help?" : "Necessiteu ajuda?",
+    "See the documentation" : "Consulteu la documentació",
     "{name} version {version} and above" : "{name} versió {version} i posterior",
     "This browser is not supported" : "Aquest navegador no és compatible",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "El vostre navegador no és compatible. Actualitzeu a una versió més recent o compatible.",
@@ -246,11 +283,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escriviu per a cercar projectes existents",
     "New in" : "Nou a",
     "View changelog" : "Mostra el registre de canvis",
-    "Very weak password" : "Contrasenya molt feble",
-    "Weak password" : "Contrasenya feble",
-    "So-so password" : "Contrasenya justa",
-    "Good password" : "Contrasenya bona",
-    "Strong password" : "Contrasenya forta",
     "No action available" : "No hi ha cap acció disponible",
     "Error fetching contact actions" : "S'ha produït un error en carregar les accions del contacte",
     "Close \"{dialogTitle}\" dialog" : "Tanca el quadre de diàleg «{dialogTitle}»",
@@ -262,7 +294,7 @@ OC.L10N.register(
     "Rename" : "Canvia el nom",
     "Collaborative tags" : "Etiquetes col·laboratives",
     "No tags found" : "No s'ha trobat cap etiqueta",
-    "Clipboard not available, please copy manually" : "El porta-retalls no està disponible, copieu-lo manualment:",
+    "Clipboard not available, please copy manually" : "El porta-retalls no està disponible; copieu-lo manualment",
     "Personal" : "Personal",
     "Accounts" : "Comptes",
     "Admin" : "Administració",
@@ -288,34 +320,6 @@ OC.L10N.register(
     "File: %s" : "Fitxer: %s",
     "Line: %s" : "Línia: %s",
     "Trace" : "Traça",
-    "Security warning" : "Avís de seguretat",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La carpeta de dades i els fitxers probablement són accessibles des d'Internet perquè el fitxer .htaccess no funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per a obtenir informació sobre com configurar correctament el servidor, consulteu la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentació</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Creació d'un compte d'administrador</strong>",
-    "New admin account name" : "Nou nom del compte d'administració",
-    "New admin password" : "Nova contrassenya d'administració",
-    "Show password" : "Mostra la contrasenya",
-    "Toggle password visibility" : "Canvia la visibilitat de la contrasenya",
-    "Storage & database" : "Emmagatzematge i base de dades",
-    "Data folder" : "Carpeta de dades",
-    "Configure the database" : "Configuració de la base de dades",
-    "Only %s is available." : "Només hi ha disponible %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Instal·leu i activeu mòduls del PHP addicionals per a seleccionar altres tipus de bases de dades.",
-    "For more details check out the documentation." : "Per a conèixer més detalls, consulteu la documentació.",
-    "Database account" : "Compte de base de dades",
-    "Database password" : "Contrasenya de la base de dades",
-    "Database name" : "Nom de la base de dades",
-    "Database tablespace" : "Espai de taula de la base de dades",
-    "Database host" : "Servidor de la base de dades",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifiqueu el número de port, juntament amb el nom del servidor (per exemple, localhost:5432).",
-    "Performance warning" : "Avís de rendiment",
-    "You chose SQLite as database." : "Heu triat l'SQLite com a base de dades.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "L'SQLite només s'hauria d'utilitzar per a instàncies mínimes i de desenvolupament. Per a sistemes en producció, us recomanem un rerefons de base de dades diferent.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si utilitzeu clients per a la sincronització de fitxers, no es recomana en absolut l'ús de l'SQLite.",
-    "Install" : "Instal·la",
-    "Installing …" : "S'està instal·lant…",
-    "Need help?" : "Necessiteu ajuda?",
-    "See the documentation" : "Consulteu la documentació",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sembla que intenteu reinstal·lar el Nextcloud, però falta el fitxer CAN_INSTALL en la carpeta de configuració. Creeu el fitxer CAN_INSTALL en la carpeta de configuració per a continuar.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No s'ha pogut suprimir CAN_INSTALL de la carpeta de configuració. Suprimiu-lo manualment.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aquesta aplicació requereix el JavaScript per a funcionar correctament. {linkstart}Habiliteu el JavaScript{linkend} i torneu a carregar la pàgina.",
@@ -375,8 +379,8 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Aquesta pàgina s'actualitzarà automàticament quan la instància torni a estar disponible.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacteu amb l'administrador del sistema si aquest missatge persisteix o si apareix inesperadament.",
     "Currently open" : "Oberta actualment",
-    "Login with username or email" : "Inicieu sessió amb nom d'usuari o correu electrònic",
-    "Login with username" : "Inicieu sessió amb el nom d'usuari",
+    "Login with username or email" : "Inici de sessió amb nom d'usuari o correu electrònic",
+    "Login with username" : "Inici de sessió amb el nom d'usuari",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Xat, videotrucades, pantalla compartida, reunions en línia i conferències per Internet; en el navegador i amb aplicacions mòbils.",
     "You have not added any info yet" : "Encara no heu afegit cap informació",
     "{user} has not added any info yet" : "{user} encara no ha afegit cap informació",
@@ -384,7 +388,22 @@ OC.L10N.register(
     "Edit Profile" : "Edita el perfil",
     "The headline and about sections will show up here" : "La capçalera i les seccions d'informació es mostraran aquí",
     "Error loading message template: {error}" : "S'ha produït un error en carregar la plantilla del missatge: {error}",
+    "Very weak password" : "Contrasenya molt feble",
+    "Weak password" : "Contrasenya feble",
+    "So-so password" : "Contrasenya justa",
+    "Good password" : "Contrasenya bona",
+    "Strong password" : "Contrasenya forta",
     "Profile not found" : "No s'ha trobat el perfil",
-    "The profile does not exist." : "El perfil no existeix."
+    "The profile does not exist." : "El perfil no existeix.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La carpeta de dades i els fitxers probablement són accessibles des d'Internet perquè el fitxer .htaccess no funciona.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per a obtenir informació sobre com configurar correctament el servidor, consulteu la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentació</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Creació d'un compte d'administrador</strong>",
+    "New admin account name" : "Nou nom del compte d'administració",
+    "New admin password" : "Nova contrassenya d'administració",
+    "Show password" : "Mostra la contrasenya",
+    "Toggle password visibility" : "Canvia la visibilitat de la contrasenya",
+    "Configure the database" : "Configuració de la base de dades",
+    "Only %s is available." : "Només hi ha disponible %s.",
+    "Database account" : "Compte de base de dades"
 },
 "nplurals=2; plural=(n != 1);");
