@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Log ind med en enhed",
     "Login or email" : "Log ind med e-mail",
     "Your account is not setup for passwordless login." : "Din konto er ikke opsat til kodefri login.",
-    "Browser not supported" : "Browser ikke understøttet",
-    "Passwordless authentication is not supported in your browser." : "Kodefri bekræftelse er ikke understøttet af din browser.",
     "Your connection is not secure" : "Din forbindelse er ikke sikker",
     "Passwordless authentication is only available over a secure connection." : "Kodefri bekræftelse er kun understøttet gennem en sikker forbindelse.",
+    "Browser not supported" : "Browser ikke understøttet",
+    "Passwordless authentication is not supported in your browser." : "Kodefri bekræftelse er ikke understøttet af din browser.",
     "Reset password" : "Nulstil kodeord",
+    "Back to login" : "Tilbage til log in",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Hvis denne konto eksisterer, er der sendt en besked om nulstilling af adgangskode til dens e-mailadresse. Hvis du ikke modtager det, skal du bekræfte din e-mailadresse og/eller login, tjekke dine spam-/junk-mapper eller bede din lokale administration om hjælp.",
     "Couldn't send reset email. Please contact your administrator." : "Der opstod et problem under afsending af e-mailen til nulstilling. Kontakt venligst din administrator.",
     "Password cannot be changed. Please contact your administrator." : "Adgangskoden kan ikke ændres. Kontakt venligst din administrator.",
-    "Back to login" : "Tilbage til log in",
     "New password" : "Ny adgangskode",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dine filer er krypteret. Det vil ikke være muligt at kunne genskabe din data hvis din adgangskode nulstilles. Hvis du ikke er sikker på hvad du skal gøre, så kontakt venligst din administrator før du fortsætter. Ønsker du at forsætte?",
     "I know what I'm doing" : "Jeg ved, hvad jeg har gang i",
@@ -207,6 +207,42 @@ OC.L10N.register(
     "Login form is disabled." : "Loginformularen er deaktiveret.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud-loginformularen er deaktiveret. Brug en anden login-mulighed, hvis den er tilgængelig, eller kontakt din administration.",
     "More actions" : "Flere handlinger",
+    "Password is too weak" : "Adgangskoden er for svag",
+    "Password is weak" : "Adgangskoden er svag",
+    "Password is average" : "Adgangskoden er middel",
+    "Password is strong" : "Adgangskoden er stærk",
+    "Password is very strong" : "Adgangskoden er meget stærk",
+    "Password is extremely strong" : "Adgangskoden er ekstremt stærk",
+    "Unknown password strength" : "Ukendt adgangskodestyrke",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Din datamappe og filer er formentlig tilgængelige fra internettet fordi <code>.htaccess</code> filen ikke virker.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "For information om hvordan du konfigurerer din server korrekt, {linkStart}se venligst dokumentationen{linkEnd}",
+    "Autoconfig file detected" : "Autoconfig fil detekteret",
+    "The setup form below is pre-filled with the values from the config file." : "Opsætningsformularen nedenfor er præudfyldt med værdierne fra config filen.",
+    "Security warning" : "Sikkerheds advarsel",
+    "Create administration account" : "Opret administrationkonto",
+    "Administration account name" : "Administrationskontonavn",
+    "Administration account password" : "Administrationskonto adgangskode",
+    "Storage & database" : "Lager & database",
+    "Data folder" : "Datamappe",
+    "Database configuration" : "Databaskonfiguration",
+    "Only {firstAndOnlyDatabase} is available." : "Kun {firstAndOnlyDatabase} er tilgængelig.",
+    "Install and activate additional PHP modules to choose other database types." : "Installer og aktiver yderligere PHP-moduler for at vælge andre databasetyper.",
+    "For more details check out the documentation." : "For flere oplysninger, så henvises der til dokumentationen.",
+    "Performance warning" : "Ydelses advarsel",
+    "You chose SQLite as database." : "Du valgte SQLite som database.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite bør kun bruges til minimale og udviklingsmæssige servere. Til produktion anbefaler vi en anden database backend.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Hvis du bruger klienter til fil synkronisering, frarådes brugen af SQLite på det kraftigste.",
+    "Database user" : "Databasebruger",
+    "Database password" : "Databasekodeord",
+    "Database name" : "Navn på database",
+    "Database tablespace" : "Database tabelplads",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Angiv et portnummer sammen med hostnavnet (f.eks. localhost:5432).",
+    "Database host" : "Databasehost",
+    "localhost" : "localhost",
+    "Installing …" : "Installerer...",
+    "Install" : "Installer",
+    "Need help?" : "Brug for hjælp?",
+    "See the documentation" : "Se dokumentationen",
     "{name} version {version} and above" : "{name} version {version} eller nyere",
     "This browser is not supported" : "Denne browser understøttes ikke",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Din browser understøttes ikke. Opdater venligst til en nyere version, eller vælg en anden der supporteres. ",
@@ -247,11 +283,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Skriv for at søge efter eksisterende projekter",
     "New in" : "Ny i",
     "View changelog" : "Se ændringslog",
-    "Very weak password" : "Meget svagt kodeord",
-    "Weak password" : "Svagt kodeord",
-    "So-so password" : "Jævnt kodeord",
-    "Good password" : "Godt kodeord",
-    "Strong password" : "Stærkt kodeord",
     "No action available" : "Ingen funktion tilgængelig",
     "Error fetching contact actions" : "Kunne ikke hente kontakt funktioner",
     "Close \"{dialogTitle}\" dialog" : "Luk dialogboksen \"{dialogTitle}\".",
@@ -289,34 +320,6 @@ OC.L10N.register(
     "File: %s" : "Fil: %s",
     "Line: %s" : "Linje: %s",
     "Trace" : "Sporing",
-    "Security warning" : "Sikkerheds advarsel",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Dine data mappe og filer er sandsynligvis tilgængelige fra internettet fordi .htaccess filen ikke virker.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information om, hvordan du konfigurerer din server korrekt se <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentationen</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Opret en administrator konto</strong>",
-    "New admin account name" : "Navn på ny admin konto",
-    "New admin password" : "Ny admin adgangskode",
-    "Show password" : "Vis adgangskode",
-    "Toggle password visibility" : "Skift adgangskodesynlighed",
-    "Storage & database" : "Lager & database",
-    "Data folder" : "Datamappe",
-    "Configure the database" : "Konfigurer databasen",
-    "Only %s is available." : "Kun %s er tilgængelig.",
-    "Install and activate additional PHP modules to choose other database types." : "Installer og aktiver yderligere PHP-moduler for at vælge andre databasetyper.",
-    "For more details check out the documentation." : "For flere oplysninger, så henvises der til dokumentationen.",
-    "Database account" : "Database konto",
-    "Database password" : "Databasekodeord",
-    "Database name" : "Navn på database",
-    "Database tablespace" : "Database tabelplads",
-    "Database host" : "Databasehost",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Angiv et portnummer sammen med hostnavnet (f.eks. localhost:5432).",
-    "Performance warning" : "Ydelses advarsel",
-    "You chose SQLite as database." : "Du valgte SQLite som database.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite bør kun bruges til minimale og udviklingsmæssige servere. Til produktion anbefaler vi en anden database backend.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Hvis du bruger klienter til fil synkronisering, frarådes brugen af SQLite på det kraftigste.",
-    "Install" : "Installer",
-    "Installing …" : "Installerer...",
-    "Need help?" : "Brug for hjælp?",
-    "See the documentation" : "Se dokumentationen",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Det ser ud til at du forsøger at geninstallere Nextcloud. Men filen CAN_INSTALL mangler fra din konfiguration mappe. Venligst opret filen CAN_INSTALL i din konfiguration mappe for at fortsætte.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Kunne ikke fjerne CAN_INSTALL fra konfiguration mappen. Venligst fjern denne fil manuelt.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denne applikation kræver JavaScript for at fungere korrekt. {linkstart}Slå venligst JavaScript til{linkend} og genindlæs siden.",
@@ -385,7 +388,22 @@ OC.L10N.register(
     "Edit Profile" : "Rediger profil",
     "The headline and about sections will show up here" : "Overskriften og om sektionerne vises her",
     "Error loading message template: {error}" : "Fejl ved indlæsning af besked skabelon: {error}",
+    "Very weak password" : "Meget svagt kodeord",
+    "Weak password" : "Svagt kodeord",
+    "So-so password" : "Jævnt kodeord",
+    "Good password" : "Godt kodeord",
+    "Strong password" : "Stærkt kodeord",
     "Profile not found" : "Profil ikke fundet",
-    "The profile does not exist." : "Profilen eksisterer ikke."
+    "The profile does not exist." : "Profilen eksisterer ikke.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Dine data mappe og filer er sandsynligvis tilgængelige fra internettet fordi .htaccess filen ikke virker.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information om, hvordan du konfigurerer din server korrekt se <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentationen</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Opret en administrator konto</strong>",
+    "New admin account name" : "Navn på ny admin konto",
+    "New admin password" : "Ny admin adgangskode",
+    "Show password" : "Vis adgangskode",
+    "Toggle password visibility" : "Skift adgangskodesynlighed",
+    "Configure the database" : "Konfigurer databasen",
+    "Only %s is available." : "Kun %s er tilgængelig.",
+    "Database account" : "Database konto"
 },
 "nplurals=2; plural=(n != 1);");
