@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Mit einem Gerät anmelden",
     "Login or email" : "Anmeldename oder E-Mail-Adresse",
     "Your account is not setup for passwordless login." : "Ihr Konto ist nicht für eine Anmeldung ohne Passwort eingerichtet.",
-    "Browser not supported" : "Browser wird nicht unterstützt!",
-    "Passwordless authentication is not supported in your browser." : "Anmeldung ohne Passwort wird von Ihrem Browser nicht unterstützt.",
     "Your connection is not secure" : "Ihre Verbindung ist nicht sicher",
     "Passwordless authentication is only available over a secure connection." : "Anmeldung ohne Passwort ist nur über eine sichere Verbindung möglich",
+    "Browser not supported" : "Browser wird nicht unterstützt!",
+    "Passwordless authentication is not supported in your browser." : "Anmeldung ohne Passwort wird von Ihrem Browser nicht unterstützt.",
     "Reset password" : "Passwort zurücksetzen",
+    "Back to login" : "Zurück zur Anmeldung",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Sofern dieses Konto existiert, wurde eine Nachricht zum Zurücksetzen des Passworts an die hinterlegte E-Mail-Adresse gesendet. Wenn Sie diese E-Mail nicht erhalten, überprüfen Sie Ihre E-Mail-Adresse und/oder Anmeldenamen, überprüfen Sie Ihre Spam-/Junk-Ordner oder bitten Sie Ihre lokale Administration um Hilfe.",
     "Couldn't send reset email. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht versendet werden. Bitte kontaktieren Sie Ihre Administration.",
     "Password cannot be changed. Please contact your administrator." : "Passwort kann nicht geändert werden. Bitte kontaktieren Sie Ihre Administration.",
-    "Back to login" : "Zurück zur Anmeldung",
     "New password" : "Neues Passwort",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ihre Dateien sind verschlüsselt. Es gibt keine Möglichkeit, Ihre Dateien nach dem Zurücksetzen des Passwortes wiederherzustellen. Falls Sie sich nicht sicher sind, kontaktieren Sie zunächst Ihre Administration. Möchten Sie wirklich fortfahren?",
     "I know what I'm doing" : "Ich weiß, was ich mache",
@@ -207,6 +207,42 @@ OC.L10N.register(
     "Login form is disabled." : "Das Anmeldeformular ist deaktiviert.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Das Nextcloud-Anmeldeformular ist deaktiviert. Nutzen Sie ggf. eine andere Anmeldemöglichkeit oder wenden Sie sich an Ihre Administration.",
     "More actions" : "Weitere Aktionen",
+    "Password is too weak" : "Passwort ist zu schwach",
+    "Password is weak" : "Passwort ist schwach",
+    "Password is average" : "Passwort ist durchschnittlich",
+    "Password is strong" : "Passwort ist stark",
+    "Password is very strong" : "Passwort ist sehr stark",
+    "Password is extremely strong" : "Passwort ist extrem stark",
+    "Unknown password strength" : "Unbekannte Passwortstärke",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Ihr Datenverzeichnis und Ihre Dateien sind wahrscheinlich über das Internet zugänglich, da die <code>.htaccess</code>-Datei nicht funktioniert.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Informationen zur ordnungsgemäßen Konfiguration des Servers sind {linkStart}in der Dokumentation zu finden{linkEnd}",
+    "Autoconfig file detected" : "Autoconfig-Datei erkannt",
+    "The setup form below is pre-filled with the values from the config file." : "Das folgende Einrichtungsformular ist mit den Werten aus der Konfigurationsdatei vorausgefüllt.",
+    "Security warning" : "Sicherheitswarnung",
+    "Create administration account" : "Administrationskonto erstellen",
+    "Administration account name" : "Name des Administrationskontos",
+    "Administration account password" : "Passwort des Administrationskontos",
+    "Storage & database" : "Speicher & Datenbank",
+    "Data folder" : "Datenverzeichnis",
+    "Database configuration" : "Datenbankkonfiguration",
+    "Only {firstAndOnlyDatabase} is available." : "Nur {firstAndOnlyDatabase} ist verfügbar",
+    "Install and activate additional PHP modules to choose other database types." : "Um weitere Datenbank-Typen auswählen zu können, müssen zusätzliche PHP-Module installiert und aktiviert werden.",
+    "For more details check out the documentation." : "Weitere Informationen finden Sie in der Dokumentation.",
+    "Performance warning" : "Leistungswarnung",
+    "You chose SQLite as database." : "Sie haben SQLite als Datenbanktyp ausgewählt.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sollte nur für Minimal- und Entwicklungsinstanzen gewählt werden. Für die Produktion empfehlen wir ein anderes Datenbank-Backend.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Wenn Clients für die Dateisynchronisierung verwenden werden, so wird von der Verwendung von SQLite dringend abgeraten.",
+    "Database user" : "Datenbank-Benutzer",
+    "Database password" : "Datenbank-Passwort",
+    "Database name" : "Datenbank-Name",
+    "Database tablespace" : "Datenbank-Tablespace",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bitte die Portnummer mit der Hostadresse zusammen angeben (z.B. localhost:5432)",
+    "Database host" : "Datenbank-Host",
+    "localhost" : "localhost",
+    "Installing …" : "Installiere …",
+    "Install" : "Installieren",
+    "Need help?" : "Hilfe nötig?",
+    "See the documentation" : "Schauen Sie in die Dokumentation",
     "{name} version {version} and above" : "{name} Version {version} und neuer",
     "This browser is not supported" : "Dieser Browser wird nicht unterstützt",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ihr Browser wird nicht unterstützt. Bitte aktualisieren Sie Ihren Browser auf eine neuere oder unterstützte Version.",
@@ -247,11 +283,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Tippen, um nach existierenden Projekten zu suchen",
     "New in" : "Neu in",
     "View changelog" : "Liste der Änderungen ansehen",
-    "Very weak password" : "Sehr schwaches Passwort",
-    "Weak password" : "Schwaches Passwort",
-    "So-so password" : "Passables Passwort",
-    "Good password" : "Gutes Passwort",
-    "Strong password" : "Starkes Passwort",
     "No action available" : "Keine Aktion verfügbar",
     "Error fetching contact actions" : "Fehler beim Einlesen der Kontakt-Aktionen",
     "Close \"{dialogTitle}\" dialog" : "Dialog \"{dialogTitle}\" schließen",
@@ -289,34 +320,6 @@ OC.L10N.register(
     "File: %s" : "Datei: %s",
     "Line: %s" : "Zeile: %s",
     "Trace" : "Trace",
-    "Security warning" : "Sicherheitswarnung",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ihr Datenverzeichnis und Ihre Dateien sind wahrscheinlich vom Internet aus erreichbar, weil die .htaccess-Datei nicht funktioniert.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informationen zur richtigen Einrichtung Ihres Servers können Sie der <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">Dokumentation</a> entnehmen.",
-    "<strong>Create an admin account</strong>" : "<strong>Administrationskonto anlegen</strong>",
-    "New admin account name" : "Neuer Administrationskontoname",
-    "New admin password" : "Neues Administrationskennwort",
-    "Show password" : "Passwort anzeigen",
-    "Toggle password visibility" : "Passwortsichtbarkeit umschalten",
-    "Storage & database" : "Speicher & Datenbank",
-    "Data folder" : "Datenverzeichnis",
-    "Configure the database" : "Datenbank einrichten",
-    "Only %s is available." : "Es ist nur %s verfügbar.",
-    "Install and activate additional PHP modules to choose other database types." : "Um weitere Datenbank-Typen auswählen zu können, müssen zusätzliche PHP-Module installiert und aktiviert werden.",
-    "For more details check out the documentation." : "Weitere Informationen finden Sie in der Dokumentation.",
-    "Database account" : "Datenbankkonto",
-    "Database password" : "Datenbank-Passwort",
-    "Database name" : "Datenbank-Name",
-    "Database tablespace" : "Datenbank-Tablespace",
-    "Database host" : "Datenbank-Host",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bitte die Portnummer mit der Hostadresse zusammen angeben (z.B. localhost:5432)",
-    "Performance warning" : "Leistungswarnung",
-    "You chose SQLite as database." : "Sie haben SQLite als Datenbanktyp ausgewählt.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sollte nur für Minimal- und Entwicklungsinstanzen gewählt werden. Für die Produktion empfehlen wir ein anderes Datenbank-Backend.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Wenn Clients für die Dateisynchronisierung verwenden werden, so wird von der Verwendung von SQLite dringend abgeraten.",
-    "Install" : "Installieren",
-    "Installing …" : "Installiere …",
-    "Need help?" : "Hilfe nötig?",
-    "See the documentation" : "Schauen Sie in die Dokumentation",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Es sieht so aus, als ob Sie Nextcloud erneut installieren möchten. Es fehlt jedoch die Datei CAN_INSTALL in ihrem Konfigurationsordner. Bitte erstellen Sie die Datei CAN_INSTALL im Konfigurationsordner um fortzufahren.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "CAN_INSTALL kann nicht aus dem Konfigurationsordner gelöscht werden. Bitte entfernen Sie die Datei manuell.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Diese Anwendung benötigt JavaScript zum ordnungsgemäßen Betrieb. Bitte {linkstart}aktivieren Sie JavaScript{linkend} und laden Sie die Seite neu.",
@@ -385,7 +388,22 @@ OC.L10N.register(
     "Edit Profile" : "Profil bearbeiten",
     "The headline and about sections will show up here" : "Die Überschrift und der Infobereich werden hier angezeigt",
     "Error loading message template: {error}" : "Fehler beim Laden der Nachrichtenvorlage: {error}",
+    "Very weak password" : "Sehr schwaches Passwort",
+    "Weak password" : "Schwaches Passwort",
+    "So-so password" : "Passables Passwort",
+    "Good password" : "Gutes Passwort",
+    "Strong password" : "Starkes Passwort",
     "Profile not found" : "Profil nicht gefunden",
-    "The profile does not exist." : "Das Profil existiert nicht."
+    "The profile does not exist." : "Das Profil existiert nicht.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ihr Datenverzeichnis und Ihre Dateien sind wahrscheinlich vom Internet aus erreichbar, weil die .htaccess-Datei nicht funktioniert.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informationen zur richtigen Einrichtung Ihres Servers können Sie der <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">Dokumentation</a> entnehmen.",
+    "<strong>Create an admin account</strong>" : "<strong>Administrationskonto anlegen</strong>",
+    "New admin account name" : "Neuer Administrationskontoname",
+    "New admin password" : "Neues Administrationskennwort",
+    "Show password" : "Passwort anzeigen",
+    "Toggle password visibility" : "Passwortsichtbarkeit umschalten",
+    "Configure the database" : "Datenbank einrichten",
+    "Only %s is available." : "Es ist nur %s verfügbar.",
+    "Database account" : "Datenbankkonto"
 },
 "nplurals=2; plural=(n != 1);");
