@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Iniciar sesión con dispositivo",
     "Login or email" : "Nombre de usuario o correo electrónico",
     "Your account is not setup for passwordless login." : "Tu cuenta no está configurada para iniciar de sesión sin contraseña",
-    "Browser not supported" : "Navegador no compatible",
-    "Passwordless authentication is not supported in your browser." : "La autenticación sin contraseña no está soportada en tu navegador.",
     "Your connection is not secure" : "Tu conexión no es segura",
     "Passwordless authentication is only available over a secure connection." : "La autenticación sin contraseña solo está disponible bajo una conexión segura.",
+    "Browser not supported" : "Navegador no compatible",
+    "Passwordless authentication is not supported in your browser." : "La autenticación sin contraseña no está soportada en tu navegador.",
     "Reset password" : "Restablecer contraseña",
+    "Back to login" : "Volver a la identificación",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si la cuenta existe, se ha enviado un mensaje para reestablecer la contraseña a su dirección de correo. Si no lo recibe, verifique su dirección de correo y/o su nombre de cuenta, compruebe también sus carpetas de Spam/Correo basura o solicite ayuda a su administrador.",
     "Couldn't send reset email. Please contact your administrator." : "No pudo enviarse el correo para restablecer la contraseña. Por favor, contacte con su administrador.",
     "Password cannot be changed. Please contact your administrator." : "La contraseña no puede ser cambiada. Por favor, contacte con su administrador.",
-    "Back to login" : "Volver a la identificación",
     "New password" : "Nueva contraseña",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Tus archivos están encriptados. No habrá forma de recuperar sus datos después de restablecer su contraseña. Si no está seguro de qué hacer, comuníquese con su administrador antes de continuar. ¿De verdad quieres continuar?",
     "I know what I'm doing" : "Sé lo que estoy haciendo",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "La página de inicio de sesión está deshabilitada.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulario de inicio de sesión de Nextcloud está deshabilitado. Use otro medio de inicio de sesión disponible o contacte a su administración.",
     "More actions" : "Más acciones",
+    "Security warning" : "Advertencia de seguridad",
+    "Storage & database" : "Almacenamiento y base de datos",
+    "Data folder" : "Carpeta de datos",
+    "Install and activate additional PHP modules to choose other database types." : "Instalar y activar módulos PHP adicionales para elegir otros formatos de base de datos.",
+    "For more details check out the documentation." : "Para más detalles revisar la documentación.",
+    "Performance warning" : "Advertencia de rendimiento",
+    "You chose SQLite as database." : "Has elegido SQLite como base de datos.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite solo debería usarse para instancias mínimas y de desarrollo. Para producción recomendamos un motor de bases de datos diferente.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si usas clientes para sincronizar archivos, el uso del SQLite está muy desaconsejado.",
+    "Database user" : "Usuario de la base de datos",
+    "Database password" : "Contraseña de la base de datos",
+    "Database name" : "Nombre de la base de datos",
+    "Database tablespace" : "Espacio de tablas de la base de datos",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifique el numero del puerto junto al nombre del host (p.e., localhost:5432).",
+    "Database host" : "Host de la base de datos",
+    "Installing …" : "Instalando …",
+    "Install" : "Instalar",
+    "Need help?" : "¿Necesita ayuda?",
+    "See the documentation" : "Vea la documentación",
     "{name} version {version} and above" : "{name} versión {version} y superior",
     "This browser is not supported" : "Este navegador no está soportado",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navegador no está soportado. Por favor actualice a una versión nueva o a uno soportado.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escribe para buscar proyectos existentes",
     "New in" : "Nuevo en",
     "View changelog" : "Ver registro de cambios",
-    "Very weak password" : "Contraseña muy débil",
-    "Weak password" : "Contraseña débil",
-    "So-so password" : "Contraseña normal",
-    "Good password" : "Contraseña buena",
-    "Strong password" : "Contraseña muy buena",
     "No action available" : "No hay acciones disponibles",
     "Error fetching contact actions" : "Error recuperando las acciones de los contactos",
     "Close \"{dialogTitle}\" dialog" : "Cerrar diálogo \"{dialogTitle}\"",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "Archivo: %s",
     "Line: %s" : "Línea: %s",
     "Trace" : "Trazas",
-    "Security warning" : "Advertencia de seguridad",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para información sobre cómo configurar adecuadamente el servidor, revisa por favor la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
-    "<strong>Create an admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
-    "New admin account name" : "Nuevo nombre para la cuenta de administrador",
-    "New admin password" : "Nueva contraseña de administrador",
-    "Show password" : "Mostrar contraseña",
-    "Toggle password visibility" : "Alternar visibilidad de la contraseña",
-    "Storage & database" : "Almacenamiento y base de datos",
-    "Data folder" : "Carpeta de datos",
-    "Configure the database" : "Configurar la base de datos",
-    "Only %s is available." : "Solo %s está disponible.",
-    "Install and activate additional PHP modules to choose other database types." : "Instalar y activar módulos PHP adicionales para elegir otros formatos de base de datos.",
-    "For more details check out the documentation." : "Para más detalles revisar la documentación.",
-    "Database account" : "Cuenta de la base de datos",
-    "Database password" : "Contraseña de la base de datos",
-    "Database name" : "Nombre de la base de datos",
-    "Database tablespace" : "Espacio de tablas de la base de datos",
-    "Database host" : "Host de la base de datos",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifique el numero del puerto junto al nombre del host (p.e., localhost:5432).",
-    "Performance warning" : "Advertencia de rendimiento",
-    "You chose SQLite as database." : "Has elegido SQLite como base de datos.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite solo debería usarse para instancias mínimas y de desarrollo. Para producción recomendamos un motor de bases de datos diferente.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si usas clientes para sincronizar archivos, el uso del SQLite está muy desaconsejado.",
-    "Install" : "Instalar",
-    "Installing …" : "Instalando …",
-    "Need help?" : "¿Necesita ayuda?",
-    "See the documentation" : "Vea la documentación",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Parece que estás intentando reinstalar Nextcloud. Sin embargo el archivo CAN_INSTALL no se encuentra en la carpeta config. Por favor, crea el archivo CAN_INSTALL en la carpeta config para continuar",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No se puede eliminar el archivo CAN_INSTALL de la carpeta config. Por favor, eliminalo manualmente.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere JavaScript para operar correctamente. Por favor, {linkstart}habilite JavaScript{linkend} y recargue la página.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "Editar perfil",
     "The headline and about sections will show up here" : "El título y la sección acerca de aparecerán aquí",
     "Error loading message template: {error}" : "Error al cargar plantilla del mensaje: {error}",
+    "Very weak password" : "Contraseña muy débil",
+    "Weak password" : "Contraseña débil",
+    "So-so password" : "Contraseña normal",
+    "Good password" : "Contraseña buena",
+    "Strong password" : "Contraseña muy buena",
     "Profile not found" : "Perfil no encontrado",
-    "The profile does not exist." : "El perfil no existe."
+    "The profile does not exist." : "El perfil no existe.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para información sobre cómo configurar adecuadamente el servidor, revisa por favor la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
+    "<strong>Create an admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
+    "New admin account name" : "Nuevo nombre para la cuenta de administrador",
+    "New admin password" : "Nueva contraseña de administrador",
+    "Show password" : "Mostrar contraseña",
+    "Toggle password visibility" : "Alternar visibilidad de la contraseña",
+    "Configure the database" : "Configurar la base de datos",
+    "Only %s is available." : "Solo %s está disponible.",
+    "Database account" : "Cuenta de la base de datos"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
