@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Hasi saioa gailu batekin",
     "Login or email" : "Erabiltzaile-izen edo e-posta",
     "Your account is not setup for passwordless login." : "Zure kontua ez dago pasahitzik gabeko autentifikaziorako konfiguratua.",
-    "Browser not supported" : "Ez da nabigatzailea onartzen",
-    "Passwordless authentication is not supported in your browser." : "Zure nabigatzaileak ez du pasahitzik gabeko autentifikaziorik onartzen.",
     "Your connection is not secure" : "Zure konexioa ez da segurua",
     "Passwordless authentication is only available over a secure connection." : "Pasahitzik gabeko autentifikazioa konexio seguruetan erabil daiteke soilik.",
+    "Browser not supported" : "Ez da nabigatzailea onartzen",
+    "Passwordless authentication is not supported in your browser." : "Zure nabigatzaileak ez du pasahitzik gabeko autentifikaziorik onartzen.",
     "Reset password" : "Berrezarri pasahitza",
+    "Back to login" : "Itzuli saio hasierara",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Kontu hau badago, pasahitza berrezartzeko mezua bidali da bere helbide elektronikora. Jasotzen ez baduzu, egiaztatu zure helbide elektronikoa eta/edo kontuaren izena, egiaztatu spam/zabor-karpetak edo eskatu laguntza administrazio lokalari.",
     "Couldn't send reset email. Please contact your administrator." : "Ezin izan da berrezartzeko e-posta bidali. Jarri zure administratzailearekin harremanetan.",
     "Password cannot be changed. Please contact your administrator." : "Ezin da pasahitza aldatu. Jarri harremanetan zure administratzailearekin.",
-    "Back to login" : "Itzuli saio hasierara",
     "New password" : "Pasahitz berria",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Zure fitxategiak enkriptatuta daude. Pasahitza berrezarri ondoren ezin izango dituzu zure datuak berreskuratu. Ez bazaude ziur, galdetu zure administratzaileari jarraitu aurretik. Ziur zaude jarraitu nahi duzula?",
     "I know what I'm doing" : "Badakit zertan ari naizen",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "Saioa hasteko inprimakia desgaituta dago.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud saioa hasteko inprimakia desgaituta dago. Erabili saioa hasteko beste aukera eskuragarri badago edo jarri harremanetan zure administrazioarekin.",
     "More actions" : "Ekintza gehiago",
+    "Security warning" : "Segurtasun abisua",
+    "Storage & database" : "Biltegia eta datu-basea",
+    "Data folder" : "Datuen karpeta",
+    "Install and activate additional PHP modules to choose other database types." : "Instalatu eta aktibatu PHP modulu osagarriak, beste datu-base mota batzuk aukeratzeko.",
+    "For more details check out the documentation." : "Xehetasun gehiago nahi izanez gero, begiratu dokumentazioa.",
+    "Performance warning" : "Errendimendu abisua",
+    "You chose SQLite as database." : "SQLite hautatu duzu datu-base gisa.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite garapenerako eta instantzia txikietarako soilik erabili behar litzateke. Produkziorako beste datu-base sistema bat erabiltzea gomendatzen dugu.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Fitxategiak sinkronizatzeko bezeroak erabiltzen badituzu, SQLite ez da batere gomendagarria.",
+    "Database user" : "Datu-basearen erabiltzailea",
+    "Database password" : "Datu-basearen pasahitza",
+    "Database name" : "Datu-basearen izena",
+    "Database tablespace" : "Datu-basearen taula-lekua",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zehaztu ataka, makinaren izenarekin batera (adb. localhost:5432).",
+    "Database host" : "Datu-basearen ostalaria",
+    "Installing …" : "Instalatzen ...",
+    "Install" : "Instalatu",
+    "Need help?" : "Laguntza behar duzu?",
+    "See the documentation" : "Ikusi dokumentazioa",
     "{name} version {version} and above" : "{name} {version} bertsioa eta hortik gorakoak",
     "This browser is not supported" : "Nabigatzaile hau ez da onartzen",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Zure nabigatzailea ez da onartzen. Mesedez, eguneratu bertsio berriago batera edo onartzen den batera.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Hasi idazten, dauden proiektuak bilatzeko",
     "New in" : "Berria hemen:",
     "View changelog" : "Ikusi aldaketen egunkaria",
-    "Very weak password" : "Pasahitz oso ahula",
-    "Weak password" : "Pasahitz ahula",
-    "So-so password" : "Hala moduzko pasahitza",
-    "Good password" : "Pasahitz ona",
-    "Strong password" : "Pasahitz sendoa",
     "No action available" : "Ez dago ekintzarik eskuragarri",
     "Error fetching contact actions" : "Errorea kontaktu-ekintzak eskuratzean",
     "Close \"{dialogTitle}\" dialog" : "Itxi \"{dialogTitle}\" elkarrizketa",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "Fitxategia: %s",
     "Line: %s" : "Lerroa: %s",
     "Trace" : "Aztarna",
-    "Security warning" : "Segurtasun abisua",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Zure datuen karpeta eta fitxategiak interneten bidez eskuragarri egon daitezke .htaccess fitxategia ez delako funtzionatzen ari.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Zerbitzaria behar bezala konfiguratzeari buruzko informazio gehiagorako, mesedez begira ezazu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentazioa</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Sortu administratzaile kontu bat</strong>",
-    "New admin account name" : "Administratzaile kontu berriaren izena",
-    "New admin password" : "Administratzaile pasahitz berria",
-    "Show password" : "Erakutsi pasahitza",
-    "Toggle password visibility" : "Txandakatu pasahitzaren ikusgaitasuna",
-    "Storage & database" : "Biltegia eta datu-basea",
-    "Data folder" : "Datuen karpeta",
-    "Configure the database" : "Konfiguratu datu-basea",
-    "Only %s is available." : "Soilik %s dago eskuragarri.",
-    "Install and activate additional PHP modules to choose other database types." : "Instalatu eta aktibatu PHP modulu osagarriak, beste datu-base mota batzuk aukeratzeko.",
-    "For more details check out the documentation." : "Xehetasun gehiago nahi izanez gero, begiratu dokumentazioa.",
-    "Database account" : "Datu-basearen kontua",
-    "Database password" : "Datu-basearen pasahitza",
-    "Database name" : "Datu-basearen izena",
-    "Database tablespace" : "Datu-basearen taula-lekua",
-    "Database host" : "Datu-basearen ostalaria",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zehaztu ataka, makinaren izenarekin batera (adb. localhost:5432).",
-    "Performance warning" : "Errendimendu abisua",
-    "You chose SQLite as database." : "SQLite hautatu duzu datu-base gisa.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite garapenerako eta instantzia txikietarako soilik erabili behar litzateke. Produkziorako beste datu-base sistema bat erabiltzea gomendatzen dugu.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Fitxategiak sinkronizatzeko bezeroak erabiltzen badituzu, SQLite ez da batere gomendagarria.",
-    "Install" : "Instalatu",
-    "Installing …" : "Instalatzen ...",
-    "Need help?" : "Laguntza behar duzu?",
-    "See the documentation" : "Ikusi dokumentazioa",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Badirudi zure Nextcloud berrinstalatu nahian ari zarela. Hala ere CAN_INSTALL fitxategia falta da zure config direktorioan. Mesedez sor ezazu CAN_INSTALL fitxategia zure config karpetan jarraitu ahal izateko.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ezin izan da CAN_INSTALL fitxategia config karpetatik ezabatu. Mesedez ezaba ezazu fitxategi hau eskuz.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikazio honek JavaScript eskatzen du ondo funtzionatzeko. Mesedez {linkstart}JavaScript gaitu{linkend} eta webgunea birkargatu.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "Editatu profila",
     "The headline and about sections will show up here" : "Izenburua eta 'Niri buruz' atalak hemen agertuko dira",
     "Error loading message template: {error}" : "Errorea mezu txantiloia kargatzean: {error}",
+    "Very weak password" : "Pasahitz oso ahula",
+    "Weak password" : "Pasahitz ahula",
+    "So-so password" : "Hala moduzko pasahitza",
+    "Good password" : "Pasahitz ona",
+    "Strong password" : "Pasahitz sendoa",
     "Profile not found" : "Profila ez da aurkitu",
-    "The profile does not exist." : "Profila ez da existitzen"
+    "The profile does not exist." : "Profila ez da existitzen",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Zure datuen karpeta eta fitxategiak interneten bidez eskuragarri egon daitezke .htaccess fitxategia ez delako funtzionatzen ari.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Zerbitzaria behar bezala konfiguratzeari buruzko informazio gehiagorako, mesedez begira ezazu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentazioa</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Sortu administratzaile kontu bat</strong>",
+    "New admin account name" : "Administratzaile kontu berriaren izena",
+    "New admin password" : "Administratzaile pasahitz berria",
+    "Show password" : "Erakutsi pasahitza",
+    "Toggle password visibility" : "Txandakatu pasahitzaren ikusgaitasuna",
+    "Configure the database" : "Konfiguratu datu-basea",
+    "Only %s is available." : "Soilik %s dago eskuragarri.",
+    "Database account" : "Datu-basearen kontua"
 },
 "nplurals=2; plural=(n != 1);");
