@@ -145,15 +145,15 @@ OC.L10N.register(
     "Log in with a device" : "Kirjaudu laitteella",
     "Login or email" : "Käyttäjätunnus tai sähköposti",
     "Your account is not setup for passwordless login." : "Käyttäjääsi ei ole kytketty käyttämään salasanatonta kirjautumista.",
-    "Browser not supported" : "Selain ei ole tuettu",
-    "Passwordless authentication is not supported in your browser." : "Selaimesi ei tue tunnistautumista ilman salasanaa.",
     "Your connection is not secure" : "Yhteytesi ei ole turvallinen",
     "Passwordless authentication is only available over a secure connection." : "Tunnistautuminen ilman salasanaa on mahdollista vain salattua yhteyttä käyttäessä.",
+    "Browser not supported" : "Selain ei ole tuettu",
+    "Passwordless authentication is not supported in your browser." : "Selaimesi ei tue tunnistautumista ilman salasanaa.",
     "Reset password" : "Palauta salasana",
+    "Back to login" : "Palaa kirjautumiseen",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Jos tämä tili on olemassa, sen sähköpostiosoitteeseen on lähetetty salasanan palautusviesti. Jos et saa viestiä, tarkista sähköpostiosoitteesi ja/tai kirjautumisesi, tarkista roskapostikansiot tai kysy apua paikalliselta järjestelmänvalvojalta.",
     "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
     "Password cannot be changed. Please contact your administrator." : "Salasanaa ei voi vaihtaa. Ole yhteydessä ylläpitäjään.",
-    "Back to login" : "Palaa kirjautumiseen",
     "New password" : "Uusi salasana",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Tiedostosi on salattu. Niitä ei ole mahdollista palauttaa kun salasanasi on palautettu. Jos et ole varma mitä tehdä, ota yhteyttä ylläpitäjään ennen kuin jatkat. Oletko varma, että haluat jatkaa?",
     "I know what I'm doing" : "Tiedän mitä teen",
@@ -196,6 +196,25 @@ OC.L10N.register(
     "Login form is disabled." : "Kirjautumislomake on poistettu käytöstä.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloudin kirjautumislomake on poistettu käytöstä. Käytä toista kirjautumistapaa tai ota yhteys ylläpitoon.",
     "More actions" : "Lisää toimintoja",
+    "Security warning" : "Turvallisuusvaroitus",
+    "Storage & database" : "Tallennus ja tietokanta",
+    "Data folder" : "Datakansio",
+    "Install and activate additional PHP modules to choose other database types." : "Asenna ja aktivoi erillisiä PHP-moduuleja valitaksesi muita tietokantatyyppejä.",
+    "For more details check out the documentation." : "Lue lisätiedot ohjeista.",
+    "Performance warning" : "Suorituskykyvaroitus",
+    "You chose SQLite as database." : "Valitsit SQLiten tietokannaksi.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite tulisi ottaa käyttöön vain minimaalisissa kehitysympäristöissä. Tuotantokäyttöön suosittelemme toista tietokantaratkaisua.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jos käytät asiakasohjelmia tiedostojen synkronointiin, SQLiten käyttöä ei suositella.",
+    "Database user" : "Tietokannan käyttäjä",
+    "Database password" : "Tietokannan salasana",
+    "Database name" : "Tietokannan nimi",
+    "Database tablespace" : "Tietokannan taulukkotila",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Määritä portin numero tietokantapalvelimen yhteydessä (esim. localhost:5432).",
+    "Database host" : "Tietokantapalvelin",
+    "Installing …" : "Asennetaan …",
+    "Install" : "Asenna",
+    "Need help?" : "Tarvitsetko apua?",
+    "See the documentation" : "Tutustu ohjeisiin",
     "{name} version {version} and above" : "Selaimen {name} versio {version} ja uudempi",
     "This browser is not supported" : "Tämä selain ei ole tuettu",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Selaimesi ei ole tuettu. Päivitä uudempaan versioon tai muuhun tuettuun selaimeen.",
@@ -236,11 +255,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Kirjoita etsiäksesi olemassa olevia projekteja",
     "New in" : "Uutta versiossa",
     "View changelog" : "Katso muutosloki",
-    "Very weak password" : "Erittäin heikko salasana",
-    "Weak password" : "Heikko salasana",
-    "So-so password" : "Kohtalainen salasana",
-    "Good password" : "Hyvä salasana",
-    "Strong password" : "Vahva salasana",
     "No action available" : "Toimintoa ei saatavilla",
     "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
     "Close \"{dialogTitle}\" dialog" : "Sulje \"{dialogTitle}\"-ikkuna",
@@ -278,34 +292,6 @@ OC.L10N.register(
     "File: %s" : "Tiedosto: %s",
     "Line: %s" : "Rivi: %s",
     "Trace" : "Jälki",
-    "Security warning" : "Turvallisuusvaroitus",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden nähtävissä Internetistä, koska .htaccess-tiedosto ei toimi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Lisätietoja palvelimen kunnollisista asetuksista on <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ohjeissa</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Luo ylläpitäjän tili</strong>",
-    "New admin account name" : "Uuden ylläpitäjän tilin nimi",
-    "New admin password" : "Uuden ylläpitäjän salasana",
-    "Show password" : "Näytä salasana",
-    "Toggle password visibility" : "Näytä/piilota salasana",
-    "Storage & database" : "Tallennus ja tietokanta",
-    "Data folder" : "Datakansio",
-    "Configure the database" : "Määritä tietokanta",
-    "Only %s is available." : "Vain %s on käytettävissä.",
-    "Install and activate additional PHP modules to choose other database types." : "Asenna ja aktivoi erillisiä PHP-moduuleja valitaksesi muita tietokantatyyppejä.",
-    "For more details check out the documentation." : "Lue lisätiedot ohjeista.",
-    "Database account" : "Tietokantatili",
-    "Database password" : "Tietokannan salasana",
-    "Database name" : "Tietokannan nimi",
-    "Database tablespace" : "Tietokannan taulukkotila",
-    "Database host" : "Tietokantapalvelin",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Määritä portin numero tietokantapalvelimen yhteydessä (esim. localhost:5432).",
-    "Performance warning" : "Suorituskykyvaroitus",
-    "You chose SQLite as database." : "Valitsit SQLiten tietokannaksi.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite tulisi ottaa käyttöön vain minimaalisissa kehitysympäristöissä. Tuotantokäyttöön suosittelemme toista tietokantaratkaisua.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jos käytät asiakasohjelmia tiedostojen synkronointiin, SQLiten käyttöä ei suositella.",
-    "Install" : "Asenna",
-    "Installing …" : "Asennetaan …",
-    "Need help?" : "Tarvitsetko apua?",
-    "See the documentation" : "Tutustu ohjeisiin",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Vaikuttaa siltä, että yrität Nextcloudin uudelleenasennusta. Tiedosto CAN_INSTALL puuttuu asetuskansiosta. Ole hyvä ja luo tiedosto CAN_INSTALL asetuskansioon jatkaaksesi.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Tiedostoa CAN_INSTALL ei voitu poistaa asetuskansiosta. Poista tiedosto manuaalisesti.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tämä sovellus vaatii toimiakseen JavaScript-tuen. {linkstart}Ota JavaScript käyttöön{linkend} ja päivitä sivu.",
@@ -369,7 +355,22 @@ OC.L10N.register(
     "Edit Profile" : "Muokkaa profiilia",
     "The headline and about sections will show up here" : "Otsikko ja listätieto-osiot näkyvät tässä",
     "Error loading message template: {error}" : "Virhe ladatessa viestipohjaa: {error}",
+    "Very weak password" : "Erittäin heikko salasana",
+    "Weak password" : "Heikko salasana",
+    "So-so password" : "Kohtalainen salasana",
+    "Good password" : "Hyvä salasana",
+    "Strong password" : "Vahva salasana",
     "Profile not found" : "Profiilia ei löytynyt",
-    "The profile does not exist." : "Profiilia ei ole olemassa"
+    "The profile does not exist." : "Profiilia ei ole olemassa",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datakansiosi ja tiedostosi ovat mitä luultavimmin muiden nähtävissä Internetistä, koska .htaccess-tiedosto ei toimi.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Lisätietoja palvelimen kunnollisista asetuksista on <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ohjeissa</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Luo ylläpitäjän tili</strong>",
+    "New admin account name" : "Uuden ylläpitäjän tilin nimi",
+    "New admin password" : "Uuden ylläpitäjän salasana",
+    "Show password" : "Näytä salasana",
+    "Toggle password visibility" : "Näytä/piilota salasana",
+    "Configure the database" : "Määritä tietokanta",
+    "Only %s is available." : "Vain %s on käytettävissä.",
+    "Database account" : "Tietokantatili"
 },
 "nplurals=2; plural=(n != 1);");
