@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Se connecter avec un périphérique",
     "Login or email" : "Identifiant ou e-mail",
     "Your account is not setup for passwordless login." : "Votre compte n’est pas paramétré pour une authentification sans mot de passe.",
-    "Browser not supported" : "Navigateur non compatible",
-    "Passwordless authentication is not supported in your browser." : "L’authentification sans mot de passe n’est pas supportée par votre navigateur.",
     "Your connection is not secure" : "Votre connexion n’est pas sécurisée",
     "Passwordless authentication is only available over a secure connection." : "L’authentification sans mot de passe n’est possible qu’au travers d’une connexion sécurisée.",
+    "Browser not supported" : "Navigateur non compatible",
+    "Passwordless authentication is not supported in your browser." : "L’authentification sans mot de passe n’est pas supportée par votre navigateur.",
     "Reset password" : "Réinitialiser le mot de passe",
+    "Back to login" : "Retour à la page de connexion",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si ce compte existe, un message de réinitialisation de mot de passe a été envoyé à l’adresse e-mail correspondante. Si vous ne le recevez pas, veuillez vérifier l’identifiant/adresse e-mail, vérifiez dans votre dossier d’indésirables ou demandez de l’aide à l’administrateur de cette instance.",
     "Couldn't send reset email. Please contact your administrator." : "Impossible d’envoyer l'e-mail de réinitialisation. Veuillez contacter votre administrateur.",
     "Password cannot be changed. Please contact your administrator." : "Le mot de passe ne pas être modifié. Veuillez contacter votre administrateur.",
-    "Back to login" : "Retour à la page de connexion",
     "New password" : "Nouveau mot de passe",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vos fichiers sont chiffrés. Il n’y aura aucun moyen de récupérer vos données après la réinitialisation de votre mot de passe. Si vous n’êtes pas sûr de ce que vous faîtes, veuillez contacter votre administrateur avant de continuer. Voulez-vous vraiment continuer ?",
     "I know what I'm doing" : "Je sais ce que je fais",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "Le formulaire de connexion est désactivé.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Le formulaire de connexion Nextcloud est désactivé. Utilisez une autre option de connexion si disponible ou contactez votre administration.",
     "More actions" : "Plus d'actions…",
+    "Security warning" : "Avertissement de sécurité",
+    "Storage & database" : "Stockage & base de données",
+    "Data folder" : "Répertoire des données",
+    "Install and activate additional PHP modules to choose other database types." : "Installez et activez les modules PHP additionnels adéquats pour choisir d’autres types de base de données.",
+    "For more details check out the documentation." : "Consultez la documentation pour plus de détails.",
+    "Performance warning" : "Avertissement à propos des performances",
+    "You chose SQLite as database." : "Vous avez choisi SQLite comme base de données. ",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ne devrait être utilisée que pour des instances minimales ou de développement. Pour une instance de production, nous recommandons une infrastructure de base de données différente. ",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si vous utilisez des clients de synchronisation de fichiers, l’utilisation de SQLite est fortement découragée. ",
+    "Database user" : "Utilisateur de la base de données",
+    "Database password" : "Mot de passe de la base de données",
+    "Database name" : "Nom de la base de données",
+    "Database tablespace" : "Espace de stockage de la base de données",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Veuillez spécifier le numéro du port avec le nom de l’hôte (par exemple, localhost:5432).",
+    "Database host" : "Hôte de la base de données",
+    "Installing …" : "Installation...",
+    "Install" : "Installer",
+    "Need help?" : "Besoin d’aide ?",
+    "See the documentation" : "Lire la documentation",
     "{name} version {version} and above" : "{name} version {version} et supérieure",
     "This browser is not supported" : "Ce navigateur n'est pas supporté",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Votre navigateur n'est pas pris en charge. Veuillez passer à une version plus récente ou à un navigateur supporté.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Saisissez du texte pour rechercher un projet existant",
     "New in" : "Nouveau dans",
     "View changelog" : "Voir le journal des modifications",
-    "Very weak password" : "Mot de passe très faible",
-    "Weak password" : "Mot de passe faible",
-    "So-so password" : "Mot de passe tout juste acceptable",
-    "Good password" : "Mot de passe de sécurité suffisante",
-    "Strong password" : "Mot de passe fort",
     "No action available" : "Aucune action disponible",
     "Error fetching contact actions" : "Erreur lors de la recherche d'actions de contact",
     "Close \"{dialogTitle}\" dialog" : "Fermer la boîte de dialogue « {dialogTitle} »",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "Fichier : %s",
     "Line: %s" : "Ligne : %s",
     "Trace" : "Trace",
-    "Security warning" : "Avertissement de sécurité",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Votre répertoire de données est certainement accessible depuis internet car le fichier .htaccess ne fonctionne pas.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pour les informations de configuration de votre serveur, veuillez lire la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Créer un compte administrateur</strong>",
-    "New admin account name" : "Nouveau nom de compte administrateur",
-    "New admin password" : "Nouveau mot de passe admin",
-    "Show password" : "Afficher le mot de passe",
-    "Toggle password visibility" : "Activer/Désactiver la visibilité du mot de passe",
-    "Storage & database" : "Stockage & base de données",
-    "Data folder" : "Répertoire des données",
-    "Configure the database" : "Configurer la base de données",
-    "Only %s is available." : "Seul(e) %s est disponible.",
-    "Install and activate additional PHP modules to choose other database types." : "Installez et activez les modules PHP additionnels adéquats pour choisir d’autres types de base de données.",
-    "For more details check out the documentation." : "Consultez la documentation pour plus de détails.",
-    "Database account" : "Compte de base de données",
-    "Database password" : "Mot de passe de la base de données",
-    "Database name" : "Nom de la base de données",
-    "Database tablespace" : "Espace de stockage de la base de données",
-    "Database host" : "Hôte de la base de données",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Veuillez spécifier le numéro du port avec le nom de l’hôte (par exemple, localhost:5432).",
-    "Performance warning" : "Avertissement à propos des performances",
-    "You chose SQLite as database." : "Vous avez choisi SQLite comme base de données. ",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ne devrait être utilisée que pour des instances minimales ou de développement. Pour une instance de production, nous recommandons une infrastructure de base de données différente. ",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si vous utilisez des clients de synchronisation de fichiers, l’utilisation de SQLite est fortement découragée. ",
-    "Install" : "Installer",
-    "Installing …" : "Installation...",
-    "Need help?" : "Besoin d’aide ?",
-    "See the documentation" : "Lire la documentation",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "On dirait que vous essayez de réinstaller votre Nextcloud. Toutefois, le fichier CAN_INSTALL est absent de votre répertoire de configuration. Veuillez créer le fichier CAN_INSTALL dans votre dossier de configuration pour continuer.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Impossible de supprimer CAN_INSTALL du dossier de configuration. Veuillez supprimer ce fichier manuellement.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Cette application requiert JavaScript pour fonctionner correctement. Veuillez {linkstart}activer JavaScript{linkend} et recharger la page.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "Modifier le profil",
     "The headline and about sections will show up here" : "Le titre et la section « À propos » apparaîtront ici",
     "Error loading message template: {error}" : "Erreur lors du chargement du modèle de message : {error}",
+    "Very weak password" : "Mot de passe très faible",
+    "Weak password" : "Mot de passe faible",
+    "So-so password" : "Mot de passe tout juste acceptable",
+    "Good password" : "Mot de passe de sécurité suffisante",
+    "Strong password" : "Mot de passe fort",
     "Profile not found" : "Profile introuvable",
-    "The profile does not exist." : "Le profile n'existe pas."
+    "The profile does not exist." : "Le profile n'existe pas.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Votre répertoire de données est certainement accessible depuis internet car le fichier .htaccess ne fonctionne pas.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pour les informations de configuration de votre serveur, veuillez lire la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Créer un compte administrateur</strong>",
+    "New admin account name" : "Nouveau nom de compte administrateur",
+    "New admin password" : "Nouveau mot de passe admin",
+    "Show password" : "Afficher le mot de passe",
+    "Toggle password visibility" : "Activer/Désactiver la visibilité du mot de passe",
+    "Configure the database" : "Configurer la base de données",
+    "Only %s is available." : "Seul(e) %s est disponible.",
+    "Database account" : "Compte de base de données"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
