@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Acceder cun dispositivo",
     "Login or email" : "Acceso ou correo-e",
     "Your account is not setup for passwordless login." : "A súa conta non está configurada para o acceso sen contrasinal.",
-    "Browser not supported" : "Este navegador non é compatíbel",
-    "Passwordless authentication is not supported in your browser." : "O seu navegador non admite a autenticación sen contrasinal.",
     "Your connection is not secure" : "A conexión non é segura",
     "Passwordless authentication is only available over a secure connection." : "A autenticación sen contrasinal só está dispoñíbel nunha conexión segura.",
+    "Browser not supported" : "Este navegador non é compatíbel",
+    "Passwordless authentication is not supported in your browser." : "O seu navegador non admite a autenticación sen contrasinal.",
     "Reset password" : "Restabelecer o contrasinal",
+    "Back to login" : "Volver ao acceso",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Se existe esta conta, enviouse unha mensaxe de restabelecemento do contrasinal ao seu enderezo de correo. Se non o recibe, verifique o seu enderezo de correo e/ou o acceso, consulte os seus cartafoles de correo lixo ou non desexado, ou pídalle axuda á súa administración local.",
     "Couldn't send reset email. Please contact your administrator." : "Non foi posíbel enviar o correo do restabelecemento. Póñase en contacto coa administración desta instancia.",
     "Password cannot be changed. Please contact your administrator." : "Non é posíbel cambiar o contrasinal. Póñase en contacto coa administración desta instancia.",
-    "Back to login" : "Volver ao acceso",
     "New password" : "Novo contrasinal",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Os seus ficheiros están cifrados. Non haberá maneira de recuperar os datos após o restabelecemento do contrasinal. Se non está seguro de que facer, póñase en contacto coa administración desta instancia antes de continuar. Confirma que quere continuar?",
     "I know what I'm doing" : "Sei o que estou a facer",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "O formulario de acceso está bloqueado.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulario de acceso a Nextcloud está desactivado. Use outra opción de acceso se está dispoñíbel ou póñase en contacto coa súa administración.",
     "More actions" : "Máis accións",
+    "Security warning" : "Advertencia de seguranza",
+    "Storage & database" : "Almacenamento e base de datos",
+    "Data folder" : "Cartafol de datos",
+    "Install and activate additional PHP modules to choose other database types." : "Instale e active os módulos de PHP adicionais para escoller outros tipos de bases de datos.",
+    "For more details check out the documentation." : "Para obter máis detalles revise a documentación.",
+    "Performance warning" : "Advertencia de rendemento",
+    "You chose SQLite as database." : "Escolleu SQLite como base de datos.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite só debería empregarse para instancias mínimas e de desenvolvemento. Para produción recomendámoslle que empregue unha infraestrutura de base de datos diferente.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se emprega clientes para a sincronización dos ficheiros, desaconséllase encarecidamente o uso de SQLite.",
+    "Database user" : "Usuario da base de datos",
+    "Database password" : "Contrasinal da base de datos",
+    "Database name" : "Nome da base de datos",
+    "Database tablespace" : "Táboa de espazos da base de datos",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifique o número do porto xunto co nome do anfitrión (p. ex. localhost:5432)",
+    "Database host" : "Servidor da base de datos",
+    "Installing …" : "Instalando…",
+    "Install" : "Instalar",
+    "Need help?" : "Precisa axuda?",
+    "See the documentation" : "Vexa a documentación",
     "{name} version {version} and above" : "{name} versión {version} e superior",
     "This browser is not supported" : "Este navegador non é compatíbel",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "O seu navegador non é compatíbel. Actualice a unha versión máis recente ou a unha compatíbel.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escriba para buscar proxectos existentes",
     "New in" : "Novo en",
     "View changelog" : "Ver as notas da versión",
-    "Very weak password" : "Contrasinal moi feble",
-    "Weak password" : "Contrasinal feble",
-    "So-so password" : "Contrasinal non moi aló",
-    "Good password" : "Contrasinal bo",
-    "Strong password" : "Contrasinal forte",
     "No action available" : "Non hai accións dispoñíbeis",
     "Error fetching contact actions" : "Produciuse un erro ao recuperar as accións do contacto",
     "Close \"{dialogTitle}\" dialog" : "Pechar o diálogo «{dialogTitle}».",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "Ficheiro: %s",
     "Line: %s" : "Liña: %s",
     "Trace" : "Traza",
-    "Security warning" : "Advertencia de seguranza",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "O seu directorio de datos e os ficheiros probabelmente sexan accesíbeis desde a Internet xa que o ficheiro .htaccess non está a traballar.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter información sobre como configurar o seu servidor de xeito correcto, vexa a <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Crear unha conta de administración</strong>",
-    "New admin account name" : "Nome da nova conta de administración",
-    "New admin password" : "Novo contrasinal de administración",
-    "Show password" : "Amosar o contrasinal",
-    "Toggle password visibility" : "Alternar a visibilidade do contrasinal",
-    "Storage & database" : "Almacenamento e base de datos",
-    "Data folder" : "Cartafol de datos",
-    "Configure the database" : "Configurar a base de datos",
-    "Only %s is available." : "Só está dispoñíbel %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Instale e active os módulos de PHP adicionais para escoller outros tipos de bases de datos.",
-    "For more details check out the documentation." : "Para obter máis detalles revise a documentación.",
-    "Database account" : "Conta da base de datos",
-    "Database password" : "Contrasinal da base de datos",
-    "Database name" : "Nome da base de datos",
-    "Database tablespace" : "Táboa de espazos da base de datos",
-    "Database host" : "Servidor da base de datos",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifique o número do porto xunto co nome do anfitrión (p. ex. localhost:5432)",
-    "Performance warning" : "Advertencia de rendemento",
-    "You chose SQLite as database." : "Escolleu SQLite como base de datos.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite só debería empregarse para instancias mínimas e de desenvolvemento. Para produción recomendámoslle que empregue unha infraestrutura de base de datos diferente.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se emprega clientes para a sincronización dos ficheiros, desaconséllase encarecidamente o uso de SQLite.",
-    "Install" : "Instalar",
-    "Installing …" : "Instalando…",
-    "Need help?" : "Precisa axuda?",
-    "See the documentation" : "Vexa a documentación",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Semella que está tentando reinstalar o seu Nextcloud. Non obstante o ficheiro CAN_INSTALL falta no seu directorio de configuración. Cree o ficheiro CAN_INSTALL no cartafol de configuración para continuar.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Non foi posíbel retirar CAN_INSTALL do cartafol de configuración. Retire este ficheiro manualmente.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación precisa JavaScript para un correcto funcionamento. {linkstart}Active  JavaScript{linkend} e volva cargar a páxina.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "Editar o perfil",
     "The headline and about sections will show up here" : "As seccións título e sobre aparecerán aquí",
     "Error loading message template: {error}" : "Produciuse un erro ao cargar o modelo da mensaxe: {error}",
+    "Very weak password" : "Contrasinal moi feble",
+    "Weak password" : "Contrasinal feble",
+    "So-so password" : "Contrasinal non moi aló",
+    "Good password" : "Contrasinal bo",
+    "Strong password" : "Contrasinal forte",
     "Profile not found" : "Non se atopou o perfil",
-    "The profile does not exist." : "O perfil non existe."
+    "The profile does not exist." : "O perfil non existe.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "O seu directorio de datos e os ficheiros probabelmente sexan accesíbeis desde a Internet xa que o ficheiro .htaccess non está a traballar.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter información sobre como configurar o seu servidor de xeito correcto, vexa a <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Crear unha conta de administración</strong>",
+    "New admin account name" : "Nome da nova conta de administración",
+    "New admin password" : "Novo contrasinal de administración",
+    "Show password" : "Amosar o contrasinal",
+    "Toggle password visibility" : "Alternar a visibilidade do contrasinal",
+    "Configure the database" : "Configurar a base de datos",
+    "Only %s is available." : "Só está dispoñíbel %s.",
+    "Database account" : "Conta da base de datos"
 },
 "nplurals=2; plural=(n != 1);");
