@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Accedi con un dispositivo",
     "Login or email" : "Nome utente o email",
     "Your account is not setup for passwordless login." : "Il tuo account non è configurato per l'accesso senza password.",
-    "Browser not supported" : "Browser non supportato",
-    "Passwordless authentication is not supported in your browser." : "L'autenticazione senza password non è supportata dal tuo browser. ",
     "Your connection is not secure" : "La tua connessione non è sicura",
     "Passwordless authentication is only available over a secure connection." : "L'autenticazione senza password è disponibile solo su una connessione sicura.",
+    "Browser not supported" : "Browser non supportato",
+    "Passwordless authentication is not supported in your browser." : "L'autenticazione senza password non è supportata dal tuo browser. ",
     "Reset password" : "Ripristina la password",
+    "Back to login" : "Torna alla schermata di accesso",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Se questo account esiste, è stato inviato un messaggio di reimpostazione della password al suo indirizzo email. Se non lo ricevi, verifica l'indirizzo di posta e/o il nome utente, controlla le cartelle spam/posta indesiderata o chiedi aiuto al tuo amministratore.",
     "Couldn't send reset email. Please contact your administrator." : "Impossibile inviare l'email di reimpostazione. Contatta il tuo amministratore.",
     "Password cannot be changed. Please contact your administrator." : "La password non può essere cambiata. Contatta il tuo amministratore.",
-    "Back to login" : "Torna alla schermata di accesso",
     "New password" : "Nuova password",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "I tuoi file sono cifrati. Non sarà più possibile recuperare i tuoi dati una volta che la password sarà reimpostata. Se non sei sicuro, contatta l'amministratore prima di proseguire. Vuoi davvero continuare?",
     "I know what I'm doing" : "So cosa sto facendo",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "Il modulo di accesso è disabilitato.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Il modulo di accesso a Nextcloud è disabilitato. Usa un'altra opzione di accesso, se disponibile, o contatta l'amministratore.",
     "More actions" : "Altre azioni",
+    "Security warning" : "Avviso di sicurezza",
+    "Storage & database" : "Archiviazione e database",
+    "Data folder" : "Cartella dati",
+    "Install and activate additional PHP modules to choose other database types." : "Installa e attiva i moduli PHP aggiuntivi per scegliere gli altri tipi di database.",
+    "For more details check out the documentation." : "Per ulteriori dettagli, leggi la documentazione.",
+    "Performance warning" : "Avviso di prestazioni",
+    "You chose SQLite as database." : "Hai scelto SQLite come database.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite dovrebbe essere scelto solo per istanze minimali e di sviluppo. Per la produzione, consigliamo un motore di database diverso.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se utilizzi client per la sincronizzazione dei file, l'uso di SQLite è sconsigliato.",
+    "Database user" : "Utente del database",
+    "Database password" : "Password del database",
+    "Database name" : "Nome del database",
+    "Database tablespace" : "Spazio delle tabelle del database",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Specifica il numero della porta insieme al nome host (ad es. localhost:5432).",
+    "Database host" : "Host del database",
+    "Installing …" : "Installazione …",
+    "Install" : "Installa",
+    "Need help?" : "Ti serve aiuto?",
+    "See the documentation" : "Leggi la documentazione",
     "{name} version {version} and above" : "{name} versione {version} e successive",
     "This browser is not supported" : "Questo browser non è supportato",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Il tuo browser non è supportato. Effettua l'aggiornamento a una versione più recente o supportata.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Digita per cercare progetti esistenti",
     "New in" : "Nuovo in",
     "View changelog" : "Visualizza le novità",
-    "Very weak password" : "Password molto debole",
-    "Weak password" : "Password debole",
-    "So-so password" : "Password così-così",
-    "Good password" : "Password buona",
-    "Strong password" : "Password forte",
     "No action available" : "Nessuna azione disponibile",
     "Error fetching contact actions" : "Errore durante il recupero delle azioni dei contatti",
     "Close \"{dialogTitle}\" dialog" : "Chiudi la finestra \"{dialogTitle}\"",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "File: %s",
     "Line: %s" : "Riga: %s",
     "Trace" : "Traccia",
-    "Security warning" : "Avviso di sicurezza",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La cartella dei dati e i file sono probabilmente accessibili da Internet poiché il file .htaccess non funziona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per informazioni su come configurare correttamente il tuo server, vedi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentazione</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Crea un account amministratore</strong>",
-    "New admin account name" : "Nuovo nome account amministratore",
-    "New admin password" : "Nuova password amministratore",
-    "Show password" : "Mostra password",
-    "Toggle password visibility" : "Commuta la visibilità delle password",
-    "Storage & database" : "Archiviazione e database",
-    "Data folder" : "Cartella dati",
-    "Configure the database" : "Configura il database",
-    "Only %s is available." : "È disponibile solo %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Installa e attiva i moduli PHP aggiuntivi per scegliere gli altri tipi di database.",
-    "For more details check out the documentation." : "Per ulteriori dettagli, leggi la documentazione.",
-    "Database account" : "Database account",
-    "Database password" : "Password del database",
-    "Database name" : "Nome del database",
-    "Database tablespace" : "Spazio delle tabelle del database",
-    "Database host" : "Host del database",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Specifica il numero della porta insieme al nome host (ad es. localhost:5432).",
-    "Performance warning" : "Avviso di prestazioni",
-    "You chose SQLite as database." : "Hai scelto SQLite come database.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite dovrebbe essere scelto solo per istanze minimali e di sviluppo. Per la produzione, consigliamo un motore di database diverso.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se utilizzi client per la sincronizzazione dei file, l'uso di SQLite è sconsigliato.",
-    "Install" : "Installa",
-    "Installing …" : "Installazione …",
-    "Need help?" : "Ti serve aiuto?",
-    "See the documentation" : "Leggi la documentazione",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Sembra che tu stia tentando di reinstallare il tuo Nextcloud. Tuttavia, manca il file CAN_INSTALL dalla cartella config. Crea il file CAN_INSTALL nella cartella config per continuare.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Impossibile rimuovere il file CAN_INSTALL dalla cartella config. Rimuovi il file manualmente.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Questa applicazione richiede JavaScript per un corretto funzionamento. {linkstart}Abilita JavaScript{linkend} e ricarica la pagina.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "Modifica il profilo",
     "The headline and about sections will show up here" : "Le sezioni del titolo e delle informazioni verranno mostrate qui",
     "Error loading message template: {error}" : "Errore durante il caricamento del modello di messaggio: {error}",
+    "Very weak password" : "Password molto debole",
+    "Weak password" : "Password debole",
+    "So-so password" : "Password così-così",
+    "Good password" : "Password buona",
+    "Strong password" : "Password forte",
     "Profile not found" : "Profilo non trovato",
-    "The profile does not exist." : "Il profilo non esiste."
+    "The profile does not exist." : "Il profilo non esiste.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "La cartella dei dati e i file sono probabilmente accessibili da Internet poiché il file .htaccess non funziona.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Per informazioni su come configurare correttamente il tuo server, vedi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentazione</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Crea un account amministratore</strong>",
+    "New admin account name" : "Nuovo nome account amministratore",
+    "New admin password" : "Nuova password amministratore",
+    "Show password" : "Mostra password",
+    "Toggle password visibility" : "Commuta la visibilità delle password",
+    "Configure the database" : "Configura il database",
+    "Only %s is available." : "È disponibile solo %s.",
+    "Database account" : "Database account"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
