@@ -134,14 +134,14 @@ OC.L10N.register(
     "Password" : "პაროლი",
     "Log in with a device" : "Log in with a device",
     "Your account is not setup for passwordless login." : "Your account is not setup for passwordless login.",
-    "Browser not supported" : "Browser not supported",
-    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
     "Your connection is not secure" : "Your connection is not secure",
     "Passwordless authentication is only available over a secure connection." : "Passwordless authentication is only available over a secure connection.",
+    "Browser not supported" : "Browser not supported",
+    "Passwordless authentication is not supported in your browser." : "Passwordless authentication is not supported in your browser.",
     "Reset password" : "Reset password",
+    "Back to login" : "Back to login",
     "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
     "Password cannot be changed. Please contact your administrator." : "Password cannot be changed. Please contact your administrator.",
-    "Back to login" : "Back to login",
     "New password" : "New password",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?",
     "I know what I'm doing" : "I know what I'm doing",
@@ -184,6 +184,25 @@ OC.L10N.register(
     "Back" : "Back",
     "Login form is disabled." : "Login form is disabled.",
     "More actions" : "More actions",
+    "Security warning" : "Security warning",
+    "Storage & database" : "Storage & database",
+    "Data folder" : "Data folder",
+    "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
+    "For more details check out the documentation." : "For more details check out the documentation.",
+    "Performance warning" : "Performance warning",
+    "You chose SQLite as database." : "You chose SQLite as database.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
+    "Database user" : "Database user",
+    "Database password" : "Database password",
+    "Database name" : "Database name",
+    "Database tablespace" : "Database tablespace",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
+    "Database host" : "Database host",
+    "Installing …" : "Installing …",
+    "Install" : "Install",
+    "Need help?" : "Need help?",
+    "See the documentation" : "See the documentation",
     "{name} version {version} and above" : "{name} version {version} and above",
     "This browser is not supported" : "This browser is not supported",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
@@ -224,11 +243,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Type to search for existing projects",
     "New in" : "New in",
     "View changelog" : "View changelog",
-    "Very weak password" : "Very weak password",
-    "Weak password" : "Weak password",
-    "So-so password" : "So-so password",
-    "Good password" : "Good password",
-    "Strong password" : "Strong password",
     "No action available" : "No action available",
     "Error fetching contact actions" : "Error fetching contact actions",
     "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
@@ -263,30 +277,6 @@ OC.L10N.register(
     "File: %s" : "File: %s",
     "Line: %s" : "Line: %s",
     "Trace" : "Trace",
-    "Security warning" : "Security warning",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
-    "Show password" : "Show password",
-    "Toggle password visibility" : "Toggle password visibility",
-    "Storage & database" : "Storage & database",
-    "Data folder" : "Data folder",
-    "Configure the database" : "Configure the database",
-    "Only %s is available." : "Only %s is available.",
-    "Install and activate additional PHP modules to choose other database types." : "Install and activate additional PHP modules to choose other database types.",
-    "For more details check out the documentation." : "For more details check out the documentation.",
-    "Database password" : "Database password",
-    "Database name" : "Database name",
-    "Database tablespace" : "Database tablespace",
-    "Database host" : "Database host",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
-    "Performance warning" : "Performance warning",
-    "You chose SQLite as database." : "You chose SQLite as database.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite should only be used for minimal and development instances. For production we recommend a different database backend.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "If you use clients for file syncing, the use of SQLite is highly discouraged.",
-    "Install" : "Install",
-    "Installing …" : "Installing …",
-    "Need help?" : "Need help?",
-    "See the documentation" : "See the documentation",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Could not remove CAN_INSTALL from the config folder. Please remove this file manually.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page.",
@@ -352,7 +342,18 @@ OC.L10N.register(
     "Edit Profile" : "Edit Profile",
     "The headline and about sections will show up here" : "The headline and about sections will show up here",
     "Error loading message template: {error}" : "Error loading message template: {error}",
+    "Very weak password" : "Very weak password",
+    "Weak password" : "Weak password",
+    "So-so password" : "So-so password",
+    "Good password" : "Good password",
+    "Strong password" : "Strong password",
     "Profile not found" : "Profile not found",
-    "The profile does not exist." : "The profile does not exist."
+    "The profile does not exist." : "The profile does not exist.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
+    "Show password" : "Show password",
+    "Toggle password visibility" : "Toggle password visibility",
+    "Configure the database" : "Configure the database",
+    "Only %s is available." : "Only %s is available."
 },
 "nplurals=2; plural=(n!=1);");
