@@ -123,13 +123,13 @@ OC.L10N.register(
     "Log in with a device" : "Prisijungti naudojant įrenginį",
     "Login or email" : "Prisijungimas ar el. paštas",
     "Your account is not setup for passwordless login." : "Jūsų paskyra nėra nustatyta prisijungimui be slaptažodžio.",
-    "Browser not supported" : "Naršyklė nepalaikoma",
-    "Passwordless authentication is not supported in your browser." : "Tapatybės nustatymas be slaptažodžio nėra palaikomas jūsų naršyklėje.",
     "Your connection is not secure" : "Jūsų ryšys nėra saugus",
     "Passwordless authentication is only available over a secure connection." : "Tapatybės nustatymas be slaptažodžio yra prieinamas tik per saugų ryšį.",
+    "Browser not supported" : "Naršyklė nepalaikoma",
+    "Passwordless authentication is not supported in your browser." : "Tapatybės nustatymas be slaptažodžio nėra palaikomas jūsų naršyklėje.",
     "Reset password" : "Atstatyti slaptažodį",
-    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atstatymo el. laiško. Susisiekite su savo administratoriumi.",
     "Back to login" : "Grįžti prie prisijungimo",
+    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atstatymo el. laiško. Susisiekite su savo administratoriumi.",
     "New password" : "Naujas slaptažodis",
     "I know what I'm doing" : "Aš žinau ką darau",
     "Schedule work & meetings, synced with all your devices." : "Planuokite su visais jūsų įrenginiais sinchronizuotus darbus ir susitikimus.",
@@ -162,6 +162,24 @@ OC.L10N.register(
     "Forgot password?" : "Pamiršote slaptažodį?",
     "Back" : "Atgal",
     "More actions" : "Daugiau veiksmų",
+    "Security warning" : "Saugumo įspėjimas",
+    "Storage & database" : "Saugykla ir duomenų bazė",
+    "Data folder" : "Duomenų aplankas",
+    "Install and activate additional PHP modules to choose other database types." : "Įdiekite ir aktyvuokite papildomus PHP modulius, kad pasirinktumėte kitus duomenų bazės tipus.",
+    "For more details check out the documentation." : "Išsamesnei informacijai, žiūrėkite dokumentaciją.",
+    "Performance warning" : "Sistemos našumo problemos perspėjimas",
+    "You chose SQLite as database." : "Jūs kaip duomenų bazę pasirinkote SQLite.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite turėtų būti naudojama tik minimaliems ir plėtojimo egzemplioriams. Darbiniam egzemplioriui rekomenduojame naudoti kitą duomenų bazės vidinę pusę.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jei sinchronizavimui naudojate kliento programas, tuomet SQLite naudojimas yra primygtinai nerekomenduojamas.",
+    "Database user" : "Duomenų bazės naudotojas",
+    "Database password" : "Duomenų bazės slaptažodis",
+    "Database name" : "Duomenų bazės pavadinimas",
+    "Database tablespace" : "Duomenų bazės loginis saugojimas",
+    "Database host" : "Duomenų bazės serveris",
+    "Installing …" : "Įdiegiama…",
+    "Install" : "Įdiegti",
+    "Need help?" : "Reikia pagalbos?",
+    "See the documentation" : "Žiūrėkite dokumentaciją",
     "This browser is not supported" : "Ši naršyklė nepalaikoma",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Jūsų naršyklė yra nepalaikoma. Atnaujinkite į naujesnę versiją arba naudokite palaikomą naršyklę.",
     "Continue with this unsupported browser" : "Tęsti naudojant šią nepalaikomą naršyklę",
@@ -200,11 +218,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Rašykite norėdami ieškoti esamų projektų",
     "New in" : "Nauja",
     "View changelog" : "Rodyti keitinių žurnalą",
-    "Very weak password" : "Labai silpnas slaptažodis",
-    "Weak password" : "Silpnas slaptažodis",
-    "So-so password" : "Neblogas slaptažodis",
-    "Good password" : "Geras slaptažodis",
-    "Strong password" : "Stiprus slaptažodis",
     "No action available" : "Jokie veiksmai negalimi",
     "Error fetching contact actions" : "Klaida gaunant veiksmus darbui su adresatais",
     "Non-existing tag #{tag}" : "Neegzistuojanti žymė #{tag}",
@@ -238,30 +251,6 @@ OC.L10N.register(
     "File: %s" : "Failas: %s",
     "Line: %s" : "Eilutė: %s",
     "Trace" : "Sekti",
-    "Security warning" : "Saugumo įspėjimas",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų duomenų katalogas ir failai, tikriausiai, yra prieinami per internetą, nes .htaccess failas neveikia.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Išsamesnei informacijai apie tai kaip tinkamai sukonfigūruoti savo serverį, žiūrėkite <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciją</a>.",
-    "Show password" : "Rodyti slaptažodį",
-    "Toggle password visibility" : "Perjungti slaptažodžio matomumą",
-    "Storage & database" : "Saugykla ir duomenų bazė",
-    "Data folder" : "Duomenų aplankas",
-    "Configure the database" : "Konfigūruokite duomenų bazę",
-    "Only %s is available." : "Yra prieinama tik %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Įdiekite ir aktyvuokite papildomus PHP modulius, kad pasirinktumėte kitus duomenų bazės tipus.",
-    "For more details check out the documentation." : "Išsamesnei informacijai, žiūrėkite dokumentaciją.",
-    "Database account" : "Duomenų bazės paskyra",
-    "Database password" : "Duomenų bazės slaptažodis",
-    "Database name" : "Duomenų bazės pavadinimas",
-    "Database tablespace" : "Duomenų bazės loginis saugojimas",
-    "Database host" : "Duomenų bazės serveris",
-    "Performance warning" : "Sistemos našumo problemos perspėjimas",
-    "You chose SQLite as database." : "Jūs kaip duomenų bazę pasirinkote SQLite.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite turėtų būti naudojama tik minimaliems ir plėtojimo egzemplioriams. Darbiniam egzemplioriui rekomenduojame naudoti kitą duomenų bazės vidinę pusę.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jei sinchronizavimui naudojate kliento programas, tuomet SQLite naudojimas yra primygtinai nerekomenduojamas.",
-    "Install" : "Įdiegti",
-    "Installing …" : "Įdiegiama…",
-    "Need help?" : "Reikia pagalbos?",
-    "See the documentation" : "Žiūrėkite dokumentaciją",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nepavyko iš konfigūracijos aplanko pašalinti failo CAN_INSTALL. Pašalinkite šį failą rankiniu būdu.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Sistemos veikimui reikalingas JavaScript palaikymas. Prašome {linkstart}įjungti JavaScript palaikymą{linkend} ir atnaujinti puslapį.",
     "Skip to main content" : "Pereiti į pagrindinį turinį",
@@ -315,7 +304,19 @@ OC.L10N.register(
     "Edit Profile" : "Taisyti profilį",
     "The headline and about sections will show up here" : "Čia bus rodoma santrauka apie jus bei kita su jumis susijusi informacija",
     "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
+    "Very weak password" : "Labai silpnas slaptažodis",
+    "Weak password" : "Silpnas slaptažodis",
+    "So-so password" : "Neblogas slaptažodis",
+    "Good password" : "Geras slaptažodis",
+    "Strong password" : "Stiprus slaptažodis",
     "Profile not found" : "Profilis nerastas",
-    "The profile does not exist." : "Profilio nėra."
+    "The profile does not exist." : "Profilio nėra.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų duomenų katalogas ir failai, tikriausiai, yra prieinami per internetą, nes .htaccess failas neveikia.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Išsamesnei informacijai apie tai kaip tinkamai sukonfigūruoti savo serverį, žiūrėkite <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciją</a>.",
+    "Show password" : "Rodyti slaptažodį",
+    "Toggle password visibility" : "Perjungti slaptažodžio matomumą",
+    "Configure the database" : "Konfigūruokite duomenų bazę",
+    "Only %s is available." : "Yra prieinama tik %s.",
+    "Database account" : "Duomenų bazės paskyra"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
