@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Inloggen met een apparaat",
     "Login or email" : "Login of email",
     "Your account is not setup for passwordless login." : "Je account is niet ingesteld voor inloggen zonder wachtwoord.",
-    "Browser not supported" : "Browser niet ondersteund",
-    "Passwordless authentication is not supported in your browser." : "Inloggen zonder wachtwoord is niet ondersteund door je browser.",
     "Your connection is not secure" : "Je verbinding is niet veilig",
     "Passwordless authentication is only available over a secure connection." : "Inloggen zonder wachtwoord is alleen mogelijk over een beveiligde verbinding.",
+    "Browser not supported" : "Browser niet ondersteund",
+    "Passwordless authentication is not supported in your browser." : "Inloggen zonder wachtwoord is niet ondersteund door je browser.",
     "Reset password" : "Reset wachtwoord",
+    "Back to login" : "Terug naar inloggen",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Als dit account bestaat, werd er een wachtwoordherstel email naar het overeenkomstige email adres gestuurd. Krijg je geen mail? Controleer dan het e-mailadres en/of de login, check je spam folder of vraag hulp aan je  beheerder.",
     "Couldn't send reset email. Please contact your administrator." : "Kon herstel email niet versturen. Neem contact op met je beheerder.",
     "Password cannot be changed. Please contact your administrator." : "Het wachtwoord kan niet worden gewijzigd. Neem contact op met je beheerder.",
-    "Back to login" : "Terug naar inloggen",
     "New password" : "Nieuw wachtwoord",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Je bestanden zijn versleuteld. Het is niet mogelijk om je gegevens terug te krijgen als je wachtwoord wordt gereset. Als je niet zeker weer wat je moet doen, neem dan contact op met je beheerder voordat je verdergaat. Wil je echt verder gaan?",
     "I know what I'm doing" : "Ik weet wat ik doe",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "Inlogscherm uitgeschakeld",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Het aanmeldingsformulier van Nextcloud is uitgeschakeld. Gebruik een andere inlogmogelijkheid indien beschikbaar of neem contact op met uw beheerder.",
     "More actions" : "Meer acties",
+    "Security warning" : "Beveiligingswaarschuwing",
+    "Storage & database" : "Opslag & database",
+    "Data folder" : "Gegevensmap",
+    "Install and activate additional PHP modules to choose other database types." : "Installeer en activeer aanvullende PHP modules om andere soorten databases te kiezen.",
+    "For more details check out the documentation." : "Voor meer informatie word je verwezen naar de documentatie.",
+    "Performance warning" : "Prestatiewaarschuwing",
+    "You chose SQLite as database." : "Je koos SQLite als database.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite zou alleen moeten worden gebruikt voor minimale en ontwikkelomgevingen. Voor productie raden we aan om een andere database backend te gebruiken.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Als je clients gebruikt voor bestandssynchronisatie wordt het gebruik van SQLite sterk ontraden.",
+    "Database user" : "Gebruiker database",
+    "Database password" : "Wachtwoord database",
+    "Database name" : "Naam database",
+    "Database tablespace" : "Database tablespace",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Geef het poortnummer en servernaam op (bijv. localhost:5432).",
+    "Database host" : "Databaseserver",
+    "Installing …" : "Installeren …",
+    "Install" : "Installeren",
+    "Need help?" : "Hulp nodig?",
+    "See the documentation" : "Zie de documentatie",
     "{name} version {version} and above" : "{name} versie {version} en hoger",
     "This browser is not supported" : "Deze browser wordt niet ondersteunt",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Deze browser wordt niet ondersteunt. Upgrade a.u.b naar een nieuwere versie of een browser die wel ondersteunt wordt.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Type om bestaande projecten te vinden",
     "New in" : "Nieuw in",
     "View changelog" : "Bekijk wijzigingsoverzicht",
-    "Very weak password" : "Zeer zwak wachtwoord",
-    "Weak password" : "Zwak wachtwoord",
-    "So-so password" : "Matig wachtwoord",
-    "Good password" : "Goed wachtwoord",
-    "Strong password" : "Sterk wachtwoord",
     "No action available" : "Geen actie beschikbaar",
     "Error fetching contact actions" : "Fout bij ophalen contact acties",
     "Close \"{dialogTitle}\" dialog" : "Sluit \"{dialogTitle}\" dialoog",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "Bestand: %s",
     "Line: %s" : "Regel: %s",
     "Trace" : "Trace",
-    "Security warning" : "Beveiligingswaarschuwing",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Je gegevensdirectory en bestanden zijn vermoedelijk bereikbaar vanaf het internet, omdat het .htaccess-bestand niet functioneert.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Bekijk de <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatie</a> voor Informatie over het correct configureren van je server.",
-    "<strong>Create an admin account</strong>" : "<strong>Maak een admin account aan</strong>",
-    "New admin account name" : "Nieuwe admin account naam",
-    "New admin password" : "Nieuw admin wachtwoord",
-    "Show password" : "Toon wachtwoord",
-    "Toggle password visibility" : "Omschakelen zichtbaarheid wachtwoord",
-    "Storage & database" : "Opslag & database",
-    "Data folder" : "Gegevensmap",
-    "Configure the database" : "Configureer de database",
-    "Only %s is available." : "Alleen %s is beschikbaar.",
-    "Install and activate additional PHP modules to choose other database types." : "Installeer en activeer aanvullende PHP modules om andere soorten databases te kiezen.",
-    "For more details check out the documentation." : "Voor meer informatie word je verwezen naar de documentatie.",
-    "Database account" : "Database account",
-    "Database password" : "Wachtwoord database",
-    "Database name" : "Naam database",
-    "Database tablespace" : "Database tablespace",
-    "Database host" : "Databaseserver",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Geef het poortnummer en servernaam op (bijv. localhost:5432).",
-    "Performance warning" : "Prestatiewaarschuwing",
-    "You chose SQLite as database." : "Je koos SQLite als database.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite zou alleen moeten worden gebruikt voor minimale en ontwikkelomgevingen. Voor productie raden we aan om een andere database backend te gebruiken.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Als je clients gebruikt voor bestandssynchronisatie wordt het gebruik van SQLite sterk ontraden.",
-    "Install" : "Installeren",
-    "Installing …" : "Installeren …",
-    "Need help?" : "Hulp nodig?",
-    "See the documentation" : "Zie de documentatie",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Het lijkt erop of je Nextcloud wilt herinstalleren. Maar het bestand CAN_INSTALL ontbreekt in de configdirectory. Maak het bestand CAN_INSTALL aan in je config map om verder te gaan.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Kon CAN_INSTALL niet verwijderen uit de config map. Verwijder het bestand handmatig.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Deze applicatie heeft JavaScript nodig. {linkstart}Activeer JavaScript{linkend} en ververs deze pagina.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "Wijzig Profiel",
     "The headline and about sections will show up here" : "De koplijn- en oversectie zal hier verschijnen",
     "Error loading message template: {error}" : "Fout bij laden berichtensjabloon: {error}",
+    "Very weak password" : "Zeer zwak wachtwoord",
+    "Weak password" : "Zwak wachtwoord",
+    "So-so password" : "Matig wachtwoord",
+    "Good password" : "Goed wachtwoord",
+    "Strong password" : "Sterk wachtwoord",
     "Profile not found" : "Profiel niet gevonden",
-    "The profile does not exist." : "Het profiel bestaat niet."
+    "The profile does not exist." : "Het profiel bestaat niet.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Je gegevensdirectory en bestanden zijn vermoedelijk bereikbaar vanaf het internet, omdat het .htaccess-bestand niet functioneert.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Bekijk de <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatie</a> voor Informatie over het correct configureren van je server.",
+    "<strong>Create an admin account</strong>" : "<strong>Maak een admin account aan</strong>",
+    "New admin account name" : "Nieuwe admin account naam",
+    "New admin password" : "Nieuw admin wachtwoord",
+    "Show password" : "Toon wachtwoord",
+    "Toggle password visibility" : "Omschakelen zichtbaarheid wachtwoord",
+    "Configure the database" : "Configureer de database",
+    "Only %s is available." : "Alleen %s is beschikbaar.",
+    "Database account" : "Database account"
 },
 "nplurals=2; plural=(n != 1);");
