@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Logar-se com um dispositivo",
     "Login or email" : "Login ou e-mail",
     "Your account is not setup for passwordless login." : "Sua conta não está configurada para login sem senha.",
-    "Browser not supported" : "Navegador não suportado",
-    "Passwordless authentication is not supported in your browser." : "A autenticação sem senha não é suportada no seu navegador.",
     "Your connection is not secure" : "Sua conexão não é segura",
     "Passwordless authentication is only available over a secure connection." : "A autenticação sem senha está disponível apenas em uma conexão segura.",
+    "Browser not supported" : "Navegador não suportado",
+    "Passwordless authentication is not supported in your browser." : "A autenticação sem senha não é suportada no seu navegador.",
     "Reset password" : "Redefinir senha",
+    "Back to login" : "Voltar ao login",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Se essa conta existir, uma mensagem de redefinição de senha foi enviada para o endereço de e-mail associado a ela. Se você não receber, verifique seu endereço de e-mail e/ou faça login, confira suas pastas de spam/lixeira ou peça ajuda à administração local.",
     "Couldn't send reset email. Please contact your administrator." : "Não foi possível enviar o e-mail de redefinição. Por favor, contate o administrador.",
     "Password cannot be changed. Please contact your administrator." : "A senha não pôde ser alterada. Por favor contate seu administrador.",
-    "Back to login" : "Voltar ao login",
     "New password" : "Nova senha",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Seus arquivos são criptografados. Não há como recuperar os dados depois que a senha for redefinida. Se não tiver certeza do que fazer, entre em contato com o administrador. Quer realmente continuar?",
     "I know what I'm doing" : "Eu sei o que estou fazendo",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "O formulário de login está desativado.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulário de login do Nextcloud está desabilitado. Use outra opção de login, se disponível, ou entre em contato com sua administração.",
     "More actions" : "Mais ações",
+    "Security warning" : "Alerta de segurança",
+    "Storage & database" : "Armazenamento & banco de dados",
+    "Data folder" : "Pasta de dados",
+    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos adicionais do PHP para escolher outros tipos de banco de dados.",
+    "For more details check out the documentation." : "Para mais informações consulte a documentação.",
+    "Performance warning" : "Alerta de performance",
+    "You chose SQLite as database." : "Você escolheu o SQLite como banco de dados.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "O SQLite deve ser usado apenas para instâncias mínimas e de desenvolvimento. Para produção, recomendamos um banco de dados diferente.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se você usa clientes para sincronização de arquivos, o SQLite é altamente desencorajado.",
+    "Database user" : "Usuário do banco de dados",
+    "Database password" : "Senha do banco de dados",
+    "Database name" : "Nome do banco de dados",
+    "Database tablespace" : "Espaço de tabela do banco de dados",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifique o nome do host e porta (ex., localhost:5432).",
+    "Database host" : "Host do banco de dados",
+    "Installing …" : "Instalando ...",
+    "Install" : "Instalar",
+    "Need help?" : "Precisa de ajuda?",
+    "See the documentation" : "Veja a documentação",
     "{name} version {version} and above" : "{name} versão {version} e superior",
     "This browser is not supported" : "Este navegador não é compatível",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Seu navegador não é suportado. Atualize para uma versão mais recente ou compatível.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Digite para pesquisar projetos existentes",
     "New in" : "Novo em",
     "View changelog" : "Ver alterações",
-    "Very weak password" : "Senha muito fraca",
-    "Weak password" : "Senha fraca",
-    "So-so password" : "Senha mais ou menos",
-    "Good password" : "Senha boa",
-    "Strong password" : "Senha forte",
     "No action available" : "Nenhuma ação disponível",
     "Error fetching contact actions" : "Erro ao obter as ações de contato",
     "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialog",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "Arquivo: %s",
     "Line: %s" : "Linha: %s",
     "Trace" : "Rastreamento",
-    "Security warning" : "Alerta de segurança",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Seu diretório de dados e arquivos provavelmente estão acessíveis pela internet, porque o .htaccess não funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para mais informações de como configurar apropriadamente seu servidor, consulte nossa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentação</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Criar uma conta de administrador</strong>",
-    "New admin account name" : "Nome de conta do novo Administrador",
-    "New admin password" : "Senha do novo Administrador",
-    "Show password" : "Mostrar senha",
-    "Toggle password visibility" : "Alternar visibilidade da senha",
-    "Storage & database" : "Armazenamento & banco de dados",
-    "Data folder" : "Pasta de dados",
-    "Configure the database" : "Configurar o banco de dados",
-    "Only %s is available." : "Somente %s está disponível.",
-    "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos adicionais do PHP para escolher outros tipos de banco de dados.",
-    "For more details check out the documentation." : "Para mais informações consulte a documentação.",
-    "Database account" : "Conta de banco de dados",
-    "Database password" : "Senha do banco de dados",
-    "Database name" : "Nome do banco de dados",
-    "Database tablespace" : "Espaço de tabela do banco de dados",
-    "Database host" : "Host do banco de dados",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifique o nome do host e porta (ex., localhost:5432).",
-    "Performance warning" : "Alerta de performance",
-    "You chose SQLite as database." : "Você escolheu o SQLite como banco de dados.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "O SQLite deve ser usado apenas para instâncias mínimas e de desenvolvimento. Para produção, recomendamos um banco de dados diferente.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Se você usa clientes para sincronização de arquivos, o SQLite é altamente desencorajado.",
-    "Install" : "Instalar",
-    "Installing …" : "Instalando ...",
-    "Need help?" : "Precisa de ajuda?",
-    "See the documentation" : "Veja a documentação",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Parece que você está tentando reinstalar o Nextcloud. No entanto, o arquivo CAN_INSTALL está faltando no diretório de configuração. Crie o arquivo CAN_INSTALL na pasta de configuração para continuar.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Não foi possível remover CAN_INSTALL da pasta de configuração. Remova este arquivo manualmente.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Este aplicativo requer JavaScript para sua correta operação. Por favor {linkstart}habilite o JavaScript{linkend} e recarregue a página.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "Editar Perfil ",
     "The headline and about sections will show up here" : "O título e as seções sobre serão exibidos aqui",
     "Error loading message template: {error}" : "Erro carregando o modelo de mensagem: {error}",
+    "Very weak password" : "Senha muito fraca",
+    "Weak password" : "Senha fraca",
+    "So-so password" : "Senha mais ou menos",
+    "Good password" : "Senha boa",
+    "Strong password" : "Senha forte",
     "Profile not found" : "Perfil não encontrado",
-    "The profile does not exist." : "O perfil não existe. "
+    "The profile does not exist." : "O perfil não existe. ",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Seu diretório de dados e arquivos provavelmente estão acessíveis pela internet, porque o .htaccess não funciona.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para mais informações de como configurar apropriadamente seu servidor, consulte nossa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentação</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Criar uma conta de administrador</strong>",
+    "New admin account name" : "Nome de conta do novo Administrador",
+    "New admin password" : "Senha do novo Administrador",
+    "Show password" : "Mostrar senha",
+    "Toggle password visibility" : "Alternar visibilidade da senha",
+    "Configure the database" : "Configurar o banco de dados",
+    "Only %s is available." : "Somente %s está disponível.",
+    "Database account" : "Conta de banco de dados"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
