@@ -127,14 +127,14 @@ OC.L10N.register(
     "Password" : "Crae",
     "Log in with a device" : "Autentica·ti cun unu dispositivu",
     "Your account is not setup for passwordless login." : "Su contu tuo no est fatu pro autenticatziones chene crae.",
-    "Browser not supported" : "Navigadore non suportadu",
-    "Passwordless authentication is not supported in your browser." : "S'autenticatzione chene crae no est suportada in su navigadore tuo.",
     "Your connection is not secure" : "Sa connessione tua no est segura",
     "Passwordless authentication is only available over a secure connection." : "S'autenticatzione chene crae est a disponimentu isceti cun connessiones seguras.",
+    "Browser not supported" : "Navigadore non suportadu",
+    "Passwordless authentication is not supported in your browser." : "S'autenticatzione chene crae no est suportada in su navigadore tuo.",
     "Reset password" : "Riprìstina sa crae",
+    "Back to login" : "Torra a s'autenticatzione",
     "Couldn't send reset email. Please contact your administrator." : "No at fatu a ripristinare sa posta eletrònica. Cuntata s'amministratzione.",
     "Password cannot be changed. Please contact your administrator." : "Sa crae non faghet a dda cambiare. Cuntata s'amministratzione.",
-    "Back to login" : "Torra a s'autenticatzione",
     "New password" : "Crae noa",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Is archìvios sunt critografados. Non ddoe at a èssere manera pro tènnere is datos a pustis de su riprìstinu de sa crae. Si tenes dudas, cuntata s'amministratzione in antis. A beru boles sighire?",
     "I know what I'm doing" : "Giai dd'isco ite so faghinde",
@@ -173,6 +173,25 @@ OC.L10N.register(
     "Back" : "A coa",
     "Login form is disabled." : "Su mòdulu de atzessu est disativadu.",
     "More actions" : "Àteras atziones",
+    "Security warning" : "Avisu de seguresa",
+    "Storage & database" : "Depòsitu e base de datos",
+    "Data folder" : "Cartella de datos",
+    "Install and activate additional PHP modules to choose other database types." : "Installa e ativa àteros mòdulos PHP pro seberare àteras genias de base de datos.",
+    "For more details check out the documentation." : "Pro àteros detàllios controlla sa documentatzione.",
+    "Performance warning" : "Avisu de atuatzione",
+    "You chose SQLite as database." : "As seberadu SQLite comente base de datos.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite diat èssere impreadu isceti pro istàntzias mìnimas e de isvilupu. Pro sa produtzione cussigiamus un'àtera base de datos de palas.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Chi impreas clientes pro sa sincronizatzione de is archìvios, SQLite no est cussigiadu pro nudda.",
+    "Database user" : "Utente base de datos",
+    "Database password" : "Crae base de datos",
+    "Database name" : "Nùmene base de datos",
+    "Database tablespace" : "Logu de sa tauledda de sa base de datos",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ispetzìfica su nùmeru de sa gianna aintru de su nùmene de su retzidore (p.e., retzidorelocale:5432).",
+    "Database host" : "Retzidore de sa base de datos",
+    "Installing …" : "Installende ...",
+    "Install" : "Installa",
+    "Need help?" : "Boles agiudu?",
+    "See the documentation" : "Càstia sa documentatzione",
     "{name} version {version} and above" : "{name} versione {version} e superiores",
     "This browser is not supported" : "Custu navigadore no est cumpatìbile",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navigadore tuo no est cumpatìbile. Atualiza·ddu a una versione noa o càmbia a unu navigadore cumpatìbile.",
@@ -213,11 +232,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Iscrie pro chircare is progetos chi ddoe sunt giai",
     "New in" : "Prima borta in",
     "View changelog" : "Càstia su registru de is càmbios",
-    "Very weak password" : "Crae dèbile meda",
-    "Weak password" : "Crae dèbile",
-    "So-so password" : "Crae aici aici",
-    "Good password" : "Crae bona",
-    "Strong password" : "Crae bona a beru",
     "No action available" : "Peruna atzione a disponimentu",
     "Error fetching contact actions" : "Errore in su recùperu de is atziones de cuntatu",
     "Close \"{dialogTitle}\" dialog" : "Serra su cuadru de diàlogu \"{dialogTitle}\"",
@@ -250,30 +264,6 @@ OC.L10N.register(
     "File: %s" : "Archìviu: %s",
     "Line: %s" : "Lìnia: %s",
     "Trace" : "Arrasta",
-    "Security warning" : "Avisu de seguresa",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is cartellas de datos e is archìvios tuos fortzis sunt atzessìbiles dae s'internet ca s'archìviu .htaccess no est funtzionende.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pro informatziones subra de comente cunfigurare su serbidore tuo, càstia in sa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatzione</a>.",
-    "Show password" : "Mustra crae",
-    "Toggle password visibility" : "Càmbia sa visibilidade de sa crae",
-    "Storage & database" : "Depòsitu e base de datos",
-    "Data folder" : "Cartella de datos",
-    "Configure the database" : "Cunfigura sa base de datos",
-    "Only %s is available." : "%s isceti est a disponimentu.",
-    "Install and activate additional PHP modules to choose other database types." : "Installa e ativa àteros mòdulos PHP pro seberare àteras genias de base de datos.",
-    "For more details check out the documentation." : "Pro àteros detàllios controlla sa documentatzione.",
-    "Database password" : "Crae base de datos",
-    "Database name" : "Nùmene base de datos",
-    "Database tablespace" : "Logu de sa tauledda de sa base de datos",
-    "Database host" : "Retzidore de sa base de datos",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ispetzìfica su nùmeru de sa gianna aintru de su nùmene de su retzidore (p.e., retzidorelocale:5432).",
-    "Performance warning" : "Avisu de atuatzione",
-    "You chose SQLite as database." : "As seberadu SQLite comente base de datos.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite diat èssere impreadu isceti pro istàntzias mìnimas e de isvilupu. Pro sa produtzione cussigiamus un'àtera base de datos de palas.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Chi impreas clientes pro sa sincronizatzione de is archìvios, SQLite no est cussigiadu pro nudda.",
-    "Install" : "Installa",
-    "Installing …" : "Installende ...",
-    "Need help?" : "Boles agiudu?",
-    "See the documentation" : "Càstia sa documentatzione",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Paret chi ses chirchende de torrare a installare Nextcloud. In cada manera, mancat s'archìviu CAN_INSTALL in sa cartella de cunfiguratzione. Crea s'archìviu CAN_INSTALL in sa cartella de cunfiguratzione pro sighire.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No at fatu a nche bogare CAN_INSTALL dae sa cartella de cunfiguratzione. Boga custu archìviu a manu.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Custa aplicatzione rechedet JavaScript pro un'operatzione curreta. {linkstart} Ativa JavaScript{linkend} e torra a carrigare sa pàgina.",
@@ -334,7 +324,18 @@ OC.L10N.register(
     "Edit Profile" : "Modìfica su profilu",
     "The headline and about sections will show up here" : "Is setziones de tìtulu e informatziones ant a èssere ammustradas inoghe",
     "Error loading message template: {error}" : "Errore in su carrigamentu de su modellu de messàgiu: {error}",
+    "Very weak password" : "Crae dèbile meda",
+    "Weak password" : "Crae dèbile",
+    "So-so password" : "Crae aici aici",
+    "Good password" : "Crae bona",
+    "Strong password" : "Crae bona a beru",
     "Profile not found" : "Profilu no agatadu",
-    "The profile does not exist." : "Su profilu no esistit."
+    "The profile does not exist." : "Su profilu no esistit.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is cartellas de datos e is archìvios tuos fortzis sunt atzessìbiles dae s'internet ca s'archìviu .htaccess no est funtzionende.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pro informatziones subra de comente cunfigurare su serbidore tuo, càstia in sa <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatzione</a>.",
+    "Show password" : "Mustra crae",
+    "Toggle password visibility" : "Càmbia sa visibilidade de sa crae",
+    "Configure the database" : "Cunfigura sa base de datos",
+    "Only %s is available." : "%s isceti est a disponimentu."
 },
 "nplurals=2; plural=(n != 1);");
