@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Prijava z napravo",
     "Login or email" : "Prijavno ime ali elektronski naslov",
     "Your account is not setup for passwordless login." : "Račun ni nastavljen za brezgeselno prijavo.",
-    "Browser not supported" : "Trenutno uporabljen brskalnik ni podprt!",
-    "Passwordless authentication is not supported in your browser." : "Brezgeselna overitev v tem brskalniku ni podprta.",
     "Your connection is not secure" : "Vzpostavljena povezava ni varna",
     "Passwordless authentication is only available over a secure connection." : "Brezgeselna overitev je na voljo le prek vzpostavljene varne povezave.",
+    "Browser not supported" : "Trenutno uporabljen brskalnik ni podprt!",
+    "Passwordless authentication is not supported in your browser." : "Brezgeselna overitev v tem brskalniku ni podprta.",
     "Reset password" : "Ponastavi geslo",
+    "Back to login" : "Nazaj na prijavo",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Če račun obstaja, bo na elektronski naslov poslano sporočilo za ponastavitev gesla. Če ne prispe, preverite elektronski naslov, prijavne podatke, poglejte med neželeno pošte oziroma stopite v stik s skrbnikom sistema.",
     "Couldn't send reset email. Please contact your administrator." : "Ni mogoče poslati elektronskega sporočila za ponastavitev. Stopite v stik s skrbnikom sistema.",
     "Password cannot be changed. Please contact your administrator." : "Gesla ni mogoče spremeniti. Stopite v stik s skrbnikom.",
-    "Back to login" : "Nazaj na prijavo",
     "New password" : "Novo geslo",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Datoteke so šifrirane. Če niste omogočili obnovitvenega ključa, po ponastavitvi gesla dostop do datotek ne bo več mogoč.<br />Če niste prepričani, kaj storiti, stopite v stik s skrbnikom sistema.<br />Ali res želite nadaljevati?",
     "I know what I'm doing" : "Vem, kaj delam!",
@@ -206,6 +206,25 @@ OC.L10N.register(
     "Login form is disabled." : "Prijavni obrazec je onemogočen.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Prijavni obrazec Nextcloud je onemogočen. Če je mogoče, izberite drug način prijave, ali pa stopite v stik s skrbnikom sistema.",
     "More actions" : "Več dejanj",
+    "Security warning" : "Varnostno opozorilo",
+    "Storage & database" : "Shramba in podatkovna zbirka",
+    "Data folder" : "Podatkovna mapa",
+    "Install and activate additional PHP modules to choose other database types." : "Namestite in omogočite dodatne module PHP za izbor drugih vrst podatkovnih zbirk.",
+    "For more details check out the documentation." : "Za več podrobnosti preverite dokumentacijo.",
+    "Performance warning" : "Opozorilo učinkovitosti delovanja",
+    "You chose SQLite as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Podatkovna zbirka SQLite je primerna le za manjše in razvojne namestitve. Za produkcijsko okolje je priporočljivo uporabiti drugo podatkovno ozadje.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Če uporabljate namizni odjemalec za usklajevanje datotek, je uporaba podatkovne zbirke SQLite odsvetovana.",
+    "Database user" : "Uporabnik podatkovne zbirke",
+    "Database password" : "Geslo podatkovne zbirke",
+    "Database name" : "Ime podatkovne zbirke",
+    "Database tablespace" : "Razpredelnica podatkovne zbirke",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Skupaj z imenom gostitelja je treba določiti tudi številko vrat (na primer localhost:5432).",
+    "Database host" : "Gostitelj podatkovne zbirke",
+    "Installing …" : "Poteka nameščanje ...",
+    "Install" : "Namesti",
+    "Need help?" : "Ali potrebujete pomoč?",
+    "See the documentation" : "Preverite dokumentacijo",
     "{name} version {version} and above" : "{name} različica {version} ali višja",
     "This browser is not supported" : "Trenutno uporabljen brskalnik ni podprt!",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Uporabljen brskalnik ni podprt. Posodobite program na novejšo različico, ali pa uporabite drug program.",
@@ -246,11 +265,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Vpišite niz za iskanje obstoječih projektov",
     "New in" : "Novo v",
     "View changelog" : "Poglej dnevnik sprememb",
-    "Very weak password" : "Zelo šibko geslo",
-    "Weak password" : "Šibko geslo",
-    "So-so password" : "Slabo geslo",
-    "Good password" : "Dobro geslo",
-    "Strong password" : "Odlično geslo",
     "No action available" : "Ni razpoložljivih dejanj",
     "Error fetching contact actions" : "Prišlo je do napake med pridobivanjem dejanj stikov",
     "Close \"{dialogTitle}\" dialog" : "Zapri pogovorno okno »{dialogTitle}«",
@@ -287,31 +301,6 @@ OC.L10N.register(
     "File: %s" : "Datoteka: %s",
     "Line: %s" : "Vrstica: %s",
     "Trace" : "Sledenje povezav",
-    "Security warning" : "Varnostno opozorilo",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Podatkovna mapa in datoteke so najverjetneje javno dostopni v omrežju, ker datoteka .htaccess ni ustrezno nastavljena.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Več podrobnosti, kako pravilno nastaviti strežnik, je zapisanih v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciji</a>.",
-    "Show password" : "Pokaži geslo",
-    "Toggle password visibility" : "Preklopi vidnost gesla",
-    "Storage & database" : "Shramba in podatkovna zbirka",
-    "Data folder" : "Podatkovna mapa",
-    "Configure the database" : "Nastavi podatkovno zbirko",
-    "Only %s is available." : "Na voljo je le %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Namestite in omogočite dodatne module PHP za izbor drugih vrst podatkovnih zbirk.",
-    "For more details check out the documentation." : "Za več podrobnosti preverite dokumentacijo.",
-    "Database account" : "Račun podatkovne zbirke",
-    "Database password" : "Geslo podatkovne zbirke",
-    "Database name" : "Ime podatkovne zbirke",
-    "Database tablespace" : "Razpredelnica podatkovne zbirke",
-    "Database host" : "Gostitelj podatkovne zbirke",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Skupaj z imenom gostitelja je treba določiti tudi številko vrat (na primer localhost:5432).",
-    "Performance warning" : "Opozorilo učinkovitosti delovanja",
-    "You chose SQLite as database." : "Kot podatkovna zbirka bo uporabljena zbirka SQLite.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Podatkovna zbirka SQLite je primerna le za manjše in razvojne namestitve. Za produkcijsko okolje je priporočljivo uporabiti drugo podatkovno ozadje.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Če uporabljate namizni odjemalec za usklajevanje datotek, je uporaba podatkovne zbirke SQLite odsvetovana.",
-    "Install" : "Namesti",
-    "Installing …" : "Poteka nameščanje ...",
-    "Need help?" : "Ali potrebujete pomoč?",
-    "See the documentation" : "Preverite dokumentacijo",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Kaže, da poskušate ponovno namestiti okolje Nextcloud, a datoteke CAN_INSTALL ni v mapi nastavitev. Ustvarite jo, potem lahko poskusite znova.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ni mogoče odstraniti datoteke CAN_INSTALL iz nastavitvene mape. Odstranite jo ročno.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Program zahteva podporo JavaScript za pravilno delovanje. Med nastavitvami omogočite {linkstart}JavaScript{linkend} in osvežite spletno stran.",
@@ -380,7 +369,19 @@ OC.L10N.register(
     "Edit Profile" : "Uredi profil",
     "The headline and about sections will show up here" : "Naslovnica in odsek s podatki bo prikazan na tem mestu.",
     "Error loading message template: {error}" : "Napaka nalaganja predloge sporočil: {error}",
+    "Very weak password" : "Zelo šibko geslo",
+    "Weak password" : "Šibko geslo",
+    "So-so password" : "Slabo geslo",
+    "Good password" : "Dobro geslo",
+    "Strong password" : "Odlično geslo",
     "Profile not found" : "Profila ni mogoče najti",
-    "The profile does not exist." : "Profil ne obstaja."
+    "The profile does not exist." : "Profil ne obstaja.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Podatkovna mapa in datoteke so najverjetneje javno dostopni v omrežju, ker datoteka .htaccess ni ustrezno nastavljena.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Več podrobnosti, kako pravilno nastaviti strežnik, je zapisanih v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciji</a>.",
+    "Show password" : "Pokaži geslo",
+    "Toggle password visibility" : "Preklopi vidnost gesla",
+    "Configure the database" : "Nastavi podatkovno zbirko",
+    "Only %s is available." : "Na voljo je le %s.",
+    "Database account" : "Račun podatkovne zbirke"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
