@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Bir aygıt ile oturum açın",
     "Login or email" : "Kullanıcı adı ya da e-posta",
     "Your account is not setup for passwordless login." : "Hesabınız parola kullanmadan oturum açılacak şekilde ayarlanmamış.",
-    "Browser not supported" : "Tarayıcı desteklenmiyor!",
-    "Passwordless authentication is not supported in your browser." : "Tarayıcınız parolasız kimlik doğrulama özelliğini desteklemiyor.",
     "Your connection is not secure" : "Bağlantınız güvenli değil",
     "Passwordless authentication is only available over a secure connection." : "Parolasız kimlik doğrulama özelliği yalnızca güvenli bir bağlantı üzerinden kullanılabilir.",
+    "Browser not supported" : "Tarayıcı desteklenmiyor!",
+    "Passwordless authentication is not supported in your browser." : "Tarayıcınız parolasız kimlik doğrulama özelliğini desteklemiyor.",
     "Reset password" : "Parolayı sıfırla",
+    "Back to login" : "Oturum açmaya geri dön",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Bu hesap varsa, e-posta adresine bir parola sıfırlama iletisi gönderilmiştir. Bunu almazsanız, e-posta adresinizi ve/veya kullanıcı adınızı doğrulayın, spam/önemsiz klasörlerinizi denetleyin ya da yerel yöneticinizden yardım isteyin.",
     "Couldn't send reset email. Please contact your administrator." : "Sıfırlama e-postası gönderilemedi. Lütfen BT yöneticiniz ile görüşün.",
     "Password cannot be changed. Please contact your administrator." : "Parola değiştirilemedi. Lütfen BT yöneticiniz ile görüşün.",
-    "Back to login" : "Oturum açmaya geri dön",
     "New password" : "Yeni parola",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dosyalarınız şifrelendi. Parolanız sıfırlandıktan sonra verilerinizi geri almanın herhangi bir yolu olmayacak. Ne yapacağınızı bilmiyorsanız işlemi sürdürmeden önce BT yöneticiniz ile görüşün. İşlemi sürdürmek istediğinize emin misiniz? ",
     "I know what I'm doing" : "Ne yaptığımı biliyorum",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "Oturum açma formu kullanımdan kaldırılmış.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud oturum açma formu kullanımdan kaldırılmış. Varsa başka bir oturum açma seçeneğini kullanın ya da yöneticiniz ile görüşün.",
     "More actions" : "Diğer işlemler",
+    "Security warning" : "Güvenlik uyarısı",
+    "Storage & database" : "Depolama ve veri tabanı",
+    "Data folder" : "Veri klasörü",
+    "Install and activate additional PHP modules to choose other database types." : "Diğer veri tabanı türlerini seçebilmek için ek PHP modüllerini kurun ve kullanıma alın.",
+    "For more details check out the documentation." : "Ayrıntılı bilgi almak için belgelere bakabilirsiniz.",
+    "Performance warning" : "Başarım uyarısı",
+    "You chose SQLite as database." : "Veri tabanı olarak SQLite seçtiniz.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite yalnızca küçük ve geliştirme ortamları için seçilmelidir. Üretim ortamları için farklı bir veri tabanı kullanmanız önerilir.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Dosya eşitlemesi için istemcileri kullanıyorsanız SQLite kullanımından kaçınmalısınız.",
+    "Database user" : "Veri tabanı kullanıcı adı",
+    "Database password" : "Veri tabanı parolası",
+    "Database name" : "Veri tabanı adı",
+    "Database tablespace" : "Veri tabanı tablo alanı",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lütfen sunucu adının yanında bağlantı noktasını da belirtin (Örnek: localhost:5432).",
+    "Database host" : "Veri tabanı sunucusu",
+    "Installing …" : "Kuruluyor…",
+    "Install" : "Kur",
+    "Need help?" : "Yardım gerekiyor mu?",
+    "See the documentation" : "Belgelere bakın",
     "{name} version {version} and above" : "{name} {version} üzeri sürümler",
     "This browser is not supported" : "Bu tarayıcı desteklenmiyor",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Tarayıcınız desteklenmiyor. Lütfen daha yeni bir sürüme ya da desteklenen bir sürüme yükseltin.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Var olan projeleri aramak için yazın",
     "New in" : "Şuraya ekle",
     "View changelog" : "Değişiklik günlüğünü görüntüle",
-    "Very weak password" : "Parola çok zayıf",
-    "Weak password" : "Parola zayıf",
-    "So-so password" : "Parola idare eder",
-    "Good password" : "Parola iyi",
-    "Strong password" : "Parola güçlü",
     "No action available" : "Yapılabilecek bir işlem yok",
     "Error fetching contact actions" : "Kişi işlemleri alınırken sorun çıktı",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" penceresini kapat",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "Dosya: %s",
     "Line: %s" : "Satır: %s",
     "Trace" : "İz",
-    "Security warning" : "Güvenlik uyarısı",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess dosyası yürürlükte olmadığından veri klasörünüz ve dosyalarınız İnternet üzerinden erişime açık.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Sunucunuzu nasıl yapılandıracağınız hakkında bilgi almak için <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">belgelere</a> bakabilirsiniz.",
-    "<strong>Create an admin account</strong>" : "<strong>Bir yönetici hesabı oluşturun</strong>",
-    "New admin account name" : "Yeni yönetici hesabı adı",
-    "New admin password" : "Yeni yönetici parolası",
-    "Show password" : "Parolayı görüntüle",
-    "Toggle password visibility" : "Parolayı görüntüle/gizle",
-    "Storage & database" : "Depolama ve veri tabanı",
-    "Data folder" : "Veri klasörü",
-    "Configure the database" : "Veri tabanını yapılandır",
-    "Only %s is available." : "Yalnızca %s kullanılabilir.",
-    "Install and activate additional PHP modules to choose other database types." : "Diğer veri tabanı türlerini seçebilmek için ek PHP modüllerini kurun ve kullanıma alın.",
-    "For more details check out the documentation." : "Ayrıntılı bilgi almak için belgelere bakabilirsiniz.",
-    "Database account" : "Veri tabanı hesabı",
-    "Database password" : "Veri tabanı parolası",
-    "Database name" : "Veri tabanı adı",
-    "Database tablespace" : "Veri tabanı tablo alanı",
-    "Database host" : "Veri tabanı sunucusu",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lütfen sunucu adının yanında bağlantı noktasını da belirtin (Örnek: localhost:5432).",
-    "Performance warning" : "Başarım uyarısı",
-    "You chose SQLite as database." : "Veri tabanı olarak SQLite seçtiniz.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite yalnızca küçük ve geliştirme ortamları için seçilmelidir. Üretim ortamları için farklı bir veri tabanı kullanmanız önerilir.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Dosya eşitlemesi için istemcileri kullanıyorsanız SQLite kullanımından kaçınmalısınız.",
-    "Install" : "Kur",
-    "Installing …" : "Kuruluyor…",
-    "Need help?" : "Yardım gerekiyor mu?",
-    "See the documentation" : "Belgelere bakın",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloud kurulumunu yeniden yapmayı deniyorsunuz gibi görünüyor. Ancak config klasöründe CAN_INSTALL dosyası eksik. Lütfen İşlemi sürdürmek için config klasöründe CAN_INSTALL dosyasını oluşturun.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Config klasöründeki CAN_INSTALL dosyası silinemedi. Lütfen bu dosyayı el ile silin.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Bu uygulamanın düzgün çalışabilmesi için JavaScript gereklidir. Lütfen {linkstart}JavaScript uygulamasını kullanıma alıp{linkend} sayfayı yeniden yükleyin.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "Profili düzenle",
     "The headline and about sections will show up here" : "Başlık ve hakkında bölümleri burada görüntülenir",
     "Error loading message template: {error}" : "İleti kalıbı yüklenirken sorun çıktı: {error}",
+    "Very weak password" : "Parola çok zayıf",
+    "Weak password" : "Parola zayıf",
+    "So-so password" : "Parola idare eder",
+    "Good password" : "Parola iyi",
+    "Strong password" : "Parola güçlü",
     "Profile not found" : "Profil bulunamadı",
-    "The profile does not exist." : "Profil bulunamadı."
+    "The profile does not exist." : "Profil bulunamadı.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess dosyası yürürlükte olmadığından veri klasörünüz ve dosyalarınız İnternet üzerinden erişime açık.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Sunucunuzu nasıl yapılandıracağınız hakkında bilgi almak için <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">belgelere</a> bakabilirsiniz.",
+    "<strong>Create an admin account</strong>" : "<strong>Bir yönetici hesabı oluşturun</strong>",
+    "New admin account name" : "Yeni yönetici hesabı adı",
+    "New admin password" : "Yeni yönetici parolası",
+    "Show password" : "Parolayı görüntüle",
+    "Toggle password visibility" : "Parolayı görüntüle/gizle",
+    "Configure the database" : "Veri tabanını yapılandır",
+    "Only %s is available." : "Yalnızca %s kullanılabilir.",
+    "Database account" : "Veri tabanı hesabı"
 },
 "nplurals=2; plural=(n > 1);");
