@@ -151,15 +151,15 @@ OC.L10N.register(
     "Log in with a device" : "ئۈسكۈنە بىلەن كىرىڭ",
     "Login or email" : "كىرىش ياكى ئېلخەت",
     "Your account is not setup for passwordless login." : "ھېساباتىڭىز پارولسىز كىرىش ئۈچۈن تەڭشەلمىدى.",
-    "Browser not supported" : "توركۆرگۈ قوللىمايدۇ",
-    "Passwordless authentication is not supported in your browser." : "توركۆرگۈڭىزدە پارولسىز دەلىللەشنى قوللىمايدۇ.",
     "Your connection is not secure" : "ئۇلىنىشىڭىز بىخەتەر ئەمەس",
     "Passwordless authentication is only available over a secure connection." : "پارولسىز دەلىللەش پەقەت بىخەتەر ئۇلىنىش ئارقىلىقلا بولىدۇ.",
+    "Browser not supported" : "توركۆرگۈ قوللىمايدۇ",
+    "Passwordless authentication is not supported in your browser." : "توركۆرگۈڭىزدە پارولسىز دەلىللەشنى قوللىمايدۇ.",
     "Reset password" : "پارولنى ئەسلىگە قايتۇرۇش",
+    "Back to login" : "قايتا كىرىش",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "ئەگەر بۇ ھېسابات مەۋجۇت بولسا ، ئېلېكترونلۇق خەت ئادرېسىغا پارولنى ئەسلىگە كەلتۈرۈش ئۇچۇرى ئەۋەتىلدى. ئەگەر ئۇنى تاپشۇرۇۋالمىسىڭىز ، ئېلېكترونلۇق خەت ئادرېسىڭىزنى ۋە ياكى ياكى تىزىملىتىپ كىرىڭ ، ئەخلەت خەت ساندۇقىڭىزنى تەكشۈرۈڭ ياكى يەرلىك ھۆكۈمەتتىن ياردەم سوراڭ.",
     "Couldn't send reset email. Please contact your administrator." : "قايتا ئېلېكترونلۇق خەت ئەۋەتەلمىدى. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
     "Password cannot be changed. Please contact your administrator." : "پارولنى ئۆزگەرتىشكە بولمايدۇ. باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
-    "Back to login" : "قايتا كىرىش",
     "New password" : "يېڭى ئىم",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "ھۆججەتلىرىڭىز شىفىرلانغان. پارولىڭىز ئەسلىگە كەلگەندىن كېيىن سانلىق مەلۇماتلىرىڭىزنى قايتۇرۇۋېلىشقا ئامال يوق. نېمە قىلىشنى بىلمىسىڭىز ، داۋاملاشتۇرۇشتىن بۇرۇن باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ. داۋاملاشتۇرۇشنى خالامسىز؟",
     "I know what I'm doing" : "نېمە قىلىۋاتقانلىقىمنى بىلىمەن",
@@ -202,6 +202,25 @@ OC.L10N.register(
     "Login form is disabled." : "كىرىش جەدۋىلى چەكلەنگەن.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud كىرىش جەدۋىلى چەكلەنگەن. ئەگەر بار بولسا باشقا كىرىش تاللانمىسىنى ئىشلىتىڭ ياكى باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.",
     "More actions" : "تېخىمۇ كۆپ ھەرىكەت",
+    "Security warning" : "بىخەتەرلىك ئاگاھلاندۇرۇشى",
+    "Storage & database" : "ساقلاش ۋە ساندان",
+    "Data folder" : "سانلىق مەلۇمات قىسقۇچ",
+    "Install and activate additional PHP modules to choose other database types." : "باشقا PHP بۆلەكلىرىنى ئورنىتىپ قوزغىتىپ باشقا ساندان تىپلىرىنى تاللاڭ.",
+    "For more details check out the documentation." : "تېخىمۇ كۆپ تەپسىلاتلارنى بۇ ھۆججەتتىن كۆرۈڭ.",
+    "Performance warning" : "ئىقتىدار ئاگاھلاندۇرۇشى",
+    "You chose SQLite as database." : "SQLite نى ساندان قىلىپ تاللىدىڭىز.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite پەقەت ئەڭ كىچىك ۋە تەرەققىيات مىساللىرى ئۈچۈن ئىشلىتىلىشى كېرەك. ئىشلەپچىقىرىش ئۈچۈن باشقا ساندان ئارقا سەھنىسىنى تەۋسىيە قىلىمىز.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ئەگەر ھۆججەتلەرنى ماسقەدەملەش ئۈچۈن خېرىدار ئىشلەتسىڭىز ، SQLite نى ئىشلىتىش تولىمۇ ئۈمىدسىزلىنىدۇ.",
+    "Database user" : "ساندان ئىشلەتكۈچى",
+    "Database password" : "ساندان پارولى",
+    "Database name" : "ساندان ئىسمى",
+    "Database tablespace" : "ساندان جەدۋىلى",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "باش ئاپپارات ئىسمى بىلەن بىللە پورت نومۇرىنى بەلگىلىۈڭ (مەسىلەن ، localhost: 5432).",
+    "Database host" : "ساندان مۇلازىمېتىرى",
+    "Installing …" : "قاچىلاش…",
+    "Install" : "قاچىلاش",
+    "Need help?" : "ياردەمگە ئېھتىياجلىقمۇ؟",
+    "See the documentation" : "ھۆججەتلەرنى كۆرۈڭ",
     "{name} version {version} and above" : "{name} نەشرى {version} ۋە ئۇنىڭدىن يۇقىرى",
     "This browser is not supported" : "بۇ توركۆرگۈچنى قوللىمايدۇ",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "توركۆرگۈڭىزنى قوللىمايدۇ. يېڭى نەشرىگە ياكى قوللايدىغان نەشرىگە يېڭىلاڭ.",
@@ -240,11 +259,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "مەۋجۇت تۈرلەرنى ئىزدەش ئۈچۈن كىرگۈزۈڭ",
     "New in" : "يېڭى",
     "View changelog" : "Changelog نى كۆرۈڭ",
-    "Very weak password" : "پارول بەك ئاجىز",
-    "Weak password" : "پارول ئاجىز",
-    "So-so password" : "شۇڭا مەخپىي نومۇر",
-    "Good password" : "ياخشى پارول",
-    "Strong password" : "كۈچلۈك پارول",
     "No action available" : "ھەرىكەت يوق",
     "Error fetching contact actions" : "ئالاقىلىشىش ھەرىكىتىنى ئېلىپ بېرىشتا خاتالىق",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" سۆزلىشىش رامكىسىنى تاقاڭ",
@@ -281,31 +295,6 @@ OC.L10N.register(
     "File: %s" : "ھۆججەت:% s",
     "Line: %s" : "Line:% s",
     "Trace" : "ئىز",
-    "Security warning" : "بىخەتەرلىك ئاگاھلاندۇرۇشى",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".Htaccess ھۆججىتى ئىشلىمىگەچكە ، سانلىق مەلۇمات مۇندەرىجىسىڭىز ۋە ھۆججەتلىرىڭىزنى توردىن زىيارەت قىلىشىڭىز مۇمكىن.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "مۇلازىمېتىرىڭىزنى قانداق تەڭشەش كېرەكلىكى توغرىسىدىكى ئۇچۇرلارنى <a href = \"% s\" target = \"_ blank\" rel = \"noreferrer noopener\"> ھۆججەت </a> دىن كۆرۈڭ.",
-    "Show password" : "پارولنى كۆرسەت",
-    "Toggle password visibility" : "پارولنىڭ كۆرۈنۈشچانلىقىنى توغرىلاڭ",
-    "Storage & database" : "ساقلاش ۋە ساندان",
-    "Data folder" : "سانلىق مەلۇمات قىسقۇچ",
-    "Configure the database" : "سانداننى سەپلەڭ",
-    "Only %s is available." : "پەقەت% s نىلا ئىشلەتكىلى بولىدۇ.",
-    "Install and activate additional PHP modules to choose other database types." : "باشقا PHP بۆلەكلىرىنى ئورنىتىپ قوزغىتىپ باشقا ساندان تىپلىرىنى تاللاڭ.",
-    "For more details check out the documentation." : "تېخىمۇ كۆپ تەپسىلاتلارنى بۇ ھۆججەتتىن كۆرۈڭ.",
-    "Database account" : "ساندان ھېساباتى",
-    "Database password" : "ساندان پارولى",
-    "Database name" : "ساندان ئىسمى",
-    "Database tablespace" : "ساندان جەدۋىلى",
-    "Database host" : "ساندان مۇلازىمېتىرى",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "باش ئاپپارات ئىسمى بىلەن بىللە پورت نومۇرىنى بەلگىلىۈڭ (مەسىلەن ، localhost: 5432).",
-    "Performance warning" : "ئىقتىدار ئاگاھلاندۇرۇشى",
-    "You chose SQLite as database." : "SQLite نى ساندان قىلىپ تاللىدىڭىز.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite پەقەت ئەڭ كىچىك ۋە تەرەققىيات مىساللىرى ئۈچۈن ئىشلىتىلىشى كېرەك. ئىشلەپچىقىرىش ئۈچۈن باشقا ساندان ئارقا سەھنىسىنى تەۋسىيە قىلىمىز.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ئەگەر ھۆججەتلەرنى ماسقەدەملەش ئۈچۈن خېرىدار ئىشلەتسىڭىز ، SQLite نى ئىشلىتىش تولىمۇ ئۈمىدسىزلىنىدۇ.",
-    "Install" : "قاچىلاش",
-    "Installing …" : "قاچىلاش…",
-    "Need help?" : "ياردەمگە ئېھتىياجلىقمۇ؟",
-    "See the documentation" : "ھۆججەتلەرنى كۆرۈڭ",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloud نى قايتا قاچىلىماقچى بولۇۋاتقان ئوخشايسىز. ئەمما CAN_INSTALL ھۆججىتى سەپلىمە مۇندەرىجىڭىزدە كەم. داۋاملاشتۇرۇش ئۈچۈن ھۆججەت قىسقۇچىڭىزدا CAN_INSTALL ھۆججىتىنى قۇرۇڭ.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "سەپلىمە ھۆججەت قىسقۇچىدىن CAN_INSTALL نى ئۆچۈرەلمىدى. بۇ ھۆججەتنى قولدا ئۆچۈرۈڭ.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "بۇ پروگرامما توغرا مەشغۇلات ئۈچۈن JavaScript تەلەپ قىلىدۇ. {linkstart} Java JavaScript {linkend} نى قوزغىتىپ ، بەتنى قايتا يۈكلەڭ.",
@@ -374,7 +363,19 @@ OC.L10N.register(
     "Edit Profile" : "ئارخىپنى تەھرىرلەش",
     "The headline and about sections will show up here" : "ماۋزۇ ۋە بۆلەكلەر بۇ يەردە كۆرسىتىلىدۇ",
     "Error loading message template: {error}" : "ئۇچۇر قېلىپىنى يۈكلەشتە خاتالىق: {error}",
+    "Very weak password" : "پارول بەك ئاجىز",
+    "Weak password" : "پارول ئاجىز",
+    "So-so password" : "شۇڭا مەخپىي نومۇر",
+    "Good password" : "ياخشى پارول",
+    "Strong password" : "كۈچلۈك پارول",
     "Profile not found" : "ئارخىپ تېپىلمىدى",
-    "The profile does not exist." : "ئارخىپ مەۋجۇت ئەمەس."
+    "The profile does not exist." : "ئارخىپ مەۋجۇت ئەمەس.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".Htaccess ھۆججىتى ئىشلىمىگەچكە ، سانلىق مەلۇمات مۇندەرىجىسىڭىز ۋە ھۆججەتلىرىڭىزنى توردىن زىيارەت قىلىشىڭىز مۇمكىن.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "مۇلازىمېتىرىڭىزنى قانداق تەڭشەش كېرەكلىكى توغرىسىدىكى ئۇچۇرلارنى <a href = \"% s\" target = \"_ blank\" rel = \"noreferrer noopener\"> ھۆججەت </a> دىن كۆرۈڭ.",
+    "Show password" : "پارولنى كۆرسەت",
+    "Toggle password visibility" : "پارولنىڭ كۆرۈنۈشچانلىقىنى توغرىلاڭ",
+    "Configure the database" : "سانداننى سەپلەڭ",
+    "Only %s is available." : "پەقەت% s نىلا ئىشلەتكىلى بولىدۇ.",
+    "Database account" : "ساندان ھېساباتى"
 },
 "nplurals=2; plural=(n != 1);");
