@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "使用设备登录",
     "Login or email" : "账号或电子邮箱",
     "Your account is not setup for passwordless login." : "你的账号未设置无密码登录。",
-    "Browser not supported" : "浏览器不受支持",
-    "Passwordless authentication is not supported in your browser." : "浏览器不支持无密码验证。",
     "Your connection is not secure" : "您的连接不安全",
     "Passwordless authentication is only available over a secure connection." : "无密码身份验证仅在安全连接上可用。",
+    "Browser not supported" : "浏览器不受支持",
+    "Passwordless authentication is not supported in your browser." : "浏览器不支持无密码验证。",
     "Reset password" : "重置密码",
+    "Back to login" : "返回登录",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "如果账号存在，一封密码重置信息将会被发送至你的电子邮箱地址。如果你没有收到该邮件，请验证你的电子邮箱地址/账号拼写是否正确，或检查邮件是否被归为垃圾邮件文件夹，或请求本地管理员的帮助。",
     "Couldn't send reset email. Please contact your administrator." : "未能成功发送重置邮件，请联系管理员。",
     "Password cannot be changed. Please contact your administrator." : "无法更改密码，请联系管理员。",
-    "Back to login" : "返回登录",
     "New password" : "新密码",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "您的文件已经加密。您的密码重置后就没有任何方式能恢复您的数据了。如果您不确定，请在继续前联系您的管理员。您是否真的要继续？",
     "I know what I'm doing" : "我知道我在做什么",
@@ -207,6 +207,42 @@ OC.L10N.register(
     "Login form is disabled." : "登录表单已禁用",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登录表单已禁用。如果可以，请使用其他登录选项或联系你的管理人员。",
     "More actions" : "更多操作 ",
+    "Password is too weak" : "密码太弱",
+    "Password is weak" : "弱密码",
+    "Password is average" : "一般密码",
+    "Password is strong" : "强密码",
+    "Password is very strong" : "密码很强",
+    "Password is extremely strong" : "密码极强",
+    "Unknown password strength" : "密码强度未知",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "您的数据目录和文件可能可以从互联网访问，因为 <code>.htaccess</code> 文件不起作用。",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "有关如何正确配置服务器的信息，{linkStart}请参阅文档{linkEnd}",
+    "Autoconfig file detected" : "检测到自动配置文件",
+    "The setup form below is pre-filled with the values from the config file." : "下方设置表单预先填写了配置文件中的值。",
+    "Security warning" : "安全警告",
+    "Create administration account" : "创建管理员账号",
+    "Administration account name" : "管理员账号名称",
+    "Administration account password" : "管理员账号密码",
+    "Storage & database" : "存储与数据库",
+    "Data folder" : "数据目录",
+    "Database configuration" : "数据库配置",
+    "Only {firstAndOnlyDatabase} is available." : "只有 {firstAndOnlyDatabase} 可用。",
+    "Install and activate additional PHP modules to choose other database types." : "安装并激活额外的 PHP 模块以选择其他数据库类型。",
+    "For more details check out the documentation." : "请查阅文档获得详细信息。",
+    "Performance warning" : "性能警告",
+    "You chose SQLite as database." : "您选择 SQLite 作为数据库。",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 应只用于最小化和开发实例。生产环境我们推荐使用不同的数据库后端。",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "如果您使用文件同步客户端，强烈不建议使用 SQLite。",
+    "Database user" : "数据库用户",
+    "Database password" : "数据库密码",
+    "Database name" : "数据库名",
+    "Database tablespace" : "数据库表空间",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "请填写主机名称和端口号（例如，localhost:5432）。",
+    "Database host" : "数据库主机",
+    "localhost" : "本地主机",
+    "Installing …" : "正在安装...",
+    "Install" : "安装",
+    "Need help?" : "需要帮助？",
+    "See the documentation" : "查看文档",
     "{name} version {version} and above" : "{name} 版本 {version} 及更高",
     "This browser is not supported" : "您的浏览器不受支持！",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "您的浏览器不受支持。请升级至较新或受支持的版本。",
@@ -247,11 +283,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "输入以搜索已有项目",
     "New in" : "新品",
     "View changelog" : "查看更新记录",
-    "Very weak password" : "非常弱的密码",
-    "Weak password" : "弱密码",
-    "So-so password" : "一般强度的密码",
-    "Good password" : "较强的密码",
-    "Strong password" : "强密码",
     "No action available" : "无可用操作",
     "Error fetching contact actions" : "查找联系人时出错",
     "Close \"{dialogTitle}\" dialog" : "关闭“{dialogTitle}”对话",
@@ -289,34 +320,6 @@ OC.L10N.register(
     "File: %s" : "文件：%s",
     "Line: %s" : "行：%s",
     "Trace" : "追踪",
-    "Security warning" : "安全警告",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "因为 .htaccess 文件没有工作，您的数据目录和文件可从互联网被访问。",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "关于如何正确配置服务器，请参见<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">文档</a>。",
-    "<strong>Create an admin account</strong>" : "<strong>创建管理员账号</strong>",
-    "New admin account name" : "新管理员账号名称",
-    "New admin password" : "新管理员密码",
-    "Show password" : "显示密码",
-    "Toggle password visibility" : "切换密码可见性",
-    "Storage & database" : "存储与数据库",
-    "Data folder" : "数据目录",
-    "Configure the database" : "配置数据库",
-    "Only %s is available." : "仅 %s 可用。",
-    "Install and activate additional PHP modules to choose other database types." : "安装并激活额外的 PHP 模块以选择其他数据库类型。",
-    "For more details check out the documentation." : "请查阅文档获得详细信息。",
-    "Database account" : "数据库账号",
-    "Database password" : "数据库密码",
-    "Database name" : "数据库名",
-    "Database tablespace" : "数据库表空间",
-    "Database host" : "数据库主机",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "请填写主机名称和端口号（例如，localhost:5432）。",
-    "Performance warning" : "性能警告",
-    "You chose SQLite as database." : "您选择 SQLite 作为数据库。",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 应只用于最小化和开发实例。生产环境我们推荐使用不同的数据库后端。",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "如果您使用文件同步客户端，强烈不建议使用 SQLite。",
-    "Install" : "安装",
-    "Installing …" : "正在安装...",
-    "Need help?" : "需要帮助？",
-    "See the documentation" : "查看文档",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "看起来您正在尝试重新安装您的 Nextcloud。但您的 config 文件夹中没有 CAN_INSTALL 文件。请在您的 config 文件夹中创建 CAN_INSTALL 文件以继续。",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "无法从 config 文件夹中移除 CAN_INSTALL 文件。请手动移除此文件。",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "对于正确的操作，该应用需要使用 JavaScript。请 {linkstart}启用 JavaScript{linkend}，并重新加载页面。",
@@ -385,7 +388,22 @@ OC.L10N.register(
     "Edit Profile" : "编辑个人资料",
     "The headline and about sections will show up here" : "标题和关于部分将显示在此处",
     "Error loading message template: {error}" : "加载消息模板出错：{error}",
+    "Very weak password" : "非常弱的密码",
+    "Weak password" : "弱密码",
+    "So-so password" : "一般强度的密码",
+    "Good password" : "较强的密码",
+    "Strong password" : "强密码",
     "Profile not found" : "未找到个人资料",
-    "The profile does not exist." : "个人资料不存在"
+    "The profile does not exist." : "个人资料不存在",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "因为 .htaccess 文件没有工作，您的数据目录和文件可从互联网被访问。",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "关于如何正确配置服务器，请参见<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">文档</a>。",
+    "<strong>Create an admin account</strong>" : "<strong>创建管理员账号</strong>",
+    "New admin account name" : "新管理员账号名称",
+    "New admin password" : "新管理员密码",
+    "Show password" : "显示密码",
+    "Toggle password visibility" : "切换密码可见性",
+    "Configure the database" : "配置数据库",
+    "Only %s is available." : "仅 %s 可用。",
+    "Database account" : "数据库账号"
 },
 "nplurals=1; plural=0;");
