@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "使用裝置登入",
     "Login or email" : "帳號或電子郵件",
     "Your account is not setup for passwordless login." : "您的帳號尚未設定無密碼登入。",
-    "Browser not supported" : "瀏覽器不支援",
-    "Passwordless authentication is not supported in your browser." : "您使用的瀏覽器不支援無密碼身份認證。",
     "Your connection is not secure" : "您的連線不安全",
     "Passwordless authentication is only available over a secure connection." : "無密碼身份認證僅可用於經加密的安全連線。",
+    "Browser not supported" : "瀏覽器不支援",
+    "Passwordless authentication is not supported in your browser." : "您使用的瀏覽器不支援無密碼身份認證。",
     "Reset password" : "重設密碼",
+    "Back to login" : "返回登入畫面",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "若此帳號存在，密碼重設郵件即已寄送至其電子郵件地址。若您未收到，請驗證您的電子郵件地址及/或帳號，並檢查您的垃圾郵件資料夾，或向您的本機管理員求助。",
     "Couldn't send reset email. Please contact your administrator." : "無法寄出重設密碼資訊。請聯絡您的管理員。",
     "Password cannot be changed. Please contact your administrator." : "密碼無法變更。請聯絡您的管理員。",
-    "Back to login" : "返回登入畫面",
     "New password" : "新密碼",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "由於您已啟用檔案加密，重設密碼後，您的資料將無法解密。若您不確定繼續與否，請聯絡管理員。確定要繼續嗎？",
     "I know what I'm doing" : "我知道我在做什麼",
@@ -207,6 +207,42 @@ OC.L10N.register(
     "Login form is disabled." : "登入表單已停用。",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登入表單已停用。使用其他登入選項（若可用）或聯絡您的管理人員。",
     "More actions" : "更多動作",
+    "Password is too weak" : "非常弱密碼",
+    "Password is weak" : "弱密碼",
+    "Password is average" : "一般密碼",
+    "Password is strong" : "強密碼",
+    "Password is very strong" : "非常強密碼",
+    "Password is extremely strong" : "極弱密碼",
+    "Unknown password strength" : "未知密碼強度",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "您的資料目錄與檔案似乎可從網際網路存取，因為 <code>.htaccess</code> 檔案並未生效。",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "{linkStart}閱讀說明文件{linkEnd}來瞭解如何正確設定您的伺服器",
+    "Autoconfig file detected" : "偵測到自動組態檔案",
+    "The setup form below is pre-filled with the values from the config file." : "下面的設定表單已預先填入設定檔中的值。",
+    "Security warning" : "安全性警告",
+    "Create administration account" : "建立管理員帳號",
+    "Administration account name" : "管理員帳號名稱",
+    "Administration account password" : "管理員帳號密碼",
+    "Storage & database" : "儲存空間和資料庫",
+    "Data folder" : "資料儲存位置",
+    "Database configuration" : "資料庫組態",
+    "Only {firstAndOnlyDatabase} is available." : "僅 {firstAndOnlyDatabase} 可用。",
+    "Install and activate additional PHP modules to choose other database types." : "安裝並啟用相關 PHP 模組來選擇其他資料庫類型。",
+    "For more details check out the documentation." : "請參閱說明文件了解更多細節。",
+    "Performance warning" : "效能警告",
+    "You chose SQLite as database." : "您選擇了 SQLite 作為資料庫。",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或開發中站台。對於正式上線用途，我們建議改用其他資料庫後端。",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若您會使用桌面版或手機版客戶端同步檔案，則強烈不建議使用 SQLite。",
+    "Database user" : "資料庫使用者",
+    "Database password" : "資料庫密碼",
+    "Database name" : "資料庫名稱",
+    "Database tablespace" : "資料庫資料表空間",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
+    "Database host" : "資料庫主機",
+    "localhost" : "localhost",
+    "Installing …" : "正在安裝…",
+    "Install" : "安裝",
+    "Need help?" : "需要協助嗎？",
+    "See the documentation" : "參閱說明文件",
     "{name} version {version} and above" : "{name} 版本 {version} 以上",
     "This browser is not supported" : "不支援此瀏覽器",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
@@ -247,11 +283,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "搜尋現有專案",
     "New in" : "新加入",
     "View changelog" : "檢視版本更新紀錄",
-    "Very weak password" : "密碼安全性極弱",
-    "Weak password" : "密碼安全性弱",
-    "So-so password" : "密碼安全性普通",
-    "Good password" : "密碼安全性佳",
-    "Strong password" : "密碼安全性極佳",
     "No action available" : "沒有可用的動作",
     "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
     "Close \"{dialogTitle}\" dialog" : "關閉「{dialogTitle}」對話方塊",
@@ -289,34 +320,6 @@ OC.L10N.register(
     "File: %s" : "檔案：%s",
     "Line: %s" : "行號：%s",
     "Trace" : "追蹤",
-    "Security warning" : "安全性警告",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄與檔案似乎可從網際網路存取，因為 .htaccess 檔案並未生效。",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明文件</a>來瞭解如何正確設定您的伺服器組態。",
-    "<strong>Create an admin account</strong>" : "<strong>建立管理員帳號</strong>",
-    "New admin account name" : "新管理員帳號名稱",
-    "New admin password" : "新管理員密碼",
-    "Show password" : "顯示密碼",
-    "Toggle password visibility" : "切換密碼可見性",
-    "Storage & database" : "儲存空間和資料庫",
-    "Data folder" : "資料儲存位置",
-    "Configure the database" : "設定資料庫組態",
-    "Only %s is available." : "剩下 %s 可使用。",
-    "Install and activate additional PHP modules to choose other database types." : "安裝並啟用相關 PHP 模組來選擇其他資料庫類型。",
-    "For more details check out the documentation." : "請參閱說明文件了解更多細節。",
-    "Database account" : "資料庫帳號",
-    "Database password" : "資料庫密碼",
-    "Database name" : "資料庫名稱",
-    "Database tablespace" : "資料庫資料表空間",
-    "Database host" : "資料庫主機",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "請指定連接埠號與主機名稱（例如：localhost:5432）。",
-    "Performance warning" : "效能警告",
-    "You chose SQLite as database." : "您選擇了 SQLite 作為資料庫。",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或開發中站台。對於正式上線用途，我們建議改用其他資料庫後端。",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若您會使用桌面版或手機版客戶端同步檔案，則強烈不建議使用 SQLite。",
-    "Install" : "安裝",
-    "Installing …" : "正在安裝…",
-    "Need help?" : "需要協助嗎？",
-    "See the documentation" : "參閱說明文件",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "您似乎正在嘗試重新安裝 Nextcloud。然而，檔案 CAN_INSTALL 並不在您的 config 目錄中。請在您的 config 資料夾中建立 CAN_INSTALL 檔以繼續。",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "無法從 config 資料夾中移除 CAN_INSTALL 檔案。請手動移除此檔案。",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "此應用程式需要 JavaScript 才能正常運作。請 {linkstart} 啟用 JavaScript{linkend} 然後重新載入頁面。",
@@ -385,7 +388,22 @@ OC.L10N.register(
     "Edit Profile" : "編輯個人檔案",
     "The headline and about sections will show up here" : "標題與關於區段將在此顯示",
     "Error loading message template: {error}" : "載入訊息範本時發生錯誤：{error}",
+    "Very weak password" : "密碼安全性極弱",
+    "Weak password" : "密碼安全性弱",
+    "So-so password" : "密碼安全性普通",
+    "Good password" : "密碼安全性佳",
+    "Strong password" : "密碼安全性極佳",
     "Profile not found" : "找不到個人檔案",
-    "The profile does not exist." : "個人檔案不存在。"
+    "The profile does not exist." : "個人檔案不存在。",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄與檔案似乎可從網際網路存取，因為 .htaccess 檔案並未生效。",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "請參閱<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明文件</a>來瞭解如何正確設定您的伺服器組態。",
+    "<strong>Create an admin account</strong>" : "<strong>建立管理員帳號</strong>",
+    "New admin account name" : "新管理員帳號名稱",
+    "New admin password" : "新管理員密碼",
+    "Show password" : "顯示密碼",
+    "Toggle password visibility" : "切換密碼可見性",
+    "Configure the database" : "設定資料庫組態",
+    "Only %s is available." : "剩下 %s 可使用。",
+    "Database account" : "資料庫帳號"
 },
 "nplurals=1; plural=0;");
