@@ -38,6 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "É requerido um servidor da versão %s ou superior.",
     "Server version %s or lower is required." : "É requerido um servidor da versão %s ou abaixo.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "A conta conectada deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
+    "Your current IP address doesn't allow you to perform admin actions" : "Seu endereço IP atual não permite que você execute ações administrativas",
     "Logged in account must be an admin or sub admin" : "A conta conectada deve ser de um administrador ou subadministrador",
     "Logged in account must be an admin" : "A conta logada deve ser de um administrador",
     "Wiping of device %s has started" : "Limpeza do dispositivo %s iniciou",
@@ -58,7 +59,11 @@ OC.L10N.register(
     "Avatar image is not square" : "A imagem do avatar não é quadrada",
     "Files" : "Arquivos",
     "View profile" : "Visualizar perfil",
+    "same time" : "mesmo tempo",
     "_%nh_::_%nh_" : ["%nh","%nh","%nh"],
+    "_%nm_::_%nm_" : ["%nm","%nm","%nm"],
+    "%s ahead" : "%s à frente",
+    "%s behind" : "%s atrás",
     "Local time: %s" : "Hora local: %s",
     "today" : "hoje",
     "tomorrow" : "amanhã",
@@ -81,6 +86,10 @@ OC.L10N.register(
     "seconds ago" : "segundos atrás",
     "Empty file" : "Arquivo vazio",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "O módulo com a ID: %s não existe. Por favor, habilite-o nas configurações de seu aplicativo ou contacte o administrador.",
+    "File is too large to convert" : "O arquivo é muito grande para converter",
+    "Could not convert file" : "Não foi possível converter o arquivo",
+    "Destination does not exist" : "Destino não existe",
+    "Destination is not creatable" : "Destino não pode ser criado",
     "Dot files are not allowed" : "Arquivos Dot não são permitidos",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" é um nome de arquivo ou pasta proibido.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" é um prefixo proibido para nomes de arquivos ou pastas.",
@@ -92,6 +101,10 @@ OC.L10N.register(
     "Invalid path" : "Diretório inválido",
     "Failed to create file from template" : "Falha ao criar arquivo do modelo ",
     "Templates" : "Modelos ",
+    "Moving a share (%s) into another share (%s) is not allowed" : "Não é permitido mover um compartilhamento (%s) para outro compartilhamento (%s)",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "Não é permitido mover um compartilhamento (%s) para outro armazenamento (%s)",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "Não é permitido mover um armazenamento (%s) para compartilhamento (%s)",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "Não é permitido mover um armazenamento (%s) para outro armazenamento (%s)",
     "Path contains invalid segments" : "O caminho contém segmentos inválidos",
     "Filename is a reserved word" : "Nome do arquivo é uma palavra reservada",
     "Filename contains at least one invalid character" : "O nome do arquivo contém pelo menos um caractere inválido  ",
@@ -138,6 +151,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
     "Oracle Login and/or password not valid" : "Login e/ou senha Oracle inválidos",
     "PostgreSQL Login and/or password not valid" : "Login e/ou senha do PostgreSQL inválidos",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "O Mac OS X não é compatível e %s não funcionará corretamente nessa plataforma. Use-o por sua própria conta e risco!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter melhores resultados, por favor considere o uso de um servidor GNU/Linux em seu lugar.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32 bits e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente não recomendável.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou mude o PHP para 64bit.",
@@ -167,6 +181,7 @@ OC.L10N.register(
     "You cannot share your root folder" : "Você não pode compartilhar sua pasta raiz",
     "You are not allowed to share %s" : "Você não tem permissão para compartilhar %s",
     "Valid permissions are required for sharing" : "Permissões válidas são necessárias para compartilhamento",
+    "File shares cannot have create or delete permissions" : "Os compartilhamentos de arquivos não podem ter permissões de criação ou exclusão",
     "Cannot increase permissions of %s" : "Não foi possível aumentar as permissões de %s",
     "Shares need at least read permissions" : "Compartilhamentos precisam pelo menos permissões de leitura",
     "Files cannot be shared with delete permissions" : "Arquivos não podem ser compartilhados com permissões de exclusão",
@@ -309,8 +324,13 @@ OC.L10N.register(
     "The audio to transcribe" : "O áudio a ser transcrito",
     "Transcription" : "Transcrição",
     "The transcribed text" : "O texto transcrito",
+    "ContextAgent" : "ContextAgent",
+    "Chat with an agent" : "Conversar com um agente",
     "Chat message" : "Mensagem de bate-papo",
+    "A chat message to send to the agent." : "Uma mensagem de bate-papo a ser enviada ao agente",
     "Confirmation" : "Confirmação",
+    "Conversation token" : "Token de conversação",
+    "Generated response" : "Gerar reposta",
     "Context write" : "Gravação de contexto",
     "Writes text in a given style based on the provided source material." : "Escreve texto em um determinado estilo com base no material de origem fornecido.",
     "Writing style" : "Estilo de escrita",
@@ -345,6 +365,12 @@ OC.L10N.register(
     "The history of chat messages before the current message, starting with a message by the user" : "O histórico de mensagens de bate-papo antes da mensagem atual, começando com uma mensagem do usuário",
     "Response message" : "Mensagem de resposta",
     "The generated response as part of the conversation" : "A resposta gerada como parte da conversa",
+    "Chat with tools" : "Conversar com ferramentas",
+    "Tool message" : "Mensagem da ferramenta",
+    "Available tools" : "Ferramentas disponíveis",
+    "The available tools in JSON format" : "As ferramentas disponíveis em formato JSON",
+    "The response from the chat model" : "A resposta do modelo de bate-papo",
+    "Tool calls" : "Chamadas de ferramentas",
     "Formalize text" : "Formalizar texto",
     "Takes a text and makes it sound more formal" : "Pega um texto e faz com que ele soe mais formal",
     "Write a text that you want the assistant to formalize" : "Escreva um texto que você deseja que o assistente formalize",
@@ -355,7 +381,10 @@ OC.L10N.register(
     "Original text" : "Texto original",
     "The original text to generate a headline for" : "O texto original para gerar um título para",
     "The generated headline" : "O título gerado",
+    "Proofread" : "Revisar",
     "Text" : "Texto",
+    "The text to proofread" : "O texto a ser revisado",
+    "Corrections" : "Correções",
     "Reformulate text" : "Reformular texto",
     "Takes a text and reformulates it" : "Pega um texto e o reformula",
     "Write a text that you want the assistant to reformulate" : "Escrever um texto que você deseja que o assistente reformule",
